@@ -8,11 +8,11 @@ from .flow import *  # noqa F403
 from .components import (LazyLLMDataprocBase, LazyLLMFinetuneBase, LazyLLMDeployBase,
                          LazyLLMValidateBase, register as component_register, Prompter,
                          AlpacaPrompter, ChatPrompter, FastapiApp, JsonFormatter, FileFormatter)
+from .redis_client import redis_client
 
 from .module import (ModuleBase, ModuleBase as Module, UrlModule, TrainableModule, ActionModule,
                      ServerModule, TrialModule, register as module_register,
                      OnlineChatModule, OnlineEmbeddingModule, AutoModel, OnlineMultiModalModule)
-from .client import redis_client
 from .hook import LazyLLMHook
 from .tools import (Document, Reranker, Retriever, WebModule, ToolManager, FunctionCall,
                     FunctionCallAgent, fc_register, ReactAgent, PlanAndSolveAgent, ReWOOAgent, SentenceSplitter,
@@ -79,7 +79,7 @@ __all__ = [
     'FunctionCall',
     'FunctionCallAgent',
     'fc_register',
-    "LLMParser",
+    'LLMParser',
     'ReactAgent',
     'PlanAndSolveAgent',
     'ReWOOAgent',
