@@ -28,5 +28,5 @@ def main():
     else:
         exit()
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
