@@ -1,7 +1,7 @@
 from .registry import LazyLLMRegisterMetaClass, LazyLLMRegisterMetaABCClass, _get_base_cls_from_registry, Register
 from .common import package, kwargs, arguments, LazyLLMCMD, timeout, final, ReadOnlyWrapper, DynamicDescriptor, override
 from .common import FlatList, Identity, ResultCollector, ArgsDict, CaseInsensitiveDict
-from .common import ReprRule, make_repr, modify_repr, is_valid_url, is_valid_path
+from .common import ReprRule, make_repr, modify_repr, is_valid_url, is_valid_path, SingletonMeta
 from .common import once_flag, call_once, once_wrapper, singleton, reset_on_pickle, Finalizer
 from .text import Color, colored_text
 from .option import Option, OptionIter
@@ -44,6 +44,7 @@ __all__ = [
     'load_obj',
     'is_valid_url',
     'is_valid_path',
+    'SingletonMeta',
     'Finalizer',
 
     # arg praser
