@@ -7,13 +7,14 @@ from contextlib import contextmanager
 import copy
 import threading
 import types
+import json
 from ..configs import config
 from urllib.parse import urlparse
 
 try:
     from typing import final
 except ImportError:
-    _F = typing.TypeVar("_F", bound=Callable[..., Any])
+    _F = typing.TypeVar('_F', bound=Callable[..., Any])
     def final(f: _F) -> _F:
         """A decorator to indicate final methods and final classes.
 
@@ -48,6 +49,11 @@ except ImportError:
 
 class FlatList(list):
     def absorb(self, item):
+        """Absorb elements into the list.
+
+Args:
+    item: Element to add, can be a single element or a list
+"""
         if isinstance(item, list):
             self.extend(item)
         elif item is not None:
@@ -55,15 +61,37 @@ class FlatList(list):
 
 
 class ArgsDict(dict):
+    """Parameter dictionary class for managing and validating command line arguments.
+
+Args:
+    *args: Positional arguments passed to parent dict class
+    **kwargs: Keyword arguments passed to parent dict class
+
+**Returns:**
+
+- ArgsDict instance providing parameter checking and formatting functionality
+"""
     def __init__(self, *args, **kwargs):
         super(ArgsDict, self).__init__(*args, **kwargs)
 
     def check_and_update(self, kw):
+        """Check and update parameter dictionary.
+
+Args:
+    kw (dict): Parameter dictionary to update
+"""
         assert set(kw.keys()).issubset(set(self)), f'unexpected keys: {set(kw.keys()) - set(self)}'
         self.update(kw)
 
     def parse_kwargs(self):
-        string = ' '.join(f'--{k}={v}' if type(v) is not str else f'--{k}=\"{v}\"' for k, v in self.items())
+        """Parse parameter dictionary into command line argument string.
+"""
+        string = []
+        for k, v in self.items():
+            if type(v) is dict:
+                v = json.dumps(v).replace('\"', '\\\"')
+            string.append(f'--{k}={v}' if type(v) is not str else f'--{k}=\"{v}\"')
+        string = ' '.join(string)
         return string
 
 class CaseInsensitiveDict(dict):
@@ -241,7 +269,7 @@ Examples:
         if self.no_displays:
             for item in self.no_displays:
                 pattern = r'(-{1,2}' + re.escape(item) + r')(\s|=|)(\S+|)'
-                cmd = re.sub(pattern, "", cmd)
+                cmd = re.sub(pattern, '', cmd)
             return cmd
         else:
             return cmd
@@ -290,7 +318,9 @@ def timeout(duration, *, msg=''):
 
 
 class ReadOnlyWrapper(object):
-    """A lightweight read-only wrapper that holds an arbitrary object and exposes its attributes. It supports swapping the internal object dynamically and provides utility for checking emptiness. Note: it does not enforce deep immutability, but deepcopy drops the wrapped object.
+    """
+A lightweight read-only wrapper that holds an arbitrary object and exposes its attributes. It supports swapping the internal object dynamically and provides utility for checking emptiness. Note: it does not enforce deep immutability, but deepcopy drops the wrapped object.
+
 Args:
     obj (Optional[Any]): The initial wrapped object, defaults to None.
 """
@@ -298,7 +328,8 @@ Args:
         self.obj = obj
 
     def set(self, obj):
-        """Replace the currently wrapped internal object.
+        """
+Replace the currently wrapped internal object.
 
 Args:
     obj (Any): New object to wrap.
@@ -321,12 +352,13 @@ Args:
         return ReadOnlyWrapper()
 
     def isNone(self):
-        """Check whether the wrapper currently holds no object.
+        """
+Check whether the wrapper currently holds no object.
 
 Args:
     None.
 
-**Returns**
+**Returns:**
 
 - bool: True if the internal object is None, otherwise False.
 """
@@ -334,7 +366,8 @@ Args:
 
 
 class Identity():
-    """Identity module that directly returns the input as output.
+    """
+Identity module that directly returns the input as output.
 
 This module serves as a no-op placeholder in composition pipelines. If multiple inputs are provided, they are packed together before returning.
 
@@ -379,7 +412,7 @@ Useful for scenarios where intermediate results need to be shared across steps.
     def keys(self):
         """Get all stored result names.
 
-**Returns**
+**Returns:**
 
 - KeysView[str]: A set-like object containing result names.
 """
@@ -387,7 +420,7 @@ Useful for scenarios where intermediate results need to be shared across steps.
     def items(self):
         """Get all stored (name, value) pairs.
 
-**Returns**
+**Returns:**
 
 - ItemsView[str, Any]: A set-like object containing name-value pairs of results.
 """
@@ -534,6 +567,11 @@ def once_wrapper(reset_on_pickle):
 
 
 class DynamicDescriptor:
+    """Dynamic descriptor class for creating descriptors that support both instance and class level calls.
+
+Args:
+    func (callable): Function or method to be wrapped
+"""
     class Impl:
         def __init__(self, func, instance, owner):
             self._func, self._instance, self._owner = func, instance, owner
@@ -621,6 +659,24 @@ def is_valid_path(path):
     return os.path.isfile(path)
 
 class Finalizer(object):
+    """Finalizer class for managing resource cleanup and release operations. Can be used as a context manager or trigger cleanup automatically when object is destroyed.
+
+Args:
+    func1 (Callable): Primary cleanup function. If func2 is provided, func1 is executed immediately and func2 becomes the cleanup function.
+    func2 (Optional[Callable]): Optional cleanup function, defaults to None.
+    condition (Callable): Condition function, cleanup is executed only when it returns True, defaults to always returning True.
+
+Uses:
+1. Can be used as a context manager (with statement)
+2. Can trigger cleanup automatically when object is destroyed
+3. Supports conditional cleanup
+4. Supports two-phase initialization and cleanup
+
+Note:
+    - When func2 is provided, func1 is executed immediately during initialization
+    - Cleanup function is executed only once
+    - Cleanup occurs when object is destroyed or context is exited
+"""
     def __init__(self, func1: Callable, func2: Optional[Callable] = None, *, condition: Callable = lambda: True):
         if func2:
             func1()
@@ -638,3 +694,14 @@ class Finalizer(object):
         if self._func:
             if self._condition(): self._func()
             self._func = None
+
+class SingletonMeta(type):
+    _instances = {}
+    _lock = threading.Lock()
+
+    def __call__(cls, *args, **kwargs):
+        if cls not in cls._instances:
+            with cls._lock:
+                if cls not in cls._instances:
+                    cls._instances[cls] = super().__call__(*args, **kwargs)
+        return cls._instances[cls]
