@@ -23,21 +23,21 @@ class _OptionIterator(object):
 
 
 class Option(object):
-    """Option management class provided by LazyLLM, used for managing multiple option values and iterating between them. This class is primarily used for parameter grid search and hyperparameter tuning scenarios.
+    """
+Option management class provided by LazyLLM, used for managing multiple option values and iterating between them. This class is primarily used for parameter grid search and hyperparameter tuning scenarios.
 
 Args:
-    *obj: One or more option values, which can be objects of any type. If a single list or tuple is passed, it will be automatically expanded.
+    *obj: One or more option values, which can be objects of any type. If a single list or tuple is passed, it will be automatically expanded. At least two options must be provided.
 
-Key features of this class:
+Key features:
 
-- **Multi-option Management**: Can manage multiple different option values
-- **Iteration Support**: Supports standard Python iteration protocol, can iterate through all options
-- **Current Value Access**: Always can access the currently selected option value
-- **Deep Copy**: Supports deep copying of the currently selected option value
-- **Multi-process Compatibility**: Supports usage in multi-process environments
-
-**Note**: This class is primarily used for LazyLLM's internal parameter search and trial management, especially in TrialModule for parameter grid search.
+- **Multi-option Management**: Can manage multiple different option values.
+- **Iteration Support**: Supports standard Python iteration protocol, allowing traversal of all options.
+- **Current Value Access**: Provides access to the currently selected option.
+- **Deep Copy**: Supports obtaining a deep copy of the currently selected option.
+- **Cyclic Iteration**: Options can be iterated over in a cyclic manner.
 
+**Note**: This class is mainly used for LazyLLM's internal parameter search and trial management, especially in `TrialModule` for parameter grid search.
 
 
 Examples:
