@@ -8,8 +8,8 @@ from typing import Type
 from lazyllm.thirdparty import redis
 from filelock import FileLock
 
-config.add("default_fsqueue", str, "sqlite", "DEFAULT_FSQUEUE")
-config.add("fsqredis_url", str, "", "FSQREDIS_URL")
+config.add('default_fsqueue', str, 'sqlite', 'DEFAULT_FSQUEUE')
+config.add('fsqredis_url', str, '', 'FSQREDIS_URL')
 
 class FileSystemQueue(ABC):
     """Abstract base class for file system-based queues.
@@ -43,11 +43,29 @@ Args:
 
     @classmethod
     def get_instance(cls, klass):
+        """Get the queue instance for the specified class name.
+
+This method returns the queue object bound to the given class name. If the class name has not been registered, it will be initialized automatically.
+
+Args:
+    klass (str): Queue class name identifier, must not be ``'__default__'``.
+
+**Returns:**
+
+- FileSystemQueue: Queue instance bound to the specified class name.
+"""
         assert isinstance(klass, str) and klass != '__default__'
         return cls(klass=klass)
 
     @classmethod
     def set_default(cls, queue: Type):
+        """Set the default queue implementation.
+
+This method specifies the default queue class, used as the backend implementation when `klass` is not provided.
+
+Args:
+    queue (Type): Default queue class.
+"""
         cls.__default_queue__ = queue
 
     @property
@@ -95,13 +113,11 @@ Examples:
     """
         return self._dequeue(self.sid, limit=limit)
     def peek(self):
-        """View the message at the head of the queue without removing it.
-
-This method allows viewing the earliest message in the queue without removing it from the queue.
+        """Retrieve the next message in the queue without removing it.
 
 **Returns:**
 
-- The message at the head of the queue, or None if the queue is empty.
+- Any: The next available message in the queue, or ``None`` if the queue is empty.
 
 
 Examples:
@@ -117,13 +133,11 @@ Examples:
     """
         return self._peek(self.sid)
     def size(self):
-        """Get the queue size.
-
-This method returns the current number of messages in the queue.
+        """Get the number of messages in the queue.
 
 **Returns:**
 
-- int: Number of messages in the queue.
+- int: The current number of messages in the queue.
 
 
 Examples:
@@ -143,12 +157,17 @@ Examples:
     0
     """
         return self._size(self.sid)
-    def init(self): self.clear()
+    def init(self):
+        """Initialize the queue.
+
+This method clears all messages in the current queue, equivalent to calling ``clear()``.
+"""
+        self.clear()
 
     def clear(self):
         """Clear the queue.
 
-This method removes all messages from the queue, resetting it to an empty state.
+Removes all messages from the queue, resetting it to an empty state.
 
 
 Examples:
@@ -184,11 +203,11 @@ Examples:
 # true means one connection can be used in multiple thread
 # refer to: https://sqlite.org/compile.html#threadsafe
 def sqlite3_check_threadsafety() -> bool:
-    conn = sqlite3.connect(":memory:")
-    res = conn.execute("""
+    conn = sqlite3.connect(':memory:')
+    res = conn.execute('''
         select * from pragma_compile_options
         where compile_options like 'THREADSAFE=%'
-    """).fetchall()
+    ''').fetchall()
     conn.close()
     return True if res[0][0] == 'THREADSAFE=1' else False
 
@@ -196,6 +215,7 @@ class SQLiteQueue(FileSystemQueue):
     """Persistent file system queue backed by SQLite.
 This class extends FileSystemQueue and stores queue data in an SQLite database. Messages are ordered by a position field to preserve FIFO behavior. The class supports concurrent-safe operations including enqueue, dequeue, peek, size checking, and clearing the queue.
 The queue database is saved at ~/.lazyllm_filesystem_queue.db, with a file lock mechanism ensuring safe access in multi-process environments.
+
 Args:
     klass (str): Name of the queue category used to logically separate queues. Default is '__default__'.
 """
@@ -287,14 +307,15 @@ Args:
 
 
 class RedisQueue(FileSystemQueue):
-    """Redis-backed file system queue (inherits from FileSystemQueue) for cross-process/node message passing and queue management. It initializes its underlying storage using a configured Redis URL and employs thread-safe setup logic.
+    """
+Redis-backed file system queue (inherits from FileSystemQueue) for cross-process/node message passing and queue management. It initializes its underlying storage using a configured Redis URL and employs thread-safe setup logic.
 
 Args:
     klass (str): Classification name for the queue instance to distinguish different queues. Defaults to '__default__'.
 """
     def __init__(self, klass='__default__'):
         super(__class__, self).__init__(klass=klass)
-        self.redis_url = config["fsqredis_url"]
+        self.redis_url = config['fsqredis_url']
         self._lock = threading.Lock()
         self._initialize_db()
 
@@ -303,7 +324,7 @@ Args:
             conn = redis.Redis.from_url(self.redis_url)
             assert (
                 conn.ping()
-            ), "Found fsque reids config but can not connect, please check your config `LAZYLLM_FSQREDIS_URL`."
+            ), 'Found fsque reids config but can not connect, please check your config `LAZYLLM_FSQREDIS_URL`.'
             if not conn.exists(self.sid):
                 conn.rpush(self.sid, '<start>')
 
