@@ -24,6 +24,7 @@ class LazyDict(dict):
     """A special dictionary class designed for lazy programmers. Supports various convenient access and operation methods.
 
 Features:
+
 1. Use dot notation instead of ['str'] to access dictionary elements
 2. Support lowercase first character to make statements more like function calls
 3. Support direct calls when dictionary has only one element
@@ -171,41 +172,28 @@ class Register(object):
 After the function is called, it returns a decorator which wraps the decorated function into a Component and registers it in a group named cls.
 
 Args:
-    cls (str) :The name of the group to which the function will be registered. The group must exist. Default groups include ``finetune`` and ``deploy``. Users can create new groups by calling the ``new_group`` function.
-    rewrite_func (str) :The name of the function to be rewritten after registration. Default is ``apply``. When registering a bash command, you need to pass ``cmd`` as the argument.
+    base (type): Base class
+    fnames (Union[str, List[str]]): Function name or function name list to rewrite
+    template (str, optional): Registration template string, defaults to standard registration template
+    default_group (str, optional): Default group name, defaults to None
 
-**Examples:**
 
-```python
->>> import lazyllm
->>> @lazyllm.component_register('mygroup')
-... def myfunc(input):
-...    return input
-...
->>> lazyllm.mygroup.myfunc()(1)
-1
-```
-
-<span style="font-size: 20px;">&ensp;**`register.cmd(cls)→ Decorator `**</span>
-
-After the function is called, it returns a decorator that wraps the decorated function into a Component and registers it in a group named cls. The wrapped function needs to return an executable bash command.
-
-Args:
-    cls (str) :The name of the group to which the function will be registered. The group must exist. Default groups include ``finetune`` and ``deploy``. Users can create new groups by calling the ``new_group`` function.
-
-**Examples:**
-
-```python
->>> import lazyllm
->>> @lazyllm.component_register.cmd('mygroup')
-... def mycmdfunc(input):
-...     return f'echo {input}'
-...
->>> lazyllm.mygroup.mycmdfunc()(1)
-PID: 2024-06-01 00:00:00 lazyllm INFO: (lazyllm.launcher) Command: echo 1
-PID: 2024-06-01 00:00:00 lazyllm INFO: (lazyllm.launcher) PID: 1
-```
-"""
+Examples:
+    >>> import lazyllm
+    >>> @lazyllm.component_register('mygroup')
+    ... def myfunc(input):
+    ...    return input
+    ...
+    >>> lazyllm.mygroup.myfunc()(1)
+    1
+    >>> @lazyllm.component_register.cmd('mygroup')
+    ... def mycmdfunc(input):
+    ...     return f'echo {input}'
+    ...
+    >>> lazyllm.mygroup.mycmdfunc()(1)
+    PID: 2024-06-01 00:00:00 lazyllm INFO: (lazyllm.launcher) Command: echo 1
+    PID: 2024-06-01 00:00:00 lazyllm INFO: (lazyllm.launcher) PID: 1
+    """
     def __init__(self, base, fnames, template: str = reg_template, default_group: Optional[str] = None):
         self.basecls = base
         self.fnames = [fnames] if isinstance(fnames, str) else fnames
