@@ -7,34 +7,35 @@ from .finetune import LazyLLMFinetuneBase
 from .deploy import LazyLLMDeployBase, FastapiApp
 from .validate import LazyLLMValidateBase
 from .auto import AutoDeploy, AutoFinetune
-from .utils import ModelManager
+from .utils import ModelManager, LLMType
 from .formatter import FormatterBase, EmptyFormatter, JsonFormatter, FileFormatter
 from .deploy import (StableDiffusionDeploy, TTSDeploy, BarkDeploy, ChatTTSDeploy,
                      MusicGenDeploy, SenseVoiceDeploy, OCRDeploy)
 
 
 __all__ = [
-    "register",
-    "Prompter",
-    "AlpacaPrompter",
-    "ChatPrompter",
-    "LazyLLMDataprocBase",
-    "LazyLLMFinetuneBase",
-    "LazyLLMDeployBase",
-    "LazyLLMValidateBase",
-    "FastapiApp",
-    "AutoDeploy",
-    "AutoFinetune",
-    "ModelManager",
-    "FormatterBase",
-    "EmptyFormatter",
-    "JsonFormatter",
-    "FileFormatter",
-    "StableDiffusionDeploy",
-    "TTSDeploy",
-    "BarkDeploy",
-    "ChatTTSDeploy",
-    "MusicGenDeploy",
-    "SenseVoiceDeploy",
-    "OCRDeploy",
+    'register',
+    'Prompter',
+    'AlpacaPrompter',
+    'ChatPrompter',
+    'LazyLLMDataprocBase',
+    'LazyLLMFinetuneBase',
+    'LazyLLMDeployBase',
+    'LazyLLMValidateBase',
+    'FastapiApp',
+    'AutoDeploy',
+    'AutoFinetune',
+    'ModelManager',
+    'LLMType',
+    'FormatterBase',
+    'EmptyFormatter',
+    'JsonFormatter',
+    'FileFormatter',
+    'StableDiffusionDeploy',
+    'TTSDeploy',
+    'BarkDeploy',
+    'ChatTTSDeploy',
+    'MusicGenDeploy',
+    'SenseVoiceDeploy',
+    'OCRDeploy',
 ]
