@@ -1,9 +1,13 @@
 import time
+from typing import Callable
+import random
+
 from ..core import ComponentBase
 import lazyllm
 from lazyllm import launchers, flows, LOG
 from ...components.utils.file_operate import _image_to_base64, _audio_to_base64, ocr_to_base64
-import random
+
+lazyllm.config.add('openai_api', bool, False, 'OPENAI_API')
 
 
 class LazyLLMDeployBase(ComponentBase):
@@ -38,6 +42,16 @@ Examples:
 
     @staticmethod
     def extract_result(output, inputs):
+        """Extract final result from model output. The default implementation returns raw output directly, subclasses can override this method to implement custom result extraction logic.
+
+Args:
+    output: Raw model output
+    inputs: Original input data, can be used for post-processing
+
+**Returns:**
+
+- Processed final result
+"""
         return output
 
     def __init__(self, *, launcher=launchers.remote()):  # noqa B008
@@ -53,18 +67,16 @@ simulating a simple pipeline-style deployable service with optional streaming su
 This class is primarily intended for internal testing and demonstration. It receives inputs in the format defined
 by `message_format`, and returns a dummy response or a streaming response depending on the `stream` flag.
 
-Attributes:
-- keys_name_handle (dict): Mapping of input keys for request formatting.
-- message_format (dict): Default request template including input and generation parameters.
+Args:
+    launcher: Deployment launcher instance, defaulting to `launchers.remote(sync=False)`.
+    stream (bool): Whether to simulate streaming output.
+    kw: Additional keyword arguments passed to the superclass.
 
-Parameters:
-- launcher: Deployment launcher instance, defaulting to `launchers.remote(sync=False)`.
-- stream (bool): Whether to simulate streaming output.
-- kw: Additional keyword arguments passed to the superclass.
+Call Arguments:
+    keys_name_handle (dict): Mapping of input keys for request formatting. 
+
+    message_format (dict): Default request template including input and generation parameters. 
 
-Methods:
-- __call__(*args): Starts the deployment and returns the service URL.
-- __repr__(): Returns a string representation of the underlying pipeline.
 """
     keys_name_handle = {'inputs': 'inputs'}
     message_format = {
@@ -101,21 +113,27 @@ Methods:
     def __repr__(self):
         return flows.Pipeline.__repr__(self)
 
-def verify_func_factory(error_message='ERROR:',
-                        running_message='Uvicorn running on'):
+def verify_func_factory(error_message: str, running_message: str,
+                        err_judge: Callable = lambda syb, msg: msg.lstrip().startswith(syb),
+                        run_judge: Callable = lambda syb, msg: syb in msg):
+    def _hit(symbols, msg, judge):
+        return judge(symbols, msg) if isinstance(symbols, str) else any([judge(s, msg) for s in symbols])
+
     def verify_func(job):
         while True:
             line = job.queue.get()
-            if line.startswith(error_message):
-                LOG.error(f"Capture error message: {line} \n\n")
+            if _hit(error_message, line, err_judge):
+                LOG.error(f'Capture error message: {line} \n\n')
                 return False
-            elif running_message in line:
-                LOG.info(f"Capture startup message: {line}")
+            elif _hit(running_message, line, run_judge):
+                LOG.info(f'Capture startup message: {line}')
                 break
             if job.status == lazyllm.launchers.status.Failed:
-                LOG.error("Service Startup Failed.")
+                LOG.error('Service Startup Failed.')
                 return False
         return True
     return verify_func
 
-verify_fastapi_func = verify_func_factory()
+verify_fastapi_func = verify_func_factory('ERROR:', 'Uvicorn running on')
+verify_ray_func = verify_func_factory(['ray.exceptions.RayTaskError', 'Traceback (most recent call last)'],
+                                      'Deployed app \'default\' successfully', err_judge=lambda syb, msg: syb in msg)
