@@ -10,32 +10,30 @@ class CollieFinetune(LazyLLMFinetuneBase):
     """This class is a subclass of ``LazyLLMFinetuneBase``, based on the LoRA fine-tuning capabilities provided by the [Collie](https://github.com/OpenLMLab/collie) framework, used for LoRA fine-tuning of large language models.
 
 Args:
-    base_model (str): The base model used for fine-tuning. It is required to be the path of the base model.
-    target_path (str): The path where the LoRA weights of the fine-tuned model are saved.
-    merge_path (str): The path where the model merges the LoRA weights, default to ``None``. If not specified, "lazyllm_lora" and "lazyllm_merge" directories will be created under ``target_path`` as ``target_path`` and ``merge_path`` respectively.
-    model_name (str): The name of the model, used as the prefix for setting the log name, default to "LLM".
-    cp_files (str): Specify configuration files to be copied from the base model path, which will be copied to ``merge_path``, default to "tokeniz*"
-    launcher (lazyllm.launcher): The launcher for fine-tuning, default to ``launchers.remote(ngpus=1)``.
-    kw: Keyword arguments, used to update the default training parameters. Note that additional keyword arguments cannot be arbitrarily specified.
-
-The keyword arguments and their default values for this class are as follows:
-
-Keyword Args: 
-    data_path (str): Data path, default to ``None``; generally passed as the only positional argument when this object is called.
-    batch_size (int): Batch size, default to ``64``.
-    micro_batch_size (int): Micro-batch size, default to ``4``.
-    num_epochs (int): Number of training epochs, default to ``2``.
-    learning_rate (float): Learning rate, default to ``5.e-4``.
-    dp_size (int): Data parallelism parameter, default to `` 8``.
-    pp_size (int): Pipeline parallelism parameter, default to ``1``.
-    tp_size (int): Tensor parallelism parameter, default to ``1``.
-    lora_r (int): LoRA rank, default to ``8``; this value determines the amount of parameters added, the smaller the value, the fewer the parameters.
-    lora_alpha (int): LoRA fusion factor, default to ``32``; this value determines the impact of LoRA parameters on the base model parameters, the larger the value, the greater the impact.
-    lora_dropout (float): LoRA dropout rate, default to ``0.05``, generally used to prevent overfitting.
-    lora_target_modules (str): LoRA target modules, default to ``[wo,wqkv]``, which is the default for InternLM2 model; this configuration item varies for different models.
-    modules_to_save (str): Modules for full fine-tuning, default to ``[tok_embeddings,output]``, which is the default for InternLM2 model; this configuration item varies for different models.
-    prompt_template_name (str): The name of the prompt template, default to ``alpaca``, i.e., use the prompt template provided by LazyLLM by default.
+    base_model (str): Path to the base model for fine-tuning.
+    target_path (str): Path to save LoRA weights of the fine-tuned model.
+    merge_path (Optional[str]): Path to save merged LoRA weights, default ``None``.
+        If not provided, "lazyllm_lora" and "lazyllm_merge" directories are created under ``target_path``.
+    model_name (Optional[str]): Model name used as log prefix, default "LLM".
+    cp_files (Optional[str]): Configuration files copied from base model path to ``merge_path``, default "tokeniz*".
+    launcher (lazyllm.launcher): Launcher for fine-tuning, default ``launchers.remote(ngpus=1)``.
+    kw (dict): Keyword arguments to update default training parameters:
 
+Keyword Args:
+    data_path (Optional[str]): Path to dataset, default ``None``.
+    batch_size (Optional[int]): Batch size, default 64.
+    micro_batch_size (Optional[int]): Micro-batch size, default 4.
+    num_epochs (Optional[int]): Number of training epochs, default 3.
+    learning_rate (Optional[float]): Learning rate, default 5.e-4.
+    dp_size (Optional[int]): Data parallelism parameter, default 8.
+    pp_size (Optional[int]): Pipeline parallelism parameter, default 1.
+    tp_size (Optional[int]): Tensor parallelism parameter, default 1.
+    lora_r (Optional[int]): LoRA rank, default 8.
+    lora_alpha (Optional[int]): LoRA fusion factor, default 16.
+    lora_dropout (Optional[float]): LoRA dropout rate, default 0.05.
+    lora_target_modules (Optional[str]): LoRA target modules, default ``[wo,wqkv]``.
+    modules_to_save (Optional[str]): Modules for full fine-tuning, default ``[tok_embeddings,output]``.
+    prompt_template_name (Optional[str]): Name of prompt template, default "alpaca".
 
 
 Examples:
@@ -75,7 +73,7 @@ Examples:
                  ):
         if not merge_path:
             save_path = os.path.join(lazyllm.config['train_target_root'], target_path)
-            target_path, merge_path = os.path.join(save_path, "lazyllm_lora"), os.path.join(save_path, "lazyllm_merge")
+            target_path, merge_path = os.path.join(save_path, 'lazyllm_lora'), os.path.join(save_path, 'lazyllm_merge')
             os.makedirs(target_path, exist_ok=True)
             os.makedirs(merge_path, exist_ok=True)
         super().__init__(
@@ -115,7 +113,7 @@ Examples:
                    f'--base={self.base_model} '
                    f'--adapter={self.target_path} '
                    f'--save_path={self.merge_path} ',
-                   f' cp {os.path.join(self.base_model,self.cp_files)} {self.merge_path} '
+                   f' cp {os.path.join(self.base_model, self.cp_files)} {self.merge_path} '
                 ]
 
         return cmd
