@@ -1,7 +1,10 @@
+import os
 import json
 import uuid
+import hashlib
 from typing import Callable, Optional, List, Union, Any
 
+import lazyllm
 from lazyllm.flow.flow import Pipeline
 
 from ...common import LazyLLMRegisterMetaClass, package, Finalizer
@@ -11,19 +14,18 @@ def _is_number(s: str):
         int(s)
         return True
     except ValueError:
-        if s == "None" or len(s) == 0:
+        if s == 'None' or len(s) == 0:
             return False
         else:
-            raise ValueError("Invalid number: " + s + ". You can enter an integer, None or an empyt string.")
+            raise ValueError('Invalid number: ' + s + '. You can enter an integer, None or an empyt string.')
 
 class LazyLLMFormatterBase(metaclass=LazyLLMRegisterMetaClass):
     """This class is the base class of the formatter. The formatter is the formatter of the model output result. Users can customize the formatter or use the formatter provided by LazyLLM.
-Main methods: _parse_formatter: parse the index content. _load: Parse the str object, and the part containing Python objects is parsed out, such as list, dict and other objects. _parse_py_data_by_formatter: format the python object according to the custom formatter and index. format: format the passed content. If the content is a string type, convert the string into a python object first, and then format it. If the content is a python object, format it directly.
 
 
 Examples:
-    >>> from lazyllm.components.formatter import FormatterBase
-    >>> class MyFormatter(FormatterBase):
+    >>> from lazyllm.components.formatter import LazyLLMFormatterBase
+    >>> class MyFormatter(LazyLLMFormatterBase):
     ...     def __init__(self, formatter: str = None):
     ...         self._formatter = formatter
     ...         if self._formatter:
@@ -62,9 +64,18 @@ Examples:
         return msg
 
     def _parse_py_data_by_formatter(self, py_data):
-        raise NotImplementedError("This data parse function is not implemented.")
+        raise NotImplementedError('This data parse function is not implemented.')
 
     def format(self, msg):
+        """Format input message.
+
+Args:
+    msg: Input message, can be string or other format
+
+**Returns:**
+
+- Formatted data, specific type determined by subclass implementation
+"""
         if isinstance(msg, str): msg = self._load(msg)
         return self._parse_py_data_by_formatter(msg)
 
@@ -86,6 +97,13 @@ Examples:
 
 
 class PipelineFormatter(LazyLLMFormatterBase):
+    """Pipeline formatter for encapsulating data processing pipelines as formatters.
+
+This class wraps Pipeline instances as formatters and supports combining multiple formatters through pipe operators.
+
+Args:
+    formatter (Pipeline): Pipeline instance to encapsulate
+"""
     def __init__(self, formatter: Pipeline):
         self._formatter = formatter
 
@@ -140,15 +158,15 @@ Examples:
         # Remove the surrounding brackets
         assert self._formatter.startswith('[') and self._formatter.endswith(']')
         slice_str = self._formatter.strip()[1:-1]
-        dimensions = slice_str.split("][")
+        dimensions = slice_str.split('][')
         slices = []
 
         for dim in dimensions:
             if '{' in dim:
                 slices.append(__class__._DictKeys(d.strip() for d in dim[1:-1].split(',') if d.strip()))
-            elif ":" in dim:
+            elif ':' in dim:
                 assert ',' not in dim, '[a, b:c] is not supported'
-                parts = dim.split(":")
+                parts = dim.split(':')
                 start = int(parts[0]) if _is_number(parts[0]) else None
                 end = int(parts[1]) if len(parts) > 1 and _is_number(parts[1]) else None
                 step = int(parts[2]) if len(parts) > 2 and _is_number(parts[2]) else None
@@ -362,8 +380,9 @@ Args:
     query (str): The user query string. Defaults to an empty string.
     files (str or List[str]): File path(s) associated with the query. Can be a single string or a list of strings.
 
-Returns:
-    str: A structured encoded query string or the raw query.
+**Returns:**
+
+- str: A structured encoded query string or the raw query.
 
 Raises:
     AssertionError: If `files` is not a string or list of strings.
@@ -379,8 +398,8 @@ Examples:
     query = query if query else ''
     if files:
         if isinstance(files, str): files = [files]
-        assert isinstance(files, list), "files must be a list."
-        assert all(isinstance(item, str) for item in files), "All items in files must be strings"
+        assert isinstance(files, list), 'files must be a list.'
+        assert all(isinstance(item, str) for item in files), 'All items in files must be strings'
         return LAZYLLM_QUERY_PREFIX + json.dumps({'query': query, 'files': files})
     else:
         return query
@@ -393,8 +412,9 @@ If the input string starts with the special prefix ``__lazyllm_docs__``, it atte
 Args:
     query_files (str): The encoded query string that may include both query and file paths.
 
-Returns:
-    Union[dict, str]: A dictionary containing 'query' and 'files' if structured, otherwise the original query string.
+**Returns:**
+
+- Union[dict, str]: A dictionary containing 'query' and 'files' if structured, otherwise the original query string.
 
 Raises:
     AssertionError: If the input is not a string.
@@ -412,14 +432,14 @@ Examples:
     >>> decode_query_with_filepaths("This is just a simple question")
     'This is just a simple question'
     """
-    assert isinstance(query_files, str), "query_files must be a str."
+    assert isinstance(query_files, str), 'query_files must be a str.'
     query_files = query_files.strip()
     if query_files.startswith(LAZYLLM_QUERY_PREFIX):
         try:
             obj = json.loads(query_files[len(LAZYLLM_QUERY_PREFIX):])
             return obj
         except json.JSONDecodeError as e:
-            raise ValueError(f"JSON parsing failed: {e}")
+            raise ValueError(f'JSON parsing failed: {e}')
     else:
         return query_files
 
@@ -431,8 +451,9 @@ Each argument can be a plain query string or a structured query created by ``enc
 Args:
     *args (str): Multiple query strings. Each can be either plain text or an encoded structured query with files.
 
-Returns:
-    str: A single structured query string containing the merged query and file paths.
+**Returns:**
+
+- str: A single structured query string containing the merged query and file paths.
 
 
 Examples:
@@ -451,7 +472,7 @@ Examples:
     if len(args) == 1:
         return args[0]
     for item in args:
-        assert isinstance(item, str), "Merge object must be str!"
+        assert isinstance(item, str), 'Merge object must be str!'
     querys = ''
     files = []
     for item in args:
@@ -481,6 +502,7 @@ class FileFormatter(LazyLLMFormatterBase):
     """A formatter that transforms query strings with document context between structured formats.
 
 Supports three modes:
+
 - "decode": Decodes structured query strings into dictionaries with `query` and `files`.
 - "encode": Encodes a dictionary with `query` and `files` into a structured query string.
 - "merge": Merges multiple structured query strings into one.
@@ -528,3 +550,100 @@ Examples:
                 return encode_query_with_filepaths(**py_data)
             else:
                 return py_data
+
+
+def file_content_hash(value):
+    res = decode_query_with_filepaths(value)
+    if isinstance(res, str):
+        return hashlib.md5(value.encode()).hexdigest()
+    query = res['query']
+    file_path_list = res['files']
+
+    hash_obj = hashlib.md5()
+    hash_obj.update(query.encode('utf-8'))
+
+    search_paths = [
+        '',
+        lazyllm.config['temp_dir'],
+    ]
+    for file_path in file_path_list:
+        if os.path.isabs(file_path):
+            full_path = file_path
+        else:
+            full_path = None
+            for base_path in search_paths:
+                candidate_path = os.path.join(base_path, file_path) if base_path else file_path
+                if os.path.exists(candidate_path) and os.path.isfile(candidate_path):
+                    full_path = candidate_path
+                    break
+            if full_path is None:
+                full_path = file_path
+        try:
+            with open(full_path, 'rb') as f:
+                while chunk := f.read(8192):
+                    hash_obj.update(chunk)
+        except (FileNotFoundError, IOError):
+            lazyllm.LOG.debug(f'Error: File not found or cannot be read: {full_path}')
+            hash_obj.update(full_path.encode('utf-8'))
+    return int(hash_obj.hexdigest(), 16)
+
+
+def proccess_path_recursively(value, process_func):
+    if isinstance(value, str):
+        if LAZYLLM_QUERY_PREFIX in value:
+            res = decode_query_with_filepaths(value)
+            if res['files']:
+                replace_path = []
+                for file_path in res['files']:
+                    replace_path.append(process_func(file_path))
+                res['files'] = replace_path
+            return encode_query_with_filepaths(res['query'], res['files'])
+        else:
+            return value
+    elif isinstance(value, (list, tuple)):
+        process_items = []
+        for item in value:
+            process_items.append(proccess_path_recursively(item, process_func))
+        if isinstance(value, tuple):
+            return tuple(process_items)
+        return process_items
+    elif isinstance(value, dict):
+        process_dict = {}
+        for key, val in value.items():
+            process_dict[key] = proccess_path_recursively(val, process_func)
+        return process_dict
+    elif isinstance(value, set):
+        process_set = set()
+        for item in value:
+            process_set.add(proccess_path_recursively(item, process_func))
+        return process_set
+    else:
+        return value
+
+def path_relative_to_absolute(path):
+    if os.path.isabs(path):
+        return path
+    absolute_path = os.path.join(lazyllm.config['temp_dir'], path)
+    if os.path.exists(absolute_path):
+        return os.path.abspath(absolute_path)
+    else:
+        return path
+
+def path_absolute_to_relative(path):
+    if not os.path.isabs(path):
+        return path
+    temp_dir_abs = os.path.abspath(lazyllm.config['temp_dir'])
+    if path.startswith(temp_dir_abs):
+        relative_path = path[len(temp_dir_abs):]
+        if relative_path.startswith(os.sep):
+            relative_path = relative_path[1:]
+        return relative_path
+    else:
+        return path
+
+def transform_path(value, mode='r2a'):
+    assert mode in ('r2a', 'a2r')
+    if mode == 'r2a':
+        return proccess_path_recursively(value, path_relative_to_absolute)
+    else:
+        return proccess_path_recursively(value, path_absolute_to_relative)
