@@ -98,7 +98,7 @@ Examples:
     def _extract_json_from_string(self, mixed_str: str):
         json_objects = []
         brace_level = 0
-        current_json = ""
+        current_json = ''
         in_string = False
 
         for char in mixed_str:
@@ -108,7 +108,7 @@ Examples:
             if not in_string:
                 if char in '{[':
                     if brace_level == 0:
-                        current_json = ""
+                        current_json = ''
                     brace_level += 1
                 elif char in '}]':
                     brace_level -= 1
@@ -120,7 +120,7 @@ Examples:
                 try:
                     json.loads(current_json)
                     json_objects.append(current_json)
-                    current_json = ""
+                    current_json = ''
                 except json.JSONDecodeError:
                     continue
 
@@ -128,15 +128,15 @@ Examples:
 
     def _load(self, msg: str):
         # Convert str to json format
-        assert msg.count("{") == msg.count("}"), f"{msg} is not a valid json string."
+        assert msg.count('{') == msg.count('}'), f'{msg} is not a valid json string.'
         try:
             json_strs = self._extract_json_from_string(msg)
             if len(json_strs) == 0:
-                raise TypeError(f"{msg} is not a valid json string.")
+                raise TypeError(f'{msg} is not a valid json string.')
             res = []
             for json_str in json_strs:
                 res.append(json.loads(json_str))
             return res if len(res) > 1 else res[0]
         except Exception as e:
-            lazyllm.LOG.info(f"Error: {e}")
-            return ""
+            lazyllm.LOG.info(f'Error: {e}')
+            return ''
