@@ -26,5 +26,5 @@ Examples:
         try:
             return yaml.load(msg, Loader=yaml.SafeLoader)
         except Exception as e:
-            lazyllm.LOG.info(f"Error: {e}")
-            return ""
+            lazyllm.LOG.info(f'Error: {e}')
+            return ''
