@@ -73,7 +73,7 @@ def add_doc(obj_name, docstr, module, append=''):
     for n in obj_name.split('.'):
         if isinstance(obj, type): obj = obj.__dict__[n]
         else: obj = getattr(obj, n)
-    if isinstance(obj, (classmethod, lazyllm.DynamicDescriptor)): obj = obj.__func__
+    if isinstance(obj, (classmethod, staticmethod, lazyllm.DynamicDescriptor)): obj = obj.__func__
     try:
         if append:
             if isinstance(docstr, str):
