@@ -28,7 +28,7 @@ import sys
 # Each session will have a separate engine
 class Engine(ABC):
     __default_engine__ = None
-    REPORT_URL = ""
+    REPORT_URL = ''
 
     class DefaultLockedDict(dict):
         def __init__(self, default_data, *args, **kwargs):
@@ -112,8 +112,8 @@ class Engine(ABC):
             key_db_connect_message = json.loads(key_db_connect_message)
 
         if not isinstance(key_db_connect_message, dict):
-            raise TypeError("The database connection information only supports dict and str, "
-                            f"not {type(key_db_connect_message)}.")
+            raise TypeError('The database connection information only supports dict and str, '
+                            f'not {type(key_db_connect_message)}.')
 
         self._key_db_connect_message = key_db_connect_message
 
@@ -136,23 +136,13 @@ class Engine(ABC):
 
     def subnodes(self, nodeid: str, recursive: bool = False):
         def _impl(nid, recursive):
+            if nid not in self._nodes:
+                return
             for id in self._nodes[nid].subitems:
                 yield id
                 if recursive: yield from self.subnodes(id, True)
         return list(_impl(nodeid, recursive))
 
-    @classmethod
-    @abstractmethod
-    def launch_localllm_train_service(self): pass
-
-    @classmethod
-    @abstractmethod
-    def launch_localllm_infer_service(self): pass
-
-    @classmethod
-    @abstractmethod
-    def get_infra_handle(self, token, mid) -> lazyllm.TrainableModule: pass
-
 
 class NodeConstructor(object):
     builder_methods = dict()
@@ -317,7 +307,7 @@ def make_code(code: str, vars_for_code: Optional[Dict[str, Any]] = None):
     def cls_method(self, *args, **kwargs):
         return ori_func(*args, **kwargs)
 
-    CodeBlock = type("CodeBlock", (lazyllm.ModuleBase,), {"forward": cls_method})
+    CodeBlock = type('CodeBlock', (lazyllm.ModuleBase,), {'forward': cls_method})
     code_block = CodeBlock()
     code_block.__doc__ = ori_func.__doc__
     code_block.__name__ = ori_func.__name__
@@ -326,17 +316,18 @@ def make_code(code: str, vars_for_code: Optional[Dict[str, Any]] = None):
 
 
 def _build_pipeline(nodes):
-    if isinstance(nodes, list) and len(nodes) > 1:
-        return pipeline([Engine().build_node(node).func for node in nodes])
-    elif isinstance(nodes, list) and len(nodes) == 0:
-        return lazyllm.Identity()
+    if not isinstance(nodes, list): nodes = [nodes]
+    if isinstance(nodes, list) and len(nodes) > 0:
+        return make_graph(nodes, enable_server=False)
     else:
-        return Engine().build_node(nodes[0] if isinstance(nodes, list) else nodes).func
-
+        return lazyllm.Identity()
 
 @NodeConstructor.register('Switch', subitems=['nodes:dict'])
-def make_switch(judge_on_full_input: bool, nodes: Dict[str, List[dict]]):
-    with switch(judge_on_full_input=judge_on_full_input) as sw:
+def make_switch(judge_on_full_input: bool, nodes: Dict[str, List[dict]], conversion: Optional[str] = None):
+    if conversion is not None:
+        conversion = make_code(conversion)
+
+    with switch(judge_on_full_input=judge_on_full_input, conversion=conversion) as sw:
         for cond, cond_nodes in nodes.items():
             sw.case[cond::_build_pipeline(cond_nodes)]
     return sw
@@ -394,11 +385,8 @@ def make_intention(base_model: str, nodes: Dict[str, List[dict]],
     with IntentClassifier(Engine().build_node(base_model).func,
                           prompt=prompt, constrain=constrain, attention=attention) as ic:
         for cond, sub_nodes in nodes.items():
-            if isinstance(sub_nodes, list) and len(sub_nodes) > 1:
-                f = pipeline([Engine().build_node(node).func for node in sub_nodes])
-            else:
-                f = Engine().build_node(sub_nodes[0] if isinstance(sub_nodes, list) else sub_nodes).func
-            ic.case[cond::f]
+            if not isinstance(sub_nodes, list): sub_nodes = [sub_nodes]
+            ic.case[cond::make_graph(sub_nodes, enable_server=False)]
     return ic
 
 
@@ -425,7 +413,7 @@ def make_document(dataset_path: str, _node_id: str, embed: Node = None, create_u
 
 
 @NodeConstructor.register('Retriever')
-def make_retriever(doc: str, group_name: str, similarity: str = 'cosine', similarity_cut_off: float = float("-inf"),
+def make_retriever(doc: str, group_name: str, similarity: str = 'cosine', similarity_cut_off: float = float('-inf'),
                    index: str = 'default', topk: int = 6, target: str = None, output_format: str = None,
                    join: bool = False):
     return lazyllm.tools.Retriever(Engine().build_node(doc).func, group_name=group_name, similarity=similarity,
@@ -491,7 +479,7 @@ def _get_tools(tools):
     callable_list = []
     for rid in tools:  # `tools` is a list of ids in engine's resources
         node = Engine().build_node(rid)
-        if type(node.func).__name__ == "CodeBlock":
+        if type(node.func).__name__ == 'CodeBlock':
             wrapper_func = return_a_wrapper_func(node.func._ori_func)
         else:
             wrapper_func = return_a_wrapper_func(node.func)
@@ -508,8 +496,8 @@ def make_mcp_tool(command_or_url: str, tool_name: str, args: Optional[List[str]]
                   headers: Dict[str, str] = None, timeout: float = 5):
     client = MCPClient(command_or_url, args or [], env, headers, timeout)
     tools = client.get_tools([tool_name])
-    assert len(tools) == 1, f"Current MCP client does not support tool '{tool_name}'. \
-        Please check if the tool name is correct."
+    assert len(tools) == 1, f'Current MCP client does not support tool "{tool_name}". \
+        Please check if the tool name is correct.'
     return tools[0]
 
 @NodeConstructor.register('FunctionCall', subitems=['tools'])
@@ -521,7 +509,7 @@ def make_fc(base_model: str, tools: List[str], algorithm: Optional[str] = None):
 
 
 class AuthenticationFailedError(Exception):
-    def __init__(self, message="Authentication failed for the given user and tool."):
+    def __init__(self, message='Authentication failed for the given user and tool.'):
         self._message = message
         super().__init__(self._message)
 
@@ -535,9 +523,9 @@ class TokenRefreshError(Exception):
 
 class AuthType(Enum):
     """An enumeration."""
-    SERVICE_API = "service_api"
-    OAUTH = "oauth"
-    OIDC = "oidc"
+    SERVICE_API = 'service_api'
+    OAUTH = 'oauth'
+    OIDC = 'oidc'
 
 class SharedHttpTool(lazyllm.tools.HttpTool):
     def __init__(self,
@@ -580,20 +568,20 @@ class SharedHttpTool(lazyllm.tools.HttpTool):
         if not self._token_type:
             return headers, params
         if self._token_type == AuthType.SERVICE_API.value:
-            if self._location == "header":
-                headers[self._param_name] = self._token if self._token.startswith("Bearer") \
-                    else "Bearer " + self._token
-            elif self._location == "query":
+            if self._location == 'header':
+                headers[self._param_name] = self._token if self._token.startswith('Bearer') \
+                    else 'Bearer ' + self._token
+            elif self._location == 'query':
                 params = params or {}
                 params[self._param_name] = self._token
             else:
-                raise TypeError("The Service API authentication type only supports ['header', 'query'], "
-                                f"not {self._location}.")
+                raise TypeError('The Service API authentication type only supports ["header", "query"], '
+                                f'not {self._location}.')
         elif self._token_type == AuthType.OAUTH.value:
-            headers['Authorization'] = f"Bearer {self._token}"
+            headers['Authorization'] = f'Bearer {self._token}'
         else:
-            raise TypeError("Currently, tool authentication only supports ['service_api', 'oauth'] types, "
-                            f"and does not support {self._token_type} type.")
+            raise TypeError('Currently, tool authentication only supports ["service_api", "oauth"] types, '
+                            f'and does not support {self._token_type} type.')
         return headers, params
 
     def valid_key(self):
@@ -601,20 +589,20 @@ class SharedHttpTool(lazyllm.tools.HttpTool):
             return True
         table_name = self._key_db_connect_message.get('tables_info_dict', {}).get('tables', [])[0]['name']
         SQL_SELECT = (
-            f"SELECT id, tool_api_id, endpoint_url, client_id, client_secret, user_id, location, param_name, token, "
-            f"refresh_token, token_type, expires_at FROM {table_name} "
-            f"WHERE tool_api_id = {self._tool_api_id} AND is_auth_success = True AND token_type = '{self._token_type}'"
+            f'SELECT id, tool_api_id, endpoint_url, client_id, client_secret, user_id, location, param_name, token, '
+            f'refresh_token, token_type, expires_at FROM {table_name} '
+            f'WHERE tool_api_id = {self._tool_api_id} AND is_auth_success = True AND token_type = "{self._token_type}"'
         )
         if self._share_key:
-            ret = self._fetch_valid_key(SQL_SELECT + " AND is_share = True")
+            ret = self._fetch_valid_key(SQL_SELECT + ' AND is_share = True')
             if not ret:
-                raise AuthenticationFailedError(f"Authentication failed for share_key=True and "
-                                                f"tool_api_id='{self._tool_api_id}'")
+                raise AuthenticationFailedError(f'Authentication failed for share_key=True and '
+                                                f'tool_api_id="{self._tool_api_id}"')
         else:
-            ret = self._fetch_valid_key(SQL_SELECT + f" AND user_id = '{self._user_id}'")
+            ret = self._fetch_valid_key(SQL_SELECT + f' AND user_id = "{self._user_id}"')
             if not ret:
-                raise AuthenticationFailedError(f"Authentication failed for user_id='{self._user_id}' and "
-                                                f"tool_api_id='{self._tool_api_id}'")
+                raise AuthenticationFailedError(f'Authentication failed for user_id="{self._user_id}" and '
+                                                f'tool_api_id="{self._tool_api_id}"')
 
         if self._token_type == AuthType.SERVICE_API.value:
             self._token = ret['token']
@@ -622,9 +610,9 @@ class SharedHttpTool(lazyllm.tools.HttpTool):
             self._param_name = ret['param_name']
         elif self._token_type == AuthType.OAUTH.value:
             try:
-                expires_at = datetime.strptime(ret['expires_at'], "%Y-%m-%d %H:%M:%S")
+                expires_at = datetime.strptime(ret['expires_at'], '%Y-%m-%d %H:%M:%S')
             except ValueError:
-                expires_at = datetime.strptime(ret['expires_at'], "%Y-%m-%d %H:%M:%S.%f")
+                expires_at = datetime.strptime(ret['expires_at'], '%Y-%m-%d %H:%M:%S.%f')
             self._token = self._validate_and_refresh_token(
                 id=ret['id'],
                 client_id=ret['client_id'],
@@ -635,10 +623,10 @@ class SharedHttpTool(lazyllm.tools.HttpTool):
                 expires_at=expires_at,
                 table_name=table_name)
         elif self._token_type == AuthType.OIDC.value:
-            raise TypeError("OIDC authentication is not currently supported.")
+            raise TypeError('OIDC authentication is not currently supported.')
         else:
-            raise TypeError("The authentication type only supports ['no authentication', 'service_api', "
-                            f"'oauth', 'oidc'], and does not support type {self._token_type}.")
+            raise TypeError('The authentication type only supports ["no authentication", "service_api", '
+                            f'"oauth", "oidc"], and does not support type {self._token_type}.')
 
     def _fetch_valid_key(self, query: str):
         ret = self._sql_manager.execute_query(query)
@@ -653,30 +641,30 @@ class SharedHttpTool(lazyllm.tools.HttpTool):
             if not refresh_token:
                 # Update only the expiration time
                 new_expires_at = now + timedelta(days=self._default_expired_days)
-                self._sql_manager.execute_commit(f"UPDATE {table_name} SET expires_at = "
-                                                 f"'{new_expires_at}' WHERE id = {id}")
+                self._sql_manager.execute_commit(f'UPDATE {table_name} SET expires_at = '
+                                                 f'"{new_expires_at}" WHERE id = {id}')
             return token
 
         # 2、Access token expired
         if not refresh_token:
-            raise TokenExpiredError("Access key has expired, and no refresh key was provided.")
+            raise TokenExpiredError('Access key has expired, and no refresh key was provided.')
 
         # 3、Request a new access token with the refresh_token
-        headers = {"Content-Type": "application/json", "Authorization": f"Bearer {client_secret}"}
-        data = {"client_id": client_id, "grant_type": "refresh_token", "refresh_token": refresh_token}
+        headers = {'Content-Type': 'application/json', 'Authorization': f'Bearer {client_secret}'}
+        data = {'client_id': client_id, 'grant_type': 'refresh_token', 'refresh_token': refresh_token}
         with requests.post(endpoint_url, json=data, headers=headers) as r:
             if r.status_code != 200:
-                raise TokenRefreshError(f"Request failed, status code: {r.status_code}, message: {r.text}")
+                raise TokenRefreshError(f'Request failed, status code: {r.status_code}, message: {r.text}')
 
             data = r.json()
-            new_token = data.get("access_token")
-            new_refresh_token = data.get("refresh_token")
-            new_expires_at = data.get("expires_in")
+            new_token = data.get('access_token')
+            new_refresh_token = data.get('refresh_token')
+            new_expires_at = data.get('expires_in')
 
             # update db
             self._sql_manager.execute_commit(
-                f"UPDATE {table_name} SET token = '{new_token}', refresh_token = '{new_refresh_token}', "
-                f"expires_at = '{datetime.fromtimestamp(new_expires_at)}' where id = {id}")
+                f'UPDATE {table_name} SET token = "{new_token}", refresh_token = "{new_refresh_token}", '
+                f'expires_at = "{datetime.fromtimestamp(new_expires_at)}" where id = {id}')
             return new_token
 
 @NodeConstructor.register('HttpTool')
@@ -749,7 +737,7 @@ def make_vqa(kw: dict):
 
 @NodeConstructor.register('LocalVQA')
 def make_local_vqa(base_model: str, file_resource_id: Optional[str] = None, prompt: Optional[str] = None,
-                   deploy_method: str = "auto", url: Optional[str] = None):
+                   deploy_method: str = 'auto', url: Optional[str] = None):
     model = lazyllm.TrainableModule(base_model)
     setup_deploy_method(model, deploy_method, url)
     return VQA(model, file_resource_id, prompt)
@@ -760,44 +748,21 @@ def make_online_vqa(source: str = None, base_model: Optional[str] = None, prompt
                     stream: bool = False, token: Optional[str] = None, base_url: Optional[str] = None,
                     history: Optional[List[List[str]]] = None):
     if source: source = source.lower()
-    if source == 'lazyllm':
-        return make_shared_llm(base_model, False, prompt, token, stream, history=history)
-    else:
-        return lazyllm.OnlineChatModule(base_model, source, base_url, stream,
-                                        api_key=api_key, secret_key=secret_key).prompt(prompt, history=history)
+    return lazyllm.OnlineChatModule(base_model, source, base_url, stream,
+                                    api_key=api_key, secret_key=secret_key).prompt(prompt, history=history)
 
 
-@NodeConstructor.register('SharedLLM')
-def make_shared_llm(llm: str, local: bool = True, prompt: Optional[str] = None, token: str = None,
-                    stream: Optional[bool] = None, file_resource_id: Optional[str] = None,
-                    history: Optional[List[List[str]]] = None):
-    if local:
-        llm = Engine().build_node(llm).func
-        if file_resource_id: assert isinstance(llm, VQA), 'file_resource_id is only supported in VQA'
-        r = (VQA(llm._vqa.share(prompt=prompt, history=history), file_resource_id)
-             if file_resource_id else llm.share(prompt=prompt, history=history))
-    else:
-        assert Engine().launch_localllm_infer_service.flag, 'Infer service should start first!'
-        r = Engine().get_infra_handle(token, llm)
-        if prompt: r.prompt(prompt, history=history)
-    if stream is not None: r.stream = stream
-    return r
-
 @NodeConstructor.register('SharedModel')
-def make_shared_model(llm: str, local: bool = True, prompt: Optional[str] = None, token: str = None,
+def make_shared_model(llm: str, prompt: Optional[str] = None,
                       stream: Optional[bool] = None, file_resource_id: Optional[str] = None,
-                      history: Optional[List[List[str]]] = None, cls: str = "llm"):
+                      history: Optional[List[List[str]]] = None, cls: str = 'llm'):
     if file_resource_id: assert cls == 'vqa', 'file_resource_id is only supported in VQA'
-    if local:
-        model = Engine().build_node(llm).func
-    else:
-        assert Engine().launch_localllm_infer_service.flag, 'Infer service should start first!'
-        model = Engine().get_infra_handle(token, llm)
+    model = Engine().build_node(llm).func
     if stream is not None: model.stream = stream
-    if cls == "vqa": return VQA(model, file_resource_id).share(prompt=prompt, history=history)
-    elif cls == "tts": return TTS(model)
-    elif cls == "stt": return STT(model)
-    elif cls == "sd": return SD(model)
+    if cls == 'vqa': return VQA(model, file_resource_id).share(prompt=prompt, history=history)
+    elif cls == 'tts': return TTS(model)
+    elif cls == 'stt': return STT(model)
+    elif cls == 'sd': return SD(model)
     else: return model.share(prompt=prompt, history=history)
 
 
@@ -807,11 +772,8 @@ def make_online_llm(source: str = None, base_model: Optional[str] = None, prompt
                     stream: bool = False, token: Optional[str] = None, base_url: Optional[str] = None,
                     history: Optional[List[List[str]]] = None, static_params: Optional[Dict[str, Any]] = None):
     if source: source = source.lower()
-    if source == 'lazyllm':
-        return make_shared_llm(base_model, False, prompt, token, stream, history=history)
-    else:
-        return lazyllm.OnlineChatModule(base_model, source, base_url, stream, api_key=api_key, secret_key=secret_key,
-                                        static_params=static_params or {}).prompt(prompt, history=history)
+    return lazyllm.OnlineChatModule(base_model, source, base_url, stream, api_key=api_key, secret_key=secret_key,
+                                    static_params=static_params or {}).prompt(prompt, history=history)
 
 
 class LLM(lazyllm.ModuleBase):
@@ -886,7 +848,7 @@ def make_stt(kw: dict):
     else: raise ValueError(f'Invalid type {type} given')
 
 @NodeConstructor.register('LocalSTT')
-def make_local_stt(base_model: str, deploy_method: str = "auto", url: Optional[str] = None):
+def make_local_stt(base_model: str, deploy_method: str = 'auto', url: Optional[str] = None):
     model = lazyllm.TrainableModule(base_model)
     setup_deploy_method(model, deploy_method, url)
     return STT(model)
@@ -911,10 +873,10 @@ class TTS(lazyllm.Module):
         result = self._m(query)
         if isinstance(result, str) and result.startswith(LAZYLLM_QUERY_PREFIX):
             decoded_result = decode_query_with_filepaths(result)
-            sound_list = decoded_result["files"]
+            sound_list = decoded_result['files']
             if self._target_dir and sound_list:
                 sound_list = move_files_to_target_dir(sound_list, self._target_dir)
-            result = encode_query_with_filepaths(query=decoded_result["query"], files=sound_list)
+            result = encode_query_with_filepaths(query=decoded_result['query'], files=sound_list)
         return result
 
     def share(self):
@@ -933,7 +895,7 @@ def make_tts(kw: dict):
     else: raise ValueError(f'Invalid type {type} given')
 
 @NodeConstructor.register('LocalTTS')
-def make_local_tts(base_model: str, deploy_method: str = "auto", url: Optional[str] = None):
+def make_local_tts(base_model: str, deploy_method: str = 'auto', url: Optional[str] = None):
     model = lazyllm.TrainableModule(base_model)
     setup_deploy_method(model, deploy_method, url)
     return model
@@ -955,7 +917,7 @@ def make_embedding(kw: dict):
     else: raise ValueError(f'Invalid type {type} given')
 
 @NodeConstructor.register('LocalEmbedding')
-def make_local_embedding(base_model: str, deploy_method: str = "auto", url: Optional[str] = None):
+def make_local_embedding(base_model: str, deploy_method: str = 'auto', url: Optional[str] = None):
     m = lazyllm.TrainableModule(base_model)
     return setup_deploy_method(m, deploy_method, url)
 
@@ -972,7 +934,7 @@ def make_constant(value: Any):
 
 
 @NodeConstructor.register('SqlCall')
-def make_sql_call(sql_manager: Node, base_model: str, sql_examples: str = "", use_llm_for_sql_result: bool = True,
+def make_sql_call(sql_manager: Node, base_model: str, sql_examples: str = '', use_llm_for_sql_result: bool = True,
                   return_trace: bool = True):
     llm = Engine().build_node(base_model).func
     sql_manager = Engine().build_node(sql_manager).func
@@ -981,7 +943,7 @@ def make_sql_call(sql_manager: Node, base_model: str, sql_examples: str = "", us
 
 @NodeConstructor.register('SqlManager')
 def make_sql_manager(db_type: str = None, user: str = None, password: str = None, host: str = None,
-                     port: str = None, db_name: str = None, options_str: str = "", tables_info_dict: dict = None):
+                     port: str = None, db_name: str = None, options_str: str = '', tables_info_dict: dict = None):
     return lazyllm.tools.SqlManager(db_type=db_type, user=user, password=password, host=host, port=port,
                                     db_name=db_name, options_str=options_str, tables_info_dict=tables_info_dict)
 
@@ -1001,10 +963,10 @@ class SD(lazyllm.Module):
         result = self._m(prompt)
         if isinstance(result, str) and result.startswith(LAZYLLM_QUERY_PREFIX):
             decoded_result = decode_query_with_filepaths(result)
-            image_list = decoded_result["files"]
+            image_list = decoded_result['files']
             if self._target_dir and image_list:
                 image_list = move_files_to_target_dir(image_list, self._target_dir)
-            result = encode_query_with_filepaths(query=decoded_result["query"], files=image_list)
+            result = encode_query_with_filepaths(query=decoded_result['query'], files=image_list)
         return result
 
     def share(self):
@@ -1019,7 +981,7 @@ def make_sd(kw: dict):
     else: raise ValueError(f'Invalid type {type} given')
 
 @NodeConstructor.register('LocalSD')
-def make_local_sd(base_model: str, deploy_method: str = "auto", url: Optional[str] = None):
+def make_local_sd(base_model: str, deploy_method: str = 'auto', url: Optional[str] = None):
     model = lazyllm.TrainableModule(base_model)
     setup_deploy_method(model, deploy_method, url)
     return model
@@ -1045,7 +1007,7 @@ class FileResource(object):
 def make_file(id: str):
     return FileResource(id)
 
-@NodeConstructor.register("Reader")
+@NodeConstructor.register('Reader')
 def make_simple_reader(file_resource_id: Optional[str] = None):
     if file_resource_id:
         def merge_input(input, extra_file: Union[str, List[str]]):
@@ -1067,31 +1029,31 @@ def make_simple_reader(file_resource_id: Optional[str] = None):
         return lazyllm.tools.rag.FileReader()
 
 
-@NodeConstructor.register("OCR")
-def make_ocr(base_model: Optional[str] = "PP-OCRv5_mobile", deploy_method: str = "auto", url: Optional[str] = None):
+@NodeConstructor.register('OCR')
+def make_ocr(base_model: Optional[str] = 'PP-OCRv5_mobile', deploy_method: str = 'auto', url: Optional[str] = None):
     if base_model is None:
-        base_model = "PP-OCRv5_mobile"
-    assert base_model in ["PP-OCRv5_server", "PP-OCRv5_mobile", "PP-OCRv4_server", "PP-OCRv4_mobile"]
+        base_model = 'PP-OCRv5_mobile'
+    assert base_model in ['PP-OCRv5_server', 'PP-OCRv5_mobile', 'PP-OCRv4_server', 'PP-OCRv4_mobile']
     model = lazyllm.TrainableModule(base_model)
     setup_deploy_method(model, deploy_method, url)
     return model
 
 
-@NodeConstructor.register("ParameterExtractor")
+@NodeConstructor.register('ParameterExtractor')
 def make_parameter_extractor(base_model: str, param: list[str], type: list[str],
                              description: list[str], require: list[bool]):
     base_model = Engine().build_node(base_model).func
     return lazyllm.tools.ParameterExtractor(base_model, param, type, description, require)
 
 
-@NodeConstructor.register("QustionRewrite")
-def make_qustion_rewrite(base_model: str, rewrite_prompt: str = "", formatter: str = "str"):
+@NodeConstructor.register('QustionRewrite')
+def make_qustion_rewrite(base_model: str, rewrite_prompt: str = '', formatter: str = 'str'):
     base_model = Engine().build_node(base_model).func
     return lazyllm.tools.QustionRewrite(base_model, rewrite_prompt, formatter)
 
 
-@NodeConstructor.register("CodeGenerator")
-def make_code_generator(base_model: str, prompt: str = ""):
+@NodeConstructor.register('CodeGenerator')
+def make_code_generator(base_model: str, prompt: str = ''):
     base_model = Engine().build_node(base_model).func
     return lazyllm.tools.CodeGenerator(base_model, prompt)
 
@@ -1104,7 +1066,7 @@ def setup_deploy_method(model: lazyllm.TrainableModule, deploy_method: str, url:
         url: Optional deployment URL
     """
     deploy_method = getattr(lazyllm.deploy, deploy_method)
-    if deploy_method is lazyllm.deploy.AutoDeploy:
+    if not url or url == '':
         model.deploy_method(deploy_method)
     else:
         model.deploy_method(deploy_method, url=url)
