@@ -51,14 +51,19 @@ def _is_function(f):
                           types.BuiltinMethodType, types.MethodType, types.LambdaType))
 
 class FlowBase(metaclass=_MetaBind):
-    """A base class for creating flow-like structures that can contain various items.
+    """Base class for constructing flow-like structures that can hold multiple items and organize them hierarchically.
 
-This class provides a way to organize items, which can be instances of ``FlowBase`` or other types, into a hierarchical structure. Each item can have a name and the structure can be traversed or modified dynamically.
+This class allows combining different objects (including ``FlowBase`` instances or other types)
+into a structured flow, with optional names for each item, enabling both name-based and index-based access.
+Items in the structure can be added or traversed dynamically.
 
 Args:
-    items (iterable): An iterable of items to be included in the flow. These can be instances of ``FlowBase`` or other objects.
-    item_names (list of str, optional): A list of names corresponding to the items. This allows items to be accessed by name. If not provided, items can only be accessed by index.
-    auto_capture: If True, variables newly defined within the ``with`` block will be automatically added to the flow. Defaults to ``False``.
+    *items: Items to be included in the flow, which can be instances of ``FlowBase`` or other objects.
+    item_names (list of str, optional): A list of names corresponding to the items, paired with ``items`` in order.
+        If not provided, all items will be assigned ``None`` as their name.
+    auto_capture (bool, optional): Whether to enable automatic variable capture. If ``True``, when used
+        as a context manager, newly defined variables in the current scope will be automatically added to the flow.
+        Defaults to ``False``.
 """
     def __init__(self, *items, item_names=None, auto_capture=False) -> None:
         self._father = None
@@ -242,11 +247,12 @@ input --> [Flow module1 -> Flow module2 -> ... -> Flow moduleN] --> output
                    ↑             ↓
                pre_hook       post_hook
 ```
+
 Args:
     args: A sequence of callables representing the flow modules.
     post_action: An optional callable applied to the output after main flow execution. Defaults to ``None``。
     auto_capture: If True, variables newly defined within the ``with`` block will be automatically added to the flow. Defaults to ``False``.
-
+    **kw: Key-value pairs for named components.
 """
     def __init__(self, *args, post_action=None, auto_capture=False, **kw):
         assert len(args) == 0 or len(kw) == 0, f'Cannot provide args `{args}` and kwargs `{kw}` at the same time'
@@ -315,7 +321,7 @@ Args:
 Args:
     sync (bool): Whether to execute synchronously. Default is True.
 
-**Returns**
+**Returns:**
 
 - LazyLLMFlowsBase: The current instance.
 """
@@ -331,7 +337,7 @@ Args:
     def wait(self):
         """Wait for all asynchronous tasks in the flow to complete.
 
-**Returns**
+**Returns:**
 
 - LazyLLMFlowsBase: The current instance.
 """
@@ -381,7 +387,7 @@ Args:
     *args: Positional arguments.
     **kw: Keyword arguments.
 
-**Returns**
+**Returns:**
 
 - bind: The bound bind object.
 """
@@ -460,8 +466,9 @@ Args:
     module: The module to get output from. Can be a module object or module name.
     unpack (bool): Whether to unpack the output result. Defaults to False.
 
-Returns:
-    bind.Args: A bound argument object for data passing in the pipeline.
+**Returns:**
+
+- bind.Args: A bound argument object for data passing in the pipeline.
 """
         return bind.Args(self.id(), self.id(module), unpack=unpack)
 
@@ -577,11 +584,11 @@ Args:
 
 Tag ``Parallel`` so that the return value of each call to ``Parallel`` is changed from a tuple to a dict. When using ``asdict``, make sure that the elements of ``parallel`` are named, for example: ``parallel(name=value)``.
 
-`tuple property`
+`astuple property`
 
 Mark Parallel so that the return value of Parallel changes from package to tuple each time it is called.
 
-`list property`
+`aslist property`
 
 Mark Parallel so that the return value of Parallel changes from package to list each time it is called.
 
@@ -736,13 +743,13 @@ Args:
                     error_msgs = []
                     for future in not_done:
                         if (exc := future.exception()) is not None:
-                            if (tb := getattr(future, "_traceback", None)):
+                            if (tb := getattr(future, '_traceback', None)):
                                 tb_str = ''.join(traceback.format_exception(type(exc), exc, tb))
                             else:
                                 tb_str = ''.join(traceback.format_exception(type(exc), exc, exc.__traceback__))
-                            error_msgs.append(f"Future: {future}\n{tb_str}")
+                            error_msgs.append(f'Future: {future}\n{tb_str}')
                         else:
-                            error_msgs.append(f"Future: {future} not complete without exception。")
+                            error_msgs.append(f'Future: {future} not complete without exception。')
                     raise RuntimeError('Parallel execute failed!\n' + '\n'.join(error_msgs))
                 return package([future.result() for future in futures])
         else:
@@ -786,7 +793,6 @@ Args:
     kwargs : Arbitrary keyword arguments representing additional modules, where the key is the name of the module.
 
 
-
 Examples:
     >>> import lazyllm
     >>> div = lazyllm.diverter(lambda x: x+1, lambda x: x*2, lambda x: -x)
@@ -946,7 +952,9 @@ Examples:
             assert isinstance(__input, tuple) and len(__input) >= 2
             exp = __input[0]
             __input = __input[1] if len(__input) == 2 else __input[1:]
-        if self._conversion: exp = self._conversion(exp)
+
+        if self._conversion:
+            exp = self._conversion(*exp) if isinstance(exp, package) else self._conversion(exp)
 
         for idx, cond in enumerate(self.conds):
             if (callable(cond) and self.invoke(cond, exp) is True) or (exp == cond) or (
@@ -1027,18 +1035,18 @@ Examples:
 class Loop(Pipeline):
     """Initializes a Loop flow structure which repeatedly applies a sequence of functions to an input until a stop condition is met or a specified count of iterations is reached.
 
-The Loop structure allows for the definition of a simple control flow where a series of steps are applied in a loop, with an optional stop condition that can be used to exit the loop based on the output of the steps.
+The Loop structure allows for the definition of a simple control flow where a series of steps are applied in a loop, with an optional stop condition that can be used to exit the loop early based on the output of the steps.
 
 Args:
     *item (callable or list of callables): The function(s) or callable object(s) that will be applied in the loop.
     stop_condition (callable, optional): A function that takes the output of the last item in the loop as input and returns a boolean. If it returns ``True``, the loop will stop. If ``None``, the loop will continue until ``count`` is reached. Defaults to ``None``.
-    count (int, optional): The maximum number of iterations to run the loop for. If ``None``, the loop will continue indefinitely or until ``stop_condition`` returns ``True``. Defaults to ``None``.
+    count (int, optional): The maximum number of iterations to run the loop for. Defaults to ``sys.maxsize``.
     post_action (callable, optional): A function to be called with the final output after the loop ends. Defaults to ``None``.
     auto_capture (bool, optional): If True, variables newly defined within the ``with`` block will be automatically added to the flow. Defaults to ``False``.
-    judge_on_full_input(bool): If set to ``True``, the conditional judgment will be performed through the input of ``stop_condition``, otherwise the input will be split into two parts: the judgment condition and the actual input, and only the judgment condition will be judged.
+    judge_on_full_input (bool): If set to ``True``, the conditional judgment will be performed through the input of ``stop_condition``; otherwise, the input will be split into two parts: the judgment condition and the actual input, and only the judgment condition will be judged.
 
 Raises:
-    AssertionError: If both ``stop_condition`` and ``count`` are provided or if ``count`` is not an integer when provided.
+    AssertionError: If the provided ``stop_condition`` is neither callable nor ``None``.
 
 
 Examples:
@@ -1238,8 +1246,7 @@ This method uses Kahn's algorithm to perform topological sorting on the directed
 
 - List[Node]: List of nodes arranged in topological order.
 
-**Raises:**
-
+Raises:
 - ValueError: If there are circular dependencies in the graph.
 
 
@@ -1277,10 +1284,26 @@ Examples:
                     queue.append(output_node)
 
         if len(sorted_nodes) != len(self._nodes):
-            raise ValueError("Graph has a cycle")
+            raise ValueError('Graph has a cycle')
 
         return [n for n in sorted_nodes if (self._in_degree[n] > 0 or self._out_degree[n] > 0)]
 
+    def _get_input(self, name, node, intermediate_results, futures):
+        if name.startswith('_lazyllm_constant_'):
+            return self._constants[int(name.removeprefix('_lazyllm_constant_'))]
+        if name not in intermediate_results['values']:
+            r = futures[name].result()
+            with intermediate_results['lock']:
+                if name not in intermediate_results['values']:
+                    intermediate_results['values'][name] = r
+        r = intermediate_results['values'][name]
+        if isinstance(r, Exception): raise r
+        if node.inputs[name]:
+            if isinstance(r, arguments) and not ((len(r.args) == 0) ^ (len(r.kw) == 0)):
+                raise RuntimeError('Only one of args and kwargs can be given with formatter.')
+            r = node.inputs[name]((r.args or r.kw) if isinstance(r, arguments) else r)
+        return r
+
     def compute_node(self, sid, node, intermediate_results, futures):
         """Compute the output result of a single node.
 
@@ -1312,28 +1335,13 @@ Examples:
     """
         globals._init_sid(sid)
 
-        def get_input(name):
-            if name.startswith('_lazyllm_constant_'):
-                return self._constants[int(name.removeprefix('_lazyllm_constant_'))]
-            if name not in intermediate_results['values']:
-                r = futures[name].result()
-                with intermediate_results['lock']:
-                    if name not in intermediate_results['values']:
-                        intermediate_results['values'][name] = r
-            r = intermediate_results['values'][name]
-            if isinstance(r, Exception): raise r
-            if node.inputs[name]:
-                if isinstance(r, arguments) and not ((len(r.args) == 0) ^ (len(r.kw) == 0)):
-                    raise RuntimeError('Only one of args and kwargs can be given with formatter.')
-                r = node.inputs[name]((r.args or r.kw) if isinstance(r, arguments) else r)
-            return r
-
         kw = {}
         if len(node.inputs) == 1:
-            input = get_input(list(node.inputs.keys())[0])
+            input = self._get_input(list(node.inputs.keys())[0], node, intermediate_results, futures)
         else:
             # TODO(wangzhihong): add complex rules: mixture of package / support kwargs / ...
-            inputs = package(get_input(input) for input in node.inputs.keys())
+            inputs = package(self._get_input(input, node, intermediate_results, futures)
+                             for input in node.inputs.keys())
             input = arguments()
             for inp in inputs:
                 input.append(inp)
@@ -1343,6 +1351,7 @@ Examples:
             input = input.args
 
         if node.arg_names:
+            if not isinstance(input, (list, tuple, package)): input = [input]
             kw.update({name: value for name, value in zip(node.arg_names, input)})
             input = package()
 
