@@ -12,11 +12,11 @@ __all__ = [
     'ActionModule',
     'ServerModule',
     'TrialModule',
-    "OnlineChatModule",
-    "OnlineChatModuleBase",
-    "OnlineEmbeddingModule",
-    "OnlineEmbeddingModuleBase",
-    "OnlineMultiModalModule",
-    "OnlineMultiModalBase",
-    "AutoModel",
+    'OnlineChatModule',
+    'OnlineChatModuleBase',
+    'OnlineEmbeddingModule',
+    'OnlineEmbeddingModuleBase',
+    'OnlineMultiModalModule',
+    'OnlineMultiModalBase',
+    'AutoModel',
 ]
