@@ -7,19 +7,33 @@ import copy
 import uuid
 import re
 import requests
+import yaml
+from deepdiff import DeepDiff
 
 import lazyllm
-from lazyllm import globals, LOG, launchers, Option, package, LazyLLMDeployBase, LazyLLMFinetuneBase
+from lazyllm import globals, LOG, launchers, Option, package, LazyLLMDeployBase, LazyLLMFinetuneBase, config
 from ...components.formatter import decode_query_with_filepaths, encode_query_with_filepaths
 from ...components.formatter.formatterbase import LAZYLLM_QUERY_PREFIX
-from ...components.utils import ModelManager
+from ...components.utils import ModelManager, LLMType
 from ...components.utils.file_operate import _base64_to_file, _is_base64_with_mime
 from ...launcher import LazyLLMLaunchersBase as Launcher
-from .utils import map_kw_for_framework, encode_files
+from .utils import map_kw_for_framework, encode_files, check_config_map_format
 from ...flow import Pipeline
 from ..servermodule import ModuleBase, _UrlHelper, UrlModule
 from ..utils import light_reduce
 
+lazyllm.config.add('trainable_module_config_map_path', str, '', 'TRAINABLE_MODULE_CONFIG_MAP_PATH')
+ignore_config_keys = ['log_path', 'launcher']
+
+@functools.lru_cache(maxsize=1)
+def get_trainable_module_config_map(path):
+    try:
+        cfg = yaml.safe_load(open(path, 'r')) if os.path.exists(path) else {}
+        check_config_map_format(cfg)
+    except Exception:
+        LOG.warning(f'Failed to load trainable module config map from {path}')
+        cfg = {}
+    return cfg
 
 class _UrlTemplateStruct(object):
     def __init__(self, template_message=None, keys_name_handle=None, template_headers=None, stop_words=None,
@@ -49,6 +63,10 @@ class _UrlTemplateStruct(object):
         self.stream_url_suffix = stream_url_suffix or ''
 
 
+lazyllm.config.add('trainable_magic_mock', bool, False, 'TRAINABLE_MAGIC_MOCK')  # used for unit test
+fake_url = 'dummy.url/generate'
+
+
 @light_reduce
 class _TrainableModuleImpl(ModuleBase, _UrlHelper):
     builder_keys = ['trainset', 'train_method', 'finetune_method', 'deploy_method', 'mode']
@@ -56,11 +74,12 @@ class _TrainableModuleImpl(ModuleBase, _UrlHelper):
     def __init__(self, base_model: str = '', target_path: str = '', stream: bool = False, train: Optional[type] = None,
                  finetune: Optional[LazyLLMFinetuneBase] = None, deploy: Optional[LazyLLMDeployBase] = None,
                  template: Optional[_UrlTemplateStruct] = None, url_wrapper: Optional[_UrlHelper._Wrapper] = None,
-                 trust_remote_code: bool = True):
+                 trust_remote_code: bool = True, type: Optional[LLMType] = None):
         super().__init__()
         # TODO(wangzhihong): Update ModelDownloader to support async download, and move it to deploy.
         #                    Then support Option for base_model
         base_model = base_model.rstrip('/\\')
+        self._type = LLMType(type) if type else type
         self._base_model = (ModelManager(lazyllm.config['model_source']).download(base_model) or ''
                             if trust_remote_code else base_model)
         if not self._base_model:
@@ -87,7 +106,7 @@ class _TrainableModuleImpl(ModuleBase, _UrlHelper):
         if not args.get('url'):
             if arg_cls == 'deploy' and self._deploy is lazyllm.deploy.AutoDeploy:
                 self._deploy, args['launcher'], self._deploy_args = lazyllm.deploy.AutoDeploy.get_deployer(
-                    base_model=self._base_model, **args)
+                    base_model=self._base_model, type=self._type, **args)
             args['launcher'] = args['launcher'].clone() if args.get('launcher') else launchers.remote(sync=False)
             self._launchers['default'][arg_cls] = args['launcher']
         return args
@@ -116,7 +135,7 @@ class _TrainableModuleImpl(ModuleBase, _UrlHelper):
     def _async_finetune(self, name: str, ngpus: int = 1, **kw):
         assert name and isinstance(name, str), 'Invalid name: {name}, expect a valid string'
         assert name not in self._launchers['manual'], 'Duplicate name: {name}'
-        self._launchers['manual'][name] = kw['launcher'] = launchers.remote(sync=False, ngpus=ngpus)
+        self._launchers['manual'][name] = kw['launcher'] = launchers.remote(sync=False, ngpus=ngpus, launch_type='train')
         self._set_file_name(name)
 
         def after_train(real_target_path):
@@ -152,8 +171,11 @@ class _TrainableModuleImpl(ModuleBase, _UrlHelper):
     @lazyllm.once_wrapper
     def _get_deploy_tasks(self):
         if self._deploy is None: return None
+        if lazyllm.config['trainable_magic_mock']:
+            return Pipeline(lambda *args, **kwargs: fake_url, self._set_url)
         if self._deploy is lazyllm.deploy.AutoDeploy:
             raise RuntimeError('No appropriate inference framework was selected, specify it with `.deploy_method()`.')
+
         kwargs = {'stream': self._stream} if self._deploy is lazyllm.deploy.dummy else {}
         self._deployer = self._deploy(**kwargs, **self._deploy_args)
 
@@ -177,6 +199,23 @@ class _TrainableModuleImpl(ModuleBase, _UrlHelper):
         if hasattr(self._deploy, 'auto_map') and self._deploy.auto_map:
             self._deploy_args = map_kw_for_framework(self._deploy_args, self._deploy.auto_map)
 
+        trainable_module_config_map = get_trainable_module_config_map(lazyllm.config['trainable_module_config_map_path'])
+
+        base_model_name = os.path.basename(self._base_model)
+        if base_model_name in trainable_module_config_map:
+            deploy_args_for_check = {k: v for k, v in self._deploy_args.items() if k not in ignore_config_keys}
+            for module_config in trainable_module_config_map[base_model_name]:
+                if (self._deploy.__name__.lower() == module_config.get('framework').lower()
+                    and ((not deploy_args_for_check and not module_config.get('strict'))
+                         or not DeepDiff(module_config.get('deploy_config', {}), deploy_args_for_check))):
+                    try:
+                        url = module_config.get('url')
+                        requests.get(url, timeout=3)
+                        self._deploy_args = {'url': url}
+                        break
+                    except Exception:
+                        continue
+
         stop_words = ModelManager.get_model_prompt_keys(self._base_model).get('stop_words')
 
         self._template.update(self._deploy.message_format, self._deploy.keys_name_handle,
@@ -186,7 +225,7 @@ class _TrainableModuleImpl(ModuleBase, _UrlHelper):
 
         if url := self._deploy_args.get('url'):
             assert len(self._deploy_args) == 1, 'Cannot provide other arguments together with url'
-            self._set_url(url)
+            self._set_url(re.sub(r'v1(?:/chat/completions)?/?$', 'v1/', url))
             self._get_deploy_tasks.flag.set()
         self._deploy_args.pop('url', None)
 
@@ -207,14 +246,17 @@ class _TrainableModuleImpl(ModuleBase, _UrlHelper):
         train_set_name = optimize_name(train_set_name)
 
         target_path = os.path.join(self._target_path, base_model_name,
-                                   f"{file_name}{self._delimiter}{train_set_name}{self._delimiter}"
-                                   f"{datetime.now().strftime('%y%m%d%H%M%S%f')[:14]}")
+                                   f'{file_name}{self._delimiter}{train_set_name}{self._delimiter}'
+                                   f'{datetime.now().strftime("%y%m%d%H%M%S%f")[:14]}')
         return target_path
 
     def _set_file_name(self, name):
         self._file_name = name
 
 
+config.add('cache_local_module', bool, False, 'CACHE_LOCAL_MODULE')
+
+
 class TrainableModule(UrlModule):
     """Trainable module, all models (including LLM, Embedding, etc.) are served through TrainableModule
 
@@ -379,13 +421,16 @@ m(1)
     builder_keys = _TrainableModuleImpl.builder_keys
 
     def __init__(self, base_model: Option = '', target_path='', *, stream: Union[bool, Dict[str, str]] = False,
-                 return_trace: bool = False, trust_remote_code: bool = True):
+                 return_trace: bool = False, trust_remote_code: bool = True, type: Optional[Union[str, LLMType]] = None):
         super().__init__(url=None, stream=stream, return_trace=return_trace, init_prompt=False)
         self._template = _UrlTemplateStruct()
         self._impl = _TrainableModuleImpl(base_model, target_path, stream, None, lazyllm.finetune.auto,
-                                          lazyllm.deploy.auto, self._template, self._url_wrapper, trust_remote_code)
+                                          lazyllm.deploy.auto, self._template, self._url_wrapper,
+                                          trust_remote_code, type)
         self._stream = stream
         self.prompt()
+        if config['cache_local_module']:
+            self.use_cache()
 
     template_message = property(lambda self: self._template.template_message)
     keys_name_handle = property(lambda self: self._template.keys_name_handle)
@@ -405,6 +450,7 @@ m(1)
 
     @property
     def type(self):
+        if self._impl._type is not None: return self._impl._type.value
         return ModelManager.get_model_type(self.base_model).upper()
 
     def get_all_models(self):
@@ -412,7 +458,8 @@ m(1)
 
 Returns a list of all fine-tuned model paths under the current target path.
 
-Returns:
+**Returns:**
+
 - List[str]: A list of fine-tuned model identifiers or directories.
 """
         return self._impl._get_all_finetuned_models()
@@ -423,7 +470,7 @@ Returns:
 Sets the model to be used from a specific fine-tuned model path.
 
 Args:
-- model_path (str): The path to the fine-tuned model to use.
+    model_path (str): The path to the fine-tuned model to use.
 """
         return self._impl._set_specific_finetuned_model(model_path)
 
@@ -451,6 +498,7 @@ Examples:
 
     def stop(self, task_name: Optional[str] = None):
         """Pause a specific task of the model.
+
 Args:
     task_name (str): The name of the task to pause. Defaults to None (pauses the 'deploy' task by default).
 
@@ -474,17 +522,33 @@ Examples:
 Returns the current status of a specific task in the module.
 
 Args:
-- task_name (Optional[str]): Name of the task (e.g., 'deploy'). Defaults to 'deploy' if not provided.
+    task_name (Optional[str]): Name of the task (e.g., 'deploy'). Defaults to 'deploy' if not provided.
+
+**Returns:**
 
-Returns:
 - str: Status string such as 'running', 'finished', or 'stopped'.
 """
         launcher = self._impl._launchers['manual' if task_name else 'default'][task_name or 'deploy']
         return launcher.status
 
+    def log_path(self, task_name: Optional[str] = None):
+        """Get task log path.
+
+Get corresponding log file path based on task name, supports default deployment tasks and manually specified tasks.
+
+Args:
+    task_name (Optional[str]): Task name, defaults to None (get default deployment task log)
+
+Returns:
+    str: Log file path
+"""
+        launcher = self._impl._launchers['manual' if task_name else 'default'][task_name or 'deploy']
+        return launcher.log_path
+
     # modify default value to ''
     def prompt(self, prompt: Union[str, dict] = '', history: Optional[List[List[str]]] = None):
         """Processes the input prompt and generates a format compatible with the model.
+
 Args:
     prompt (str): The input prompt. Defaults to an empty string.
     history (List): Conversation history.
@@ -496,17 +560,17 @@ Examples:
     ...    def forward(self, prompt, history):
     ...        self.prompt(prompt,history)
     """
-        if self.base_model != '' and prompt == '' and ModelManager.get_model_type(self.base_model) != 'llm':
+        if self.base_model != '' and prompt == '' and self.type != 'LLM':
             prompt = None
         clear_system = isinstance(prompt, dict) and prompt.get('drop_builtin_system')
         prompter = super(__class__, self).prompt(prompt, history)._prompt
-        self._tools = getattr(prompter, "_tools", None)
+        self._tools = getattr(prompter, '_tools', None)
         keys = ModelManager.get_model_prompt_keys(self.base_model).copy()
         if keys:
             if clear_system: keys['system'] = ''
             prompter._set_model_configs(**keys)
-            for key in ["tool_start_token", "tool_args_token", "tool_end_token"]:
-                if key in keys: setattr(self, f"_{key}", keys[key])
+            for key in ['tool_start_token', 'tool_args_token', 'tool_end_token']:
+                if key in keys: setattr(self, f'_{key}', keys[key])
         return self
 
     def _loads_str(self, text: str) -> Union[str, Dict]:
@@ -514,29 +578,29 @@ Examples:
             ret = json.loads(text)
             return self._loads_str(ret) if isinstance(ret, str) else ret
         except Exception:
-            LOG.error(f"{text} is not a valid json string.")
+            LOG.error(f'{text} is not a valid json string.')
             return text
 
     def _parse_arguments_with_args_token(self, output: str) -> tuple[str, dict]:
         items = output.split(self._tool_args_token)
         func_name = items[0].strip()
         if len(items) == 1:
-            return func_name.split(self._tool_end_token)[0].strip() if getattr(self, "_tool_end_token", None)\
+            return func_name.split(self._tool_end_token)[0].strip() if getattr(self, '_tool_end_token', None)\
                 else func_name, {}
-        args = (items[1].split(self._tool_end_token)[0].strip() if getattr(self, "_tool_end_token", None)
+        args = (items[1].split(self._tool_end_token)[0].strip() if getattr(self, '_tool_end_token', None)
                 else items[1].strip())
         return func_name, self._loads_str(args) if isinstance(args, str) else args
 
     def _parse_arguments_without_args_token(self, output: str) -> tuple[str, dict]:
-        items = output.split(self._tool_end_token)[0] if getattr(self, "_tool_end_token", None) else output
-        func_name = ""
+        items = output.split(self._tool_end_token)[0] if getattr(self, '_tool_end_token', None) else output
+        func_name = ''
         args = {}
         try:
             items = json.loads(items.strip())
             func_name = items.get('name', '')
-            args = items.get("parameters", items.get("arguments", {}))
+            args = items.get('parameters', items.get('arguments', {}))
         except Exception:
-            LOG.error(f"tool calls info {items} parse error")
+            LOG.error(f'tool calls info {items} parse error')
 
         return func_name, self._loads_str(args) if isinstance(args, str) else args
 
@@ -548,7 +612,7 @@ Examples:
         if output.get('name', '') in tools:
             is_tc = True
             func_name = output.get('name', '')
-            args = output.get("parameters", output.get("arguments", {}))
+            args = output.get('parameters', output.get('arguments', {}))
             tc = {'name': func_name, 'arguments': self._loads_str(args) if isinstance(args, str) else args}
             return is_tc, tc
         return is_tc, tc
@@ -559,30 +623,30 @@ Examples:
         content = segs[0]
         for seg in segs[1:]:
             func_name, arguments = self._parse_arguments_with_args_token(seg.strip())\
-                if getattr(self, "_tool_args_token", None)\
+                if getattr(self, '_tool_args_token', None)\
                 else self._parse_arguments_without_args_token(seg.strip())
             if func_name:
-                tool_calls.append({"name": func_name, "arguments": arguments})
+                tool_calls.append({'name': func_name, 'arguments': arguments})
 
         return content, tool_calls
 
     def _parse_tools(self, output: str) -> tuple[str, List[Dict]]:
         tool_calls = []
         tools = {tool['function']['name'] for tool in self._tools}
-        lines = output.strip().split("\n")
+        lines = output.strip().split('\n')
         content = []
         is_tool_call = False
         for idx, line in enumerate(lines):
-            if line.startswith("{") and idx > 0:
+            if line.startswith('{') and idx > 0:
                 func_name = lines[idx - 1].strip()
                 if func_name in tools:
                     is_tool_call = True
                     if func_name == content[-1].strip():
                         content.pop()
-                    arguments = "\n".join(lines[idx:]).strip()
-                    tool_calls.append({'name': func_name, "arguments": arguments})
+                    arguments = '\n'.join(lines[idx:]).strip()
+                    tool_calls.append({'name': func_name, 'arguments': arguments})
                     continue
-            if "{" in line and 'name' in line:
+            if '{' in line and 'name' in line:
                 try:
                     items = json.loads(line.strip())
                     items = [items] if isinstance(items, dict) else items
@@ -592,16 +656,16 @@ Examples:
                             if is_tool_call:
                                 tool_calls.append(tc)
                 except Exception:
-                    LOG.error(f"tool calls info {line} parse error")
+                    LOG.error(f'tool calls info {line} parse error')
             if not is_tool_call:
                 content.append(line)
-        content = "\n".join(content) if len(content) > 0 else ''
+        content = '\n'.join(content) if len(content) > 0 else ''
         return content, tool_calls
 
     def _extract_tool_calls(self, output: str) -> tuple[str, List[Dict]]:
         tool_calls = []
         content = ''
-        if getattr(self, "_tool_start_token", None) and self._tool_start_token in output:
+        if getattr(self, '_tool_start_token', None) and self._tool_start_token in output:
             content, tool_calls = self._parse_tool_start_token(output)
         elif self._tools:
             content, tool_calls = self._parse_tools(output)
@@ -613,15 +677,15 @@ Examples:
     def _decode_base64_to_file(self, content: str) -> str:
         decontent = decode_query_with_filepaths(content)
         files = [_base64_to_file(file_content) if _is_base64_with_mime(file_content) else file_content
-                 for file_content in decontent["files"]]
-        return encode_query_with_filepaths(query=decontent["query"], files=files)
+                 for file_content in decontent['files']]
+        return encode_query_with_filepaths(query=decontent['query'], files=files)
 
     def _build_response(self, content: str, tool_calls: List[Dict[str, str]]) -> str:
         tc = [{'id': str(uuid.uuid4().hex), 'type': 'function', 'function': tool_call} for tool_call in tool_calls]
         if content and tc:
-            return globals["tool_delimiter"].join([content, json.dumps(tc, ensure_ascii=False)])
+            return globals['tool_delimiter'].join([content, json.dumps(tc, ensure_ascii=False)])
         elif not content and tc:
-            return globals["tool_delimiter"] + json.dumps(tc, ensure_ascii=False)
+            return globals['tool_delimiter'] + json.dumps(tc, ensure_ascii=False)
         else:
             return content
 
@@ -650,24 +714,24 @@ Examples:
         raise AttributeError(f'{__class__} object has no attribute {key}')
 
     def _record_usage(self, text_input_for_token_usage: str, temp_output: str):
-        usage = {"prompt_tokens": self._estimate_token_usage(text_input_for_token_usage)}
-        usage["completion_tokens"] = self._estimate_token_usage(temp_output)
+        usage = {'prompt_tokens': self._estimate_token_usage(text_input_for_token_usage)}
+        usage['completion_tokens'] = self._estimate_token_usage(temp_output)
         self._record_usage_impl(usage)
 
     def _record_usage_impl(self, usage: dict):
-        globals["usage"][self._module_id] = usage
+        globals['usage'][self._module_id] = usage
         par_muduleid = self._used_by_moduleid
         if par_muduleid is None:
             return
-        if par_muduleid not in globals["usage"]:
-            globals["usage"][par_muduleid] = usage
+        if par_muduleid not in globals['usage']:
+            globals['usage'][par_muduleid] = usage
             return
-        existing_usage = globals["usage"][par_muduleid]
-        if existing_usage["prompt_tokens"] == -1 or usage["prompt_tokens"] == -1:
-            globals["usage"][par_muduleid] = {"prompt_tokens": -1, "completion_tokens": -1}
+        existing_usage = globals['usage'][par_muduleid]
+        if existing_usage['prompt_tokens'] == -1 or usage['prompt_tokens'] == -1:
+            globals['usage'][par_muduleid] = {'prompt_tokens': -1, 'completion_tokens': -1}
         else:
-            for k in globals["usage"][par_muduleid]:
-                globals["usage"][par_muduleid][k] += usage[k]
+            for k in globals['usage'][par_muduleid]:
+                globals['usage'][par_muduleid][k] += usage[k]
 
     def forward(self, __input: Union[Tuple[Union[str, Dict], str], str, Dict] = package(),  # noqa B008
                 *, llm_chat_history=None, lazyllm_files=None, tools=None, stream_output=False, **kw):
@@ -684,6 +748,64 @@ Examples:
     >>> MyModule()("Hello")
     'processed: Hello'
     """
+        if self._url.endswith('/v1/'):
+            return self.forward_openai(__input, llm_chat_history=llm_chat_history, lazyllm_files=lazyllm_files,
+                                       tools=tools, stream_output=stream_output, **kw)
+        else:
+            return self.forward_standard(__input, llm_chat_history=llm_chat_history, lazyllm_files=lazyllm_files,
+                                         tools=tools, stream_output=stream_output, **kw)
+
+    def forward_openai(self, __input: Union[Tuple[Union[str, Dict], str], str, Dict] = package(),  # noqa B008
+                       *, llm_chat_history=None, lazyllm_files=None, tools=None, stream_output=False, **kw):
+        """Perform forward inference using OpenAI compatible interface.
+
+Call deployed model service through OpenAI standard API format, supports chat history, file processing, tool calling and streaming output.
+
+Args:
+    __input (Union[Tuple[Union[str, Dict], str], str, Dict]): Input data, can be text, dictionary or packaged data
+    llm_chat_history: Chat history records
+    lazyllm_files: File data
+    tools: Tool calling configuration
+    stream_output (bool): Whether to stream output
+    **kw: Other keyword arguments
+
+Returns:
+    Model inference result
+"""
+        if not getattr(self, '_openai_module', None):
+            model_type = self.type.lower()
+            if model_type in ['llm', 'vlm']:
+                self._openai_module = lazyllm.OnlineChatModule(
+                    source='openai', model='lazyllm', base_url=self._url, skip_auth=True, type=model_type,
+                    stream=self._stream).share(prompt=self._prompt, format=self._formatter)
+                self._openai_module._prompt._set_model_configs(system='You are LazyLLM, \
+                    a large language model developed by SenseTime.')
+            elif model_type in ['embed', 'rerank']:
+                self._openai_module = lazyllm.OnlineEmbeddingModule(
+                    source='openai', embed_model_name='lazyllm', embed_url=self._url, type=model_type)
+            else:
+                raise ValueError(f'Unsupported type: {model_type} for openai compatible module')
+            self._openai_module.used_by(self._module_id)
+        return self._openai_module.forward(__input, llm_chat_history=llm_chat_history, lazyllm_files=lazyllm_files,
+                                           tools=tools, stream_output=stream_output, **kw)
+
+    def forward_standard(self, __input: Union[Tuple[Union[str, Dict], str], str, Dict] = package(),  # noqa B008
+                         *, llm_chat_history=None, lazyllm_files=None, tools=None, stream_output=False, **kw):
+        """Perform forward inference using standard interface.
+
+Call deployed model service through custom standard API format, supports template messages, file encoding and streaming output.
+
+Args:
+    __input (Union[Tuple[Union[str, Dict], str], str, Dict]): Input data, can be text, dictionary or packaged data
+    llm_chat_history: Chat history records
+    lazyllm_files: File data
+    tools: Tool calling configuration
+    stream_output (bool): Whether to stream output
+    **kw: Other keyword arguments
+
+Returns:
+    Model inference result
+"""
         __input, files = self._get_files(__input, lazyllm_files)
         text_input_for_token_usage = __input = self._prompt.generate_prompt(__input, llm_chat_history, tools)
         url = self._url
@@ -698,7 +820,7 @@ Examples:
             if stream_output:
                 if self.stream_url_suffix and not url.endswith(self.stream_url_suffix):
                     url += self.stream_url_suffix
-                if "stream" in data: data['stream'] = stream_output
+                if 'stream' in data: data['stream'] = stream_output
         else:
             data = __input
             if stream_output: LOG.warning('stream_output is not supported when template_message is not set, ignore it')
@@ -713,7 +835,7 @@ Examples:
     def _forward_impl(self, data: Union[Tuple[Union[str, Dict], str], str, Dict] = package(), *,  # noqa B008
                       url: str, stream_output: Optional[Union[bool, Dict]] = None, text_input: Optional[str] = None):
         headers = self.template_headers or {'Content-Type': 'application/json'}
-        parse_parameters = self.stream_parse_parameters if stream_output else {"delimiter": b"<|lazyllm_delimiter|>"}
+        parse_parameters = self.stream_parse_parameters if stream_output else {'delimiter': b'<|lazyllm_delimiter|>'}
 
         # context bug with httpx, so we use requests
         with requests.post(url, json=data, stream=True, headers=headers, proxies={'http': None, 'https': None}) as r:
@@ -721,7 +843,7 @@ Examples:
                 raise requests.RequestException('\n'.join([c.decode('utf-8') for c in r.iter_content(None)]))
 
             messages, cache = '', ''
-            token = getattr(self, "_tool_start_token", '')
+            token = getattr(self, '_tool_start_token', '')
             color = stream_output.get('color') if isinstance(stream_output, dict) else None
 
             for line in r.iter_lines(**parse_parameters):
@@ -766,8 +888,20 @@ Examples:
 Sets the default parameters to be used during inference or evaluation.
 
 Args:
-- optional_keys (List[str]): A list of optional keys to allow additional parameters without error.
-- **kw: Key-value pairs for default parameters such as temperature, top_k, etc.
-
+    optional_keys (List[str]): A list of optional keys to allow additional parameters without error.
+    **kw: Key-value pairs for default parameters such as temperature, top_k, etc.
 """
         self._modify_parameters(self.template_message, kw, optional_keys=optional_keys or [])
+
+    def _cache_miss_handler(self):
+        if not self._url or self._url == fake_url:
+            raise RuntimeError('Cache miss, please use `start()` to deploy the module first')
+
+    def __getstate__(self):
+        state = self.__dict__.copy()
+        state['base_model'] = self._impl._base_model
+        return state
+
+    def __setstate__(self, state):
+        self.__dict__.update(state)
+        self._impl._base_model = state['base_model']
