@@ -4,33 +4,276 @@ import traceback
 from lazyllm import ThreadPoolExecutor
 
 import lazyllm
-from lazyllm import FlatList, Option, kwargs, globals, colored_text
+from lazyllm import FlatList, Option, kwargs, globals, colored_text, redis_client
+from ..components.formatter.formatterbase import file_content_hash, transform_path
 from ..flow import FlowBase, Pipeline, Parallel
 from ..common.bind import _MetaBind
 import uuid
-from ..client import redis_client
 from ..hook import LazyLLMHook
 from lazyllm import FileSystemQueue
 from contextlib import contextmanager
-from typing import Optional, Union, Dict
+from typing import Optional, Union, Dict, List
 import copy
+from collections import defaultdict
+import sqlite3
+import pickle
+import hashlib
+from abc import ABC, abstractmethod
+from filelock import FileLock
+
+
+lazyllm.config.add('cache_dir', str, os.path.join(os.path.expanduser(lazyllm.config['home']), 'cache'), 'CACHE_DIR')
+lazyllm.config.add('cache_strategy', str, 'memory', 'CACHE_STRATEGY')
+lazyllm.config.add('cache_mode', str, 'RW', 'CACHE_MODE', options=['RW', 'RO', 'WO', 'NONE'])
+redis_client = redis_client['module']
+
+
+class CacheNotFoundError(Exception): pass
+
+
+class _CacheStorageStrategy(ABC):
+    def __init__(self, cache: Optional[bool] = False):
+        if cache:
+            self._cache_dir = os.path.join(lazyllm.config['cache_dir'], 'module')
+            os.makedirs(self._cache_dir, exist_ok=True)
+            self._lock = FileLock(os.path.join(self._cache_dir, 'cache.lock'))
+        else:
+            self._lock = lambda: contextmanager(lambda: (yield))()
+
+    @abstractmethod
+    def get(self, key: str, hash_key: str): pass
+
+    @abstractmethod
+    def set(self, key: str, hash_key: str, value): pass
+
+    def close(self): pass  # noqa B027
+
+
+class _MemoryCacheStrategy(_CacheStorageStrategy):
+    def __init__(self):
+        super().__init__()
+        self._cache = defaultdict(dict)
+
+    def get(self, key: str, hash_key: str):
+        if key not in self._cache or hash_key not in self._cache[key]:
+            raise CacheNotFoundError(f'Cache not found for {key}')
+        return self._cache[key][hash_key]
+
+    def set(self, key: str, hash_key: str, value):
+        self._cache[key][hash_key] = value
+
+    def close(self):
+        self._cache.clear()
+
+
+class _FileCacheStrategy(_CacheStorageStrategy):
+    def __init__(self):
+        super().__init__(cache=True)
+        self.cache_file = os.path.join(self._cache_dir, 'cache.dat')
+
+    def _load_cache(self):
+        if not os.path.exists(self.cache_file): return {}
+        try:
+            with open(self.cache_file, 'rb') as f:
+                return pickle.load(f)
+        except Exception:
+            return {}
+
+    def _save_cache(self, cache_data):
+        try:
+            with open(self.cache_file, 'wb') as f:
+                pickle.dump(cache_data, f)
+        except Exception:
+            pass
+
+    def get(self, key: str, hash_key: str):
+        with self._lock:
+            cache_data = self._load_cache()
+            if key not in cache_data or hash_key not in cache_data[key]:
+                raise CacheNotFoundError(f'Cache not found for {key}')
+            return cache_data[key][hash_key]
+
+    def set(self, key: str, hash_key: str, value):
+        with self._lock:
+            cache_data = self._load_cache()
+            if key not in cache_data:
+                cache_data[key] = {}
+            cache_data[key][hash_key] = value
+            self._save_cache(cache_data)
+
+
+class _SQLiteCacheStrategy(_CacheStorageStrategy):
+    def __init__(self):
+        super().__init__(cache=True)
+        self.db_path = os.path.join(self._cache_dir, 'cache.db')
+        self.conn = None
+        self._init_db()
+
+    def _init_db(self):
+        self.conn = sqlite3.connect(self.db_path, check_same_thread=False)
+        self.conn.execute('''
+            CREATE TABLE IF NOT EXISTS cache (
+                key TEXT,
+                hash_key TEXT,
+                value BLOB,
+                PRIMARY KEY (key, hash_key)
+            )
+        ''')
+        self.conn.commit()
+
+    def get(self, key: str, hash_key: str):
+        with self._lock:
+            cursor = self.conn.execute(
+                'SELECT value FROM cache WHERE key = ? AND hash_key = ?',
+                (key, hash_key)
+            )
+            row = cursor.fetchone()
+            if row is None:
+                raise CacheNotFoundError(f'Cache not found for {key}')
+            try:
+                return pickle.loads(row[0])
+            except Exception as e:
+                raise CacheNotFoundError(f'Failed to deserialize cache for {key}: {e}')
+
+    def set(self, key: str, hash_key: str, value):
+        with self._lock:
+            try:
+                serialized_value = pickle.dumps(value)
+                self.conn.execute(
+                    'INSERT OR REPLACE INTO cache (key, hash_key, value) VALUES (?, ?, ?)',
+                    (key, hash_key, serialized_value)
+                )
+                self.conn.commit()
+            except Exception:
+                pass
+
+    def close(self):
+        if self.conn:
+            self.conn.close()
+
+
+class _RedisCacheStrategy(_CacheStorageStrategy):
+    def __init__(self, prefix: str = ''):
+        if not redis_client: raise RuntimeError('Redis url should be set by `export LAZYLLM_REDIS_URL = xxx`')
+        self._client = redis_client[prefix] if prefix else redis_client
+        super().__init__()
+
+    def _get_redis_key(self, key: str, hash_key: str):
+        return f'{key}:{hash_key}'
+
+    def get(self, key: str, hash_key: str):
+        redis_key = self._get_redis_key(key, hash_key)
+        value = self._client.get(redis_key)
+        if value is None:
+            raise CacheNotFoundError(f'Cache not found for {key}')
+        try:
+            return pickle.loads(value)
+        except Exception as e:
+            raise RuntimeError(f'Failed to deserialize cache for {key}: {e}')
+
+    def set(self, key: str, hash_key: str, value):
+        try:
+            redis_key = self._get_redis_key(key, hash_key)
+            serialized_value = pickle.dumps(value)
+            self._client.set(redis_key, serialized_value)
+        except Exception:
+            pass
+
+
+class ModuleCache(object):
+    def __init__(self, strategy: Optional[str] = None):
+        self._strategy = self._create_strategy(strategy or lazyllm.config['cache_strategy'])
+
+    def _create_strategy(self, strategy: str) -> _CacheStorageStrategy:
+        strategy = strategy.lower()
+        strategies = {
+            'memory': _MemoryCacheStrategy,
+            'file': _FileCacheStrategy,
+            'sqlite': _SQLiteCacheStrategy,
+            'redis': _RedisCacheStrategy,
+        }
+
+        if strategy not in strategies:
+            raise ValueError(f'Unsupported cache strategy: {strategy}. '
+                             f'Available strategies: {list(strategies.keys())}')
+        return strategies[strategy]()
+
+    def _hash(self, args, kw):
+        def process_value(value, hash_obj):
+            meta = ''
+            if isinstance(value, (list, tuple, dict, set)):
+                meta = str(type(value)) + str(len(value))
+            if isinstance(value, str):
+                hash_obj.update(str(file_content_hash(value)).encode())
+            elif isinstance(value, set):
+                hash_obj.update((meta + '>').encode())
+                for item in sorted(value):
+                    process_value(item, hash_obj)
+                hash_obj.update(('<' + meta).encode())
+            elif isinstance(value, (list, tuple)):
+                hash_obj.update((meta + '>').encode())
+                for item in value:
+                    process_value(item, hash_obj)
+                hash_obj.update(('<' + meta).encode())
+            elif isinstance(value, dict):
+                hash_obj.update((meta + '>').encode())
+                for k, v in sorted(value.items()):
+                    key_meta = 'key:' + str(type(k)) + str(k)
+                    hash_obj.update(key_meta.encode())
+                    process_value(v, hash_obj)
+                hash_obj.update(('<' + meta).encode())
+            else:
+                value_meta = str(type(value)) + str(value)
+                hash_obj.update(value_meta.encode())
+        hash_obj = hashlib.md5()
+        process_value(args, hash_obj)
+        if kw:
+            process_value(kw, hash_obj)
+        return hash_obj.hexdigest()
+
+    def get(self, key, args, kw):
+        if 'R' not in lazyllm.config['cache_mode']:
+            raise CacheNotFoundError('Cannot read cache due to `LAZYLLM_CACHE_MODE = WO`')
+        hash_key = self._hash(args, kw)
+        value = self._strategy.get(key, hash_key)
+        return transform_path(value, mode='r2a')
+
+    def set(self, key, args, kw, value):
+        if 'W' not in lazyllm.config['cache_mode']: return
+        hash_key = self._hash(args, kw)
+        value = transform_path(value, mode='a2r')
+        self._strategy.set(key, hash_key, value)
+
+    def close(self):
+        self._strategy.close()
+
+
+module_cache = ModuleCache()
+
 
 # use _MetaBind:
 # if bind a ModuleBase: x, then hope: isinstance(x, ModuleBase)==True,
 # example: ActionModule.submodules:: isinstance(x, ModuleBase) will add submodule.
 class ModuleBase(metaclass=_MetaBind):
-    """Module is the top-level component in LazyLLM, possessing four key capabilities: training, deployment, inference, and evaluation. Each module can choose to implement some or all of these capabilities, and each capability can be composed of one or more components.
-ModuleBase itself cannot be instantiated directly; subclasses that inherit and implement the forward function can be used as a functor.
-Similar to PyTorch's Module, when a Module A holds an instance of another Module B as a member variable, B will be automatically added to A's submodules.
-If you need the following capabilities, please have your custom class inherit from ModuleBase:
+    """ModuleBase is the core base class in LazyLLM, defining the common interface and fundamental capabilities for all modules.  
+It abstracts training, deployment, inference, and evaluation logic, while also providing mechanisms for submodule management, hook registration, parameter passing, and recursive updates.  
+Custom modules should inherit from ModuleBase and implement the ``forward`` method to define specific inference logic.  
 
-1. Combine some or all of the training, deployment, inference, and evaluation capabilities. For example, an Embedding model requires training and inference.
+Key Features:
+    - Unified management of submodules, automatically tracking held ModuleBase instances.
+    - Support for Option type hyperparameters, enabling grid search and automated tuning.
+    - Hook system that allows executing custom logic before and after calls.
+    - Encapsulated update pipeline covering training, server deployment, and evaluation.
+    - Built-in evalset loading and parallel inference evaluation.
 
-2. If you want the member variables to possess some or all of the capabilities for training, deployment, and evaluation, and you want to train, deploy, and evaluate these members through the start, update, eval, and other methods of the Module's root node.
+Args:
+    return_trace (bool): Whether to write inference results into the trace queue for debugging and tracking. Default is ``False``.
 
-3. Pass user-set parameters directly to your custom module from the outermost layer (refer to WebModule).
-
-4. The desire for it to be usable by the parameter grid search module (refer to TrialModule).
+Use Cases:
+    1. When combining some or all of training, deployment, inference, and evaluation capabilities, e.g., an embedding model requiring both training and inference.
+    2. When you want to recursively manage submodules through root-level methods such as ``start``, ``update``, and ``eval``.
+    3. When you want user parameters to be automatically propagated from outer modules to inner implementations (see WebModule).
+    4. When you want the module to support parameter grid search (see TrialModule).
 
 
 Examples:
@@ -78,6 +321,7 @@ Examples:
         self._module_name = None
         self._options = []
         self.eval_result = None
+        self._use_cache: Union[bool, str] = False
         self._hooks = set()
 
     def __setattr__(self, name: str, value):
@@ -124,14 +368,15 @@ Examples:
             if (files := globals['lazyllm_files'].get(self._module_id)) is not None: kw['lazyllm_files'] = files
             if (history := globals['chat_history'].get(self._module_id)) is not None: kw['llm_chat_history'] = history
 
-            r = self.forward(**args[0], **kw) if args and isinstance(args[0], kwargs) else self.forward(*args, **kw)
+            r = (self._call_impl(**args[0], **kw)
+                 if args and isinstance(args[0], kwargs) else self._call_impl(*args, **kw))
             if self._return_trace:
                 lazyllm.FileSystemQueue.get_instance('lazy_trace').enqueue(str(r))
         except Exception as e:
             raise RuntimeError(
-                f"\nAn error occured in {self.__class__} with name {self.name}.\n"
-                f"Args:\n{args}\nKwargs\n{kw}\nError messages:\n{e}\n"
-                f"Original traceback:\n{''.join(traceback.format_tb(e.__traceback__))}")
+                f'\nAn error occured in {self.__class__} with name {self.name}.\n'
+                f'Args:\n{args}\nKwargs\n{kw}\nError messages:\n{e}\n'
+                f'Original traceback:\n{"".join(traceback.format_tb(e.__traceback__))}')
         for hook_obj in hook_objs[::-1]:
             hook_obj.post_hook(r)
         for hook_obj in hook_objs:
@@ -139,12 +384,37 @@ Examples:
         self._clear_usage()
         return r
 
+    def _call_impl(self, *args, **kw):
+        if self._use_cache and 'R' in lazyllm.config['cache_mode']:
+            try:
+                return module_cache.get(self.__cache_hash__, args, kw)
+            except CacheNotFoundError:
+                self._cache_miss_handler()
+        r = self.forward(**args[0], **kw) if args and isinstance(args[0], kwargs) else self.forward(*args, **kw)
+        if self._use_cache and 'W' in lazyllm.config['cache_mode']:
+            module_cache.set(self.__cache_hash__, args, kw, r)
+        return r
+
     def _stream_output(self, text: str, color: Optional[str] = None, *, cls: Optional[str] = None):
         (FileSystemQueue.get_instance(cls) if cls else FileSystemQueue()).enqueue(colored_text(text, color))
         return ''
 
     @contextmanager
     def stream_output(self, stream_output: Optional[Union[bool, Dict]] = None):
+        """Context manager for streaming output during inference or execution.  
+When a dictionary is provided to ``stream_output``, a prefix and suffix can be specified along with optional colors.
+
+Args:
+    stream_output (Optional[Union[bool, Dict]]): Configuration for streaming output.
+
+        - If True, enables default streaming output.
+        - If a dictionary, may include:
+
+            - 'prefix' (str): Text to output at the beginning.
+            - 'prefix_color' (str, optional): Color of the prefix.
+            - 'suffix' (str): Text to output at the end.
+            - 'suffix_color' (str, optional): Color of the suffix.
+"""
         if stream_output and isinstance(stream_output, dict) and (prefix := stream_output.get('prefix')):
             self._stream_output(prefix, stream_output.get('prefix_color'))
         yield
@@ -152,36 +422,56 @@ Examples:
             self._stream_output(suffix, stream_output.get('suffix_color'))
 
     def used_by(self, module_id):
+        """Mark which module is using the current module, indicating the calling relationship.  
+Supports chaining by returning the module itself.
+
+Args:
+    module_id (str): Unique ID of the parent module that uses this module.
+
+**Returns:**
+
+- ModuleBase: Returns the module itself for method chaining.
+"""
         self._used_by_moduleid = module_id
         return self
 
     def _clear_usage(self):
-        globals["usage"].pop(self._module_id, None)
+        globals['usage'].pop(self._module_id, None)
 
     # interfaces
     def forward(self, *args, **kw):
-        """Define computation steps executed each time, all subclasses of ModuleBase need to override.
+        """Forward computation interface that must be implemented by subclasses.  
+This method defines the logic for receiving inputs and returning outputs, and is the core function of the module as a functor.
 
-
-Examples:
-    >>> import lazyllm
-    >>> class MyModule(lazyllm.module.ModuleBase):
-    ...     def forward(self, input):
-    ...         return input + 1
-    ... 
-    >>> MyModule()(1)
-    2   
-    """
+Args:
+    *args: Variable positional arguments, subclass can define the input as needed.
+    **kw: Variable keyword arguments, subclass can define the input as needed.
+"""
         raise NotImplementedError
 
     def register_hook(self, hook_type: LazyLLMHook):
+        """Register a hook to execute specific logic during module invocation.  
+The hook must inherit from ``LazyLLMHook`` and can be used to add custom operations before or after the module's forward computation, such as logging or metrics collection.
+
+Args:
+    hook_type (LazyLLMHook): Hook object to register.
+"""
         self._hooks.add(hook_type)
 
     def unregister_hook(self, hook_type: LazyLLMHook):
+        """Unregister a previously registered hook.  
+If the hook exists in the module, it will be removed and no longer executed during module invocation.
+
+Args:
+    hook_type (LazyLLMHook): Hook object to unregister.
+"""
         if hook_type in self._hooks:
             self._hooks.remove(hook_type)
 
     def clear_hooks(self):
+        """Clear all hooks registered in the module.  
+After calling this, the module will no longer execute any hook logic.
+"""
         self._hooks = set()
 
     def _get_train_tasks(self):
@@ -231,7 +521,13 @@ Examples:
         return self._submodules
 
     def evalset(self, evalset, load_f=None, collect_f=lambda x: x):
-        """during update or eval, and the results will be stored in the eval_result variable.
+        """Set the evaluation set for the module.  
+During ``update`` or ``eval``, the module will perform inference on the evaluation set, and the results will be stored in the ``eval_result`` variable.  
+
+Args:
+    evalset (Union[list, str]): Evaluation data list or path to an evaluation data file.
+    load_f (Optional[Callable]): Function to load and parse the evaluation file into a list if ``evalset`` is a file path, default is None.
+    collect_f (Callable): Function to post-process evaluation results, default is ``lambda x: x``.
 
 
 Examples:
@@ -267,11 +563,11 @@ Examples:
         return None
 
     # update module(train or finetune),
-    def _update(self, *, mode=None, recursive=True):  # noqa C901
+    def _update(self, *, mode: Optional[Union[str, List[str]]] = None, recursive: bool = True):  # noqa C901
         if not mode: mode = list(self.mode_list)
         if type(mode) is not list: mode = [mode]
         for item in mode:
-            assert item in self.mode_list, f"Cannot find {item} in mode list: {self.mode_list}"
+            assert item in self.mode_list, f'Cannot find {item} in mode list: {self.mode_list}'
         # dfs to get all train tasks
         train_tasks, deploy_tasks, eval_tasks, post_process_tasks = FlatList(), FlatList(), FlatList(), FlatList()
         stack, visited = [(self, iter(self.submodules if recursive else []))], set()
@@ -300,7 +596,7 @@ Examples:
         Parallel.sequential(*post_process_tasks)()
         return self
 
-    def update(self, *, recursive=True):
+    def update(self, *, recursive: bool = True):
         """Update the module (and all its submodules). The module will be updated when the ``_get_train_tasks`` method is overridden.
 
 Args:
@@ -317,8 +613,15 @@ Examples:
     ["reply for 1, and parameters is {'do_sample': False, 'temperature': 0.1}", "reply for 2, and parameters is {'do_sample': False, 'temperature': 0.1}", "reply for 3, and parameters is {'do_sample': False, 'temperature': 0.1}"]
     """
         return self._update(mode=['train', 'server', 'eval'], recursive=recursive)
-    def update_server(self, *, recursive=True): return self._update(mode=['server'], recursive=recursive)
-    def eval(self, *, recursive=True):
+
+    def update_server(self, *, recursive: bool = True):
+        """Update the deployment (server) part of the module and its submodules. When a module or submodule implements deployment functionality, the corresponding services will be started.
+
+Args:
+    recursive (bool): Whether to recursively update deployment tasks of all submodules, default is True.
+"""
+        return self._update(mode=['server'], recursive=recursive)
+    def eval(self, *, recursive: bool = True):
         """Evaluate the module (and all its submodules). This function takes effect after the module has been set with an evaluation set using 'evalset'.
 
 Args:
@@ -338,7 +641,11 @@ Examples:
     """
         return self._update(mode=['eval'], recursive=recursive)
     def start(self):
-        """Deploy the module and all its submodules.
+        """Start the deployment services of the module and all its submodules. This ensures that the server functionality of the module and its submodules is executed, suitable for initialization or restarting services.
+
+**Returns:**
+
+- ModuleBase: Returns itself to support method chaining
 
 
 Examples:
@@ -351,7 +658,11 @@ Examples:
     """
         return self._update(mode=['server'], recursive=True)
     def restart(self):
-        """Re-deploy the module and all its submodules.
+        """Restart the deployment services of the module and its submodules. Internally calls the ``start`` method to reinitialize the services.
+
+**Returns:**
+
+- ModuleBase: Returns itself to support method chaining
 
 
 Examples:
@@ -363,9 +674,15 @@ Examples:
     "reply for 1, and parameters is {'do_sample': False, 'temperature': 0.1}"
     """
         return self.start()
-    def wait(self): pass
+
+    def wait(self):
+        """Wait for the module or its submodules to finish execution. Currently, this method is a no-op and can be implemented by subclasses according to specific deployment logic.
+"""
+        pass
 
     def stop(self):
+        """Stop the module and all its submodules. This method recursively calls the ``stop`` method of each submodule, suitable for releasing resources or shutting down services.
+"""
         for m in self.submodules:
             m.stop()
 
@@ -383,11 +700,30 @@ Examples:
         return lazyllm.make_repr('Module', self.__class__, name=self.name)
 
     def for_each(self, filter, action):
+        """Execute a specified action on all submodules of the module. Recursively traverses all submodules, and if a submodule satisfies the ``filter`` condition, executes the ``action``.
+
+Args:
+    filter (Callable): A function that takes a submodule as input and returns a boolean, used to determine whether to perform the action.
+    action (Callable): A function to perform on submodules that meet the condition.
+"""
         for submodule in self.submodules:
             if filter(submodule):
                 action(submodule)
             submodule.for_each(filter, action)
 
+    @property
+    def __cache_hash__(self):
+        cache_hash = self.__class__.__name__
+        if isinstance(self._use_cache, str): cache_hash += f'@{self._use_cache}'
+        if hasattr(self, 'appendix_hash_key'): cache_hash += f'@{self.appendix_hash_key}'
+        return cache_hash
+
+    def use_cache(self, flag: Union[bool, str] = True):
+        self._use_cache = flag or False
+        return self
+
+    def _cache_miss_handler(self): pass
+
 
 class ActionModule(ModuleBase):
     """Used to wrap a Module around functions, modules, flows, Module, and other callable objects. The wrapped Module (including the Module within the flow) will become a submodule of this Module.
@@ -497,7 +833,7 @@ Args:
                 self.action.for_each(lambda x: isinstance(x, ModuleBase), lambda x: submodule.append(x))
                 return submodule
         except Exception as e:
-            raise RuntimeError(f"{str(e)}\nOriginal traceback:\n{''.join(traceback.format_tb(e.__traceback__))}")
+            raise RuntimeError(f'{str(e)}\nOriginal traceback:\n{"".join(traceback.format_tb(e.__traceback__))}')
         return super().submodules
 
     def __repr__(self):
