@@ -1,5 +1,7 @@
 import re
 import time
+import json
+import hashlib
 import requests
 import pickle
 import codecs
@@ -8,18 +10,18 @@ import copy
 from dataclasses import dataclass
 
 import lazyllm
-from lazyllm import launchers, LOG, package, encode_request, globals, is_valid_url, LazyLLMLaunchersBase
+from lazyllm import launchers, LOG, package, encode_request, globals, is_valid_url, LazyLLMLaunchersBase, redis_client
 from ..components.formatter import FormatterBase, EmptyFormatter, decode_query_with_filepaths
 from ..components.formatter.formatterbase import LAZYLLM_QUERY_PREFIX, _lazyllm_get_file_list
 from ..components.prompter import PrompterBase, ChatPrompter, EmptyPrompter
+from ..components.utils import LLMType
 from ..flow import FlowBase, Pipeline
-from ..client import get_redis, redis_client
 from urllib.parse import urljoin
 from .utils import light_reduce
 from .module import ModuleBase, ActionModule
 
 
-class LLMBase(ModuleBase):
+class LLMBase(object):
     """Base class for large language model modules, inheriting from ModuleBase.  
 Manages initialization and switching of streaming output, prompts, and formatters; processes file information in inputs; supports instance sharing.
 
@@ -28,10 +30,10 @@ Args:
     return_trace (bool): Whether to return execution trace, default is False.
     init_prompt (bool): Whether to automatically create a default prompt at initialization, default is True.
 """
-    def __init__(self, stream: Union[bool, Dict[str, str]] = False, return_trace: bool = False,
-                 init_prompt: bool = True):
-        super().__init__(return_trace=return_trace)
+    def __init__(self, stream: Union[bool, Dict[str, str]] = False,
+                 init_prompt: bool = True, type: Optional[Union[str, LLMType]] = None):
         self._stream = stream
+        self._type = LLMType(type) if type else LLMType.LLM
         if init_prompt: self.prompt()
         __class__.formatter(self)
 
@@ -42,7 +44,7 @@ Args:
         if isinstance(input, str) and input.startswith(LAZYLLM_QUERY_PREFIX):
             assert not lazyllm_files, 'Argument `files` is already provided by query'
             deinput = decode_query_with_filepaths(input)
-            assert isinstance(deinput, dict), "decode_query_with_filepaths must return a dict."
+            assert isinstance(deinput, dict), 'decode_query_with_filepaths must return a dict.'
             input, files = deinput['query'], deinput['files']
         else:
             files = _lazyllm_get_file_list(lazyllm_files) if lazyllm_files else []
@@ -55,7 +57,7 @@ Args:
     prompt (str/dict/PrompterBase/None): The prompt to set.
     history (list): Conversation history, only valid when prompt is str or dict.
 
-**Returns**
+**Returns:**
 
 - self: For chaining calls.
 """
@@ -68,7 +70,7 @@ Args:
         elif isinstance(prompt, (str, dict)):
             self._prompt = ChatPrompter(prompt, history=history)
         else:
-            raise TypeError(f"{prompt} type is not supported.")
+            raise TypeError(f'{prompt} type is not supported.')
         return self
 
     def formatter(self, format: Optional[FormatterBase] = None):
@@ -77,7 +79,7 @@ Args:
 Args:
     format (FormatterBase/Callable/None): Formatter object or function, default is None.
 
-**Returns**
+**Returns:**
 
 - self: For chaining calls.
 """
@@ -96,7 +98,7 @@ Args:
     stream (bool/dict/None): New streaming settings, optional.
     history (list/None): New conversation history, effective only when setting prompt.
 
-**Returns**
+**Returns:**
 
 - LLMBase: The new shared instance.
 """
@@ -108,6 +110,10 @@ Args:
         if stream is not None: new.stream = stream
         return new
 
+    @property
+    def type(self):
+        return self._type.value
+
     @property
     def stream(self):
         return self._stream
@@ -121,6 +127,20 @@ Args:
             return NotImplemented
         return self.share(format=(other if isinstance(self._formatter, EmptyFormatter) else (self._formatter | other)))
 
+    @property
+    def appendix_hash_key(self):
+        try:
+            prompts = self._prompt.generate_prompt('x')
+        except Exception:
+            prompts = self._prompt._instruction_template
+        if not isinstance(prompts, str):
+            try:
+                content = json.dumps(prompts, sort_keys=True)
+            except Exception:
+                content = str(prompts)
+        else:
+            content = prompts
+        return hashlib.md5(content.encode()).hexdigest()
 
 class _UrlHelper(object):
     @dataclass
@@ -138,22 +158,26 @@ class _UrlHelper(object):
             if redis_client:
                 try:
                     while not self._url_wrapper.url:
-                        self._url_wrapper.url = get_redis(self._url_id)
+                        url = redis_client['url'].get(self._url_id)
+                        self._url_wrapper.url = url.decode('utf-8') if url else None
                         if self._url_wrapper.url: break
-                        time.sleep(lazyllm.config["redis_recheck_delay"])
+                        time.sleep(lazyllm.config['redis_recheck_delay'])
                 except Exception as e:
-                    LOG.error(f"Error accessing Redis: {e}")
+                    LOG.error(f'Error accessing Redis: {e}')
                     raise
         return self._url_wrapper.url
 
     def _set_url(self, url):
         if redis_client:
-            redis_client.set(self._url_id, url)
+            redis_client['url'].set(self._url_id, url)
         LOG.debug(f'url: {url}')
         self._url_wrapper.url = url
 
+    def _release_url(self):
+        if redis_client:
+            redis_client['url'].delete(self._url_id)
 
-class UrlModule(LLMBase, _UrlHelper):
+class UrlModule(ModuleBase, LLMBase, _UrlHelper):
     """The URL obtained from deploying the ServerModule can be wrapped into a Module. When calling ``__call__`` , it will access the service.
 
 Args:
@@ -182,24 +206,25 @@ Examples:
 
     def __init__(self, *, url: Optional[str] = '', stream: Union[bool, Dict[str, str]] = False,
                  return_trace: bool = False, init_prompt: bool = True):
-        super().__init__(stream=stream, return_trace=return_trace, init_prompt=init_prompt)
+        super().__init__(return_trace=return_trace)
+        LLMBase.__init__(self, stream=stream, init_prompt=init_prompt)
         _UrlHelper.__init__(self, url)
 
     def _estimate_token_usage(self, text):
         if not isinstance(text, str):
             return 0
         # extract english words, number and comma
-        pattern = r"\b[a-zA-Z0-9]+\b|,"
+        pattern = r'\b[a-zA-Z0-9]+\b|,'
         ascii_words = re.findall(pattern, text)
         ascii_ch_count = sum(len(ele) for ele in ascii_words)
-        non_ascii_pattern = r"[^\x00-\x7F]"
+        non_ascii_pattern = r'[^\x00-\x7F]'
         non_ascii_chars = re.findall(non_ascii_pattern, text)
         non_ascii_char_count = len(non_ascii_chars)
         return int(ascii_ch_count / 3.0 + non_ascii_char_count + 1)
 
     def _decode_line(self, line: bytes):
         try:
-            return pickle.loads(codecs.decode(line, "base64"))
+            return pickle.loads(codecs.decode(line, 'base64'))
         except Exception:
             return line.decode('utf-8')
 
@@ -210,7 +235,6 @@ Examples:
         """Defines the computation steps to be executed each time. All subclasses of ModuleBase need to override this function.
 
 
-
 Examples:
     >>> import lazyllm
     >>> class MyModule(lazyllm.module.ModuleBase):
@@ -235,7 +259,8 @@ Examples:
 
 @light_reduce
 class _ServerModuleImpl(ModuleBase, _UrlHelper):
-    def __init__(self, m=None, pre=None, post=None, launcher=None, port=None, pythonpath=None, url_wrapper=None):
+    def __init__(self, m=None, pre=None, post=None, launcher=None, port=None, pythonpath=None, url_wrapper=None,
+                 num_replicas: int = 1):
         super().__init__()
         _UrlHelper.__init__(self, url=url_wrapper)
         self._m = ActionModule(m) if isinstance(m, FlowBase) else m
@@ -243,13 +268,15 @@ class _ServerModuleImpl(ModuleBase, _UrlHelper):
         self._launcher = launcher.clone() if launcher else launchers.remote(sync=False)
         self._port = port
         self._pythonpath = pythonpath
+        self._num_replicas = num_replicas
 
     @lazyllm.once_wrapper
     def _get_deploy_tasks(self):
         if self._m is None: return None
         return Pipeline(
             lazyllm.deploy.RelayServer(func=self._m, pre_func=self._pre_func, port=self._port,
-                                       pythonpath=self._pythonpath, post_func=self._post_func, launcher=self._launcher),
+                                       pythonpath=self._pythonpath, post_func=self._post_func,
+                                       launcher=self._launcher, num_replicas=self._num_replicas),
             self._set_url)
 
     def stop(self):
@@ -261,118 +288,57 @@ class _ServerModuleImpl(ModuleBase, _UrlHelper):
 
 
 class ServerModule(UrlModule):
-    """Using FastAPI, any callable object can be wrapped into an API service, allowing the simultaneous launch of one main service and multiple satellite services.
+    """The ServerModule class inherits from UrlModule and provides functionality to deploy any callable object as an API service.  
+Built on FastAPI, it supports launching a main service with multiple satellite services, as well as preprocessing, postprocessing, and streaming capabilities.  
+A local callable can be deployed as a service, or an existing service can be accessed directly via a URL.
 
 Args:
-    m (Callable): The function to be wrapped as a service. It can be a function or a functor. When launching satellite services, it needs to be an object implementing ``__call__`` (a functor).
-    pre (Callable): Preprocessing function executed in the service process. It can be a function or a functor, default is ``None``.
-    post (Callable): Postprocessing function executed in the service process. It can be a function or a functor, default is ``None``.
-    stream (bool): Whether to request and output in streaming mode, default is non-streaming.
-    return_trace (bool): Whether to record the results in trace, default is ``False``.
-    port (int): Specifies the port after the service is deployed. The default is ``None``, which will generate a random port.
-    pythonpath (str): PYTHONPATH environment variable passed to the subprocess. Defaults to None.
-    launcher (LazyLLMLaunchersBase): Specifies the compute node for running the service. Defaults to asynchronous remote deployment via launchers.remote(sync=False).
-    url (str): The service URL of the module. Defaults to None, in which case the URL is retrieved from Redis.
-
-**Examples:**
-
-```python
->>> def demo(input): return input * 2
-... 
->>> s = lazyllm.ServerModule(demo, launcher=launchers.empty(sync=False))
->>> s.start()
-INFO:     Uvicorn running on http://0.0.0.0:35485
->>> print(s(1))
-2
-```
-
-```python
->>> class MyServe(object):
-...     def __call__(self, input):
-...         return 2 * input
-...     
-...     @lazyllm.FastapiApp.post
-...     def server1(self, input):
-...         return f'reply for {input}'
-...
-...     @lazyllm.FastapiApp.get
-...     def server2(self):
-...        return f'get method'
-...
->>> m = lazyllm.ServerModule(MyServe(), launcher=launchers.empty(sync=False))
->>> m.start()
->>> print(m(1))
-INFO:     Uvicorn running on http://0.0.0.0:32028
->>> print(m(1))
-2  
-```
-
-<span style="font-size: 20px;">**`evalset(evalset, load_f=None, collect_f=<function ModuleBase.<lambda>>)`**</span>
-
-Set the evaluation set for the Module. Modules that have been set with an evaluation set will be evaluated during ``update`` or ``eval``, and the evaluation results will be stored in the eval_result variable. 
+    m (Optional[Union[str, ModuleBase]]): The module or its name to be wrapped as a service.  
+        If a string is provided, it is treated as a URL and `url` must be None.  
+        If a ModuleBase is provided, it will be wrapped as a service.
+    pre (Optional[Callable]): Preprocessing function executed in the service process. Default is ``None``.
+    post (Optional[Callable]): Postprocessing function executed in the service process. Default is ``None``.
+    stream (Union[bool, Dict]): Whether to enable streaming output. Can be a boolean or a dictionary with streaming configuration. Default is ``False``.
+    return_trace (Optional[bool]): Whether to return debug trace information. Default is ``False``.
+    port (Optional[int]): Port to deploy the service. If ``None``, a random port will be assigned.
+    pythonpath (Optional[str]): PYTHONPATH environment variable passed to the subprocess. Defaults to ``None``.
+    launcher (Optional[LazyLLMLaunchersBase]): The launcher used to deploy the service. Defaults to asynchronous remote deployment.
+    url (Optional[str]): URL of an already deployed service. If provided, `m` must be None.
 
 
-<span style="font-size: 18px;">&ensp;**`evalset(evalset, collect_f=lambda x: ...)→ None `**</span>
-
-
-Args:
-    evalset (list) :Evaluation set
-    collect_f (Callable) :Post-processing method for evaluation results, no post-processing by default.
-
-
-
-<span style="font-size: 18px;">&ensp;**`evalset(evalset, load_f=None, collect_f=lambda x: ...)→ None`**</span>
-
-
-Args:
-    evalset (str) :Path to the evaluation set
-    load_f (Callable) :Method for loading the evaluation set, including parsing file formats and converting to a list
-    collect_f (Callable) :Post-processing method for evaluation results, no post-processing by default.
-
-**Examples:**
-
-```python
->>> import lazyllm
->>> m = lazyllm.module.TrainableModule().deploy_method(deploy.dummy)
->>> m.evalset([1, 2, 3])
->>> m.update()
-INFO: (lazyllm.launcher) PID: dummy finetune!, and init-args is {}
->>> m.eval_result
-["reply for 1, and parameters is {'do_sample': False, 'temperature': 0.1}", "reply for 2, and parameters is {'do_sample': False, 'temperature': 0.1}", "reply for 3, and parameters is {'do_sample': False, 'temperature': 0.1}"]
-```
-
-<span style="font-size: 20px;">**`restart() `**</span>
-
-Restart the module and all its submodules.
-
-**Examples:**
-
-```python
->>> import lazyllm
->>> m = lazyllm.module.TrainableModule().deploy_method(deploy.dummy)
->>> m.restart()
->>> m(1)
-"reply for 1, and parameters is {'do_sample': False, 'temperature': 0.1}"
-```
-
-<span style="font-size: 20px;">**`start() `**</span> 
-
-Deploy the module and all its submodules.
-
-**Examples:**
-
-```python
-import lazyllm
-m = lazyllm.module.TrainableModule().deploy_method(deploy.dummy)
-m.start()
-m(1)
-"reply for 1, and parameters is {'do_sample': False, 'temperature': 0.1}"
-```                                                                    
-"""
+Examples:
+    >>> import lazyllm
+    >>> def demo(input): return input * 2
+    ...
+    >>> s = lazyllm.ServerModule(demo, launcher=launchers.empty(sync=False))
+    >>> s.start()
+    INFO:     Uvicorn running on http://0.0.0.0:35485
+    >>> print(s(1))
+    2
+    
+    >>> class MyServe(object):
+    ...     def __call__(self, input):
+    ...         return 2 * input
+    ...
+    ...     @lazyllm.FastapiApp.post
+    ...     def server1(self, input):
+    ...         return f'reply for {input}'
+    ...
+    ...     @lazyllm.FastapiApp.get
+    ...     def server2(self):
+    ...        return f'get method'
+    ...
+    >>> m = lazyllm.ServerModule(MyServe(), launcher=launchers.empty(sync=False))
+    >>> m.start()
+    INFO:     Uvicorn running on http://0.0.0.0:32028
+    >>> print(m(1))
+    2
+    """
     def __init__(self, m: Optional[Union[str, ModuleBase]] = None, pre: Optional[Callable] = None,
                  post: Optional[Callable] = None, stream: Union[bool, Dict] = False,
                  return_trace: bool = False, port: Optional[int] = None, pythonpath: Optional[str] = None,
-                 launcher: Optional[LazyLLMLaunchersBase] = None, url: Optional[str] = None):
+                 launcher: Optional[LazyLLMLaunchersBase] = None, url: Optional[str] = None,
+                 num_replicas: int = 1):
         assert stream is False or return_trace is False, 'Module with stream output has no trace'
         assert (post is None) or (stream is False), 'Stream cannot be true when post-action exists'
         if isinstance(m, str):
@@ -382,15 +348,22 @@ m(1)
             assert is_valid_url(url), f'Invalid url: {url}'
             assert m is None, 'm should be None when url is provided'
         super().__init__(url=url, stream=stream, return_trace=return_trace)
-        self._impl = _ServerModuleImpl(m, pre, post, launcher, port, pythonpath, self._url_wrapper)
+        self._impl = _ServerModuleImpl(m, pre, post, launcher, port, pythonpath, self._url_wrapper,
+                                       num_replicas=num_replicas)
         if url: self._impl._get_deploy_tasks.flag.set()
 
     _url_id = property(lambda self: self._impl._module_id)
 
     def wait(self):
+        """Wait for the current module service to finish starting or executing.  
+Typically used to block the main thread until the service finishes or is interrupted.  
+"""
         self._impl._launcher.wait()
 
     def stop(self):
+        """Stop the current module service and its related subprocesses.  
+After this call, the module will no longer respond to requests.  
+"""
         self._impl.stop()
 
     @property
@@ -399,9 +372,15 @@ m(1)
 
     def _call(self, fname, *args, **kwargs):
         args, kwargs = lazyllm.dump_obj(args), lazyllm.dump_obj(kwargs)
-        url = urljoin(self._url.rsplit("/", 1)[0], '_call')
+        url = urljoin(self._url.rsplit('/', 1)[0], '_call')
         r = requests.post(url, json=(fname, args, kwargs), headers={'Content-Type': 'application/json'})
-        return pickle.loads(codecs.decode(r.content, "base64"))
+        if r.status_code != 200:
+            try:
+                error_info = r.json()
+            except ValueError:
+                error_info = r.text
+            raise requests.RequestException(f'{r.status_code}: {error_info}')
+        return pickle.loads(codecs.decode(r.content, 'base64'))
 
     def forward(self, __input: Union[Tuple[Union[str, Dict], str], str, Dict] = package(), **kw):  # noqa B008
         headers = {
@@ -419,7 +398,7 @@ m(1)
 
             messages = ''
             with self.stream_output(self._stream):
-                for line in r.iter_lines(delimiter=b"<|lazyllm_delimiter|>"):
+                for line in r.iter_lines(delimiter=b'<|lazyllm_delimiter|>'):
                     line = self._decode_line(line)
                     if self._stream:
                         self._stream_output(str(line), getattr(self._stream, 'get', lambda x: None)('color'))
