@@ -4,7 +4,7 @@ from .functionCall import FunctionCall
 from typing import List, Any, Dict
 import json5 as json
 
-INSTRUCTION = """You are designed to help with a variety of tasks, from answering questions to providing \
+INSTRUCTION = '''You are designed to help with a variety of tasks, from answering questions to providing \
 summaries to other types of analyses.
 
 ## Tools
@@ -31,23 +31,25 @@ Answer: your answer here (In the same language as the user's question)
 
 ## Current Conversation
 
-Below is the current conversation consisting of interleaving human and assistant messages. Think step by step."""
-WITH_TOKEN_PROMPT = """{tool_start_token}tool name (one of {tool_names}) if using a tool.
-{tool_args_token}the input to the tool, in a JSON format representing the kwargs (e.g. {{"input": "hello world", \
-"num_beams": 5}})
-{tool_end_token}end of tool."""
-WITHOUT_TOKEN_PROMPT = """Answering questions should include Thought regardless of whether or not you need to \
-call a tool.(Thought is required, tool_calls is optional.)"""
+Below is the current conversation consisting of interleaving human and assistant messages. Think step by step.'''
+WITH_TOKEN_PROMPT = '''{tool_start_token}tool name (one of {tool_names}) if using a tool.
+{tool_args_token}the input to the tool, in a JSON format representing the kwargs (e.g. {{'input': 'hello world', \
+'num_beams': 5}})
+{tool_end_token}end of tool.'''
+WITHOUT_TOKEN_PROMPT = '''Answering questions should include Thought regardless of whether or not you need to \
+call a tool.(Thought is required, tool_calls is optional.)'''
 
 class ReactAgent(ModuleBase):
     """ReactAgent follows the process of `Thought->Action->Observation->Thought...->Finish` step by step through LLM and tool calls to display the steps to solve user questions and the final answer to the user.
 
 Args:
-    llm (ModuleBase): The LLM to be used can be either TrainableModule or OnlineChatModule.
-    tools (List[str]): A list of tool names for LLM to use.
-    max_retries (int): The maximum number of tool call iterations. The default value is 5.
-    return_trace (bool): If True, return intermediate steps and tool calls.
-    stream (bool): Whether to stream the planning and solving process.
+    llm: Large language model instance for generating reasoning and tool calling decisions
+    tools (List[str]): List of available tools, can be tool functions or tool names
+    max_retries (int): Maximum retry count, automatically retries when tool calling fails, defaults to 5
+    return_trace (bool): Whether to return complete execution trace for debugging and analysis, defaults to False
+    prompt (str): Custom prompt template, uses built-in template if None
+    stream (bool): Whether to enable streaming output for real-time generation display, defaults to False
+
 
 
 Examples:
@@ -87,17 +89,17 @@ Examples:
                  prompt: str = None, stream: bool = False):
         super().__init__(return_trace=return_trace)
         self._max_retries = max_retries
-        assert llm and tools, "llm and tools cannot be empty."
+        assert llm and tools, 'llm and tools cannot be empty.'
 
         if not prompt:
-            prompt = INSTRUCTION.replace("{TOKENIZED_PROMPT}", WITHOUT_TOKEN_PROMPT if isinstance(llm, OnlineChatModule)
-                                         else WITH_TOKEN_PROMPT)
-            prompt = prompt.replace("{tool_names}", json.dumps([t.__name__ if callable(t) else t for t in tools],
+            prompt = INSTRUCTION.replace('{TOKENIZED_PROMPT}', WITHOUT_TOKEN_PROMPT if isinstance(llm, OnlineChatModule)
+                                         or llm._url.endswith('/v1/') else WITH_TOKEN_PROMPT)
+            prompt = prompt.replace('{tool_names}', json.dumps([t.__name__ if callable(t) else t for t in tools],
                                                                ensure_ascii=False))
         self._agent = loop(FunctionCall(llm, tools, _prompt=prompt, return_trace=return_trace, stream=stream),
                            stop_condition=lambda x: isinstance(x, str), count=self._max_retries)
 
     def forward(self, query: str, llm_chat_history: List[Dict[str, Any]] = None):
         ret = self._agent(query, llm_chat_history) if llm_chat_history is not None else self._agent(query)
-        return ret if isinstance(ret, str) else (_ for _ in ()).throw(ValueError(f"After retrying \
-            {self._max_retries} times, the function call agent still failes to call successfully."))
+        return ret if isinstance(ret, str) else (_ for _ in ()).throw(ValueError(f'After retrying \
+            {self._max_retries} times, the function call agent still failes to call successfully.'))
