@@ -4,12 +4,12 @@ from .toolsManager import ToolManager
 from typing import List, Dict, Union, Callable
 import re
 
-P_PROMPT_PREFIX = ("For the following tasks, make plans that can solve the problem step-by-step. "
-                   "For each plan, indicate which external tool together with tool input to retrieve "
-                   "evidence. You can store the evidence into a variable #E that can be called by "
-                   "later tools. (Plan, #E1, Plan, #E2, Plan, #E3...) \n\n")
+P_PROMPT_PREFIX = ('For the following tasks, make plans that can solve the problem step-by-step. '
+                   'For each plan, indicate which external tool together with tool input to retrieve '
+                   'evidence. You can store the evidence into a variable #E that can be called by '
+                   'later tools. (Plan, #E1, Plan, #E2, Plan, #E3...) \n\n')
 
-P_FEWSHOT = """For example,
+P_FEWSHOT = '''For example,
 Task: Thomas, Toby, and Rebecca worked a total of 157 hours in one week. Thomas worked x
 hours. Toby worked 10 hours less than twice what Thomas worked, and Rebecca worked 8 hours
 less than Toby. How many hours did Rebecca work?
@@ -19,16 +19,16 @@ with Wolfram Alpha.
 Plan: Find out the number of hours Thomas worked.
 #E2 = LLM[What is x, given #E1]
 Plan: Calculate the number of hours Rebecca worked.
-#E3 = Calculator[(2 ∗ #E2 − 10) − 8]"""
+#E3 = Calculator[(2 ∗ #E2 − 10) − 8]'''
 
-P_PROMPT_SUFFIX = ("Begin! Describe your plans with rich details. Each Plan should be followed by only one #E.\n\n")
+P_PROMPT_SUFFIX = ('Begin! Describe your plans with rich details. Each Plan should be followed by only one #E.\n\n')
 
-S_PROMPT_PREFIX = ("Solve the following task or problem. To assist you, we provide some plans and "
-                   "corresponding evidences that might be helpful. Notice that some of these information "
-                   "contain noise so you should trust them with caution.\n\n")
+S_PROMPT_PREFIX = ('Solve the following task or problem. To assist you, we provide some plans and '
+                   'corresponding evidences that might be helpful. Notice that some of these information '
+                   'contain noise so you should trust them with caution.\n\n')
 
-S_PROMPT_SUFFIX = ("\nNow begin to solve the task or problem. Respond with "
-                   "the answer directly with no extra words.\n\n")
+S_PROMPT_SUFFIX = ('\nNow begin to solve the task or problem. Respond with '
+                   'the answer directly with no extra words.\n\n')
 
 class ReWOOAgent(ModuleBase):
     """ReWOOAgent consists of three parts: Planer, Worker and Solver. The Planner uses predictive reasoning capabilities to create a solution blueprint for a complex task; the Worker interacts with the environment through tool calls and fills in actual evidence or observations into instructions; the Solver processes all plans and evidence to develop a solution to the original task or problem.
@@ -38,7 +38,6 @@ Args:
     tools (List[str]): A list of tool names for LLM to use.
     plan_llm (ModuleBase): The LLM to be used by the planner, which can be either TrainableModule or OnlineChatModule.
     solve_llm (ModuleBase): The LLM to be used by the solver, which can be either TrainableModule or OnlineChatModule.
-    max_retries (int): The maximum number of tool call iterations. The default value is 5.
     return_trace (bool): If True, return intermediate steps and tool calls.
     stream (bool): Whether to stream the planning and solving process.
 
@@ -93,7 +92,7 @@ Examples:
         assert (llm is None and plan_llm and solve_llm) or (llm and plan_llm is None), 'Either specify only llm \
                without specify plan and solve, or specify only plan and solve without specifying llm, or specify \
                both llm and solve. Other situations are not allowed.'
-        assert tools, "tools cannot be empty."
+        assert tools, 'tools cannot be empty.'
         self._planner = (plan_llm or llm).share(stream=dict(
             prefix='\nI will give a plan first:\n', prefix_color=Color.blue, color=Color.green) if stream else False)
         self._solver = (solve_llm or llm).share(stream=dict(
@@ -108,56 +107,56 @@ Examples:
             self._agent.solver = self._solver
 
     def _build_planner_prompt(self, input: str):
-        prompt = P_PROMPT_PREFIX + "Tools can be one of the following:\n"
+        prompt = P_PROMPT_PREFIX + 'Tools can be one of the following:\n'
         for name, tool in self._name2tool.items():
-            prompt += f"{name}[search query]: {tool.description}\n"
-        prompt += P_FEWSHOT + "\n" + P_PROMPT_SUFFIX + input + "\n"
+            prompt += f'{name}[search query]: {tool.description}\n'
+        prompt += P_FEWSHOT + '\n' + P_PROMPT_SUFFIX + input + '\n'
         globals['chat_history'][self._planner._module_id] = []
         return prompt
 
     def _parse_plan(self, response: str):
-        LOG.debug(f"planner plans: {response}")
+        LOG.debug(f'planner plans: {response}')
         plans = []
         evidence = {}
         for line in response.splitlines():
-            if line.startswith("Plan"):
+            if line.startswith('Plan'):
                 plans.append(line)
-            elif line.startswith("#") and line[1] == "E" and line[2].isdigit():
-                e, tool_call = line.split("=", 1)
+            elif line.startswith('#') and line[1] == 'E' and line[2].isdigit():
+                e, tool_call = line.split('=', 1)
                 e, tool_call = e.strip(), tool_call.strip()
                 if len(e) == 3:
                     evidence[e] = tool_call
                 else:
-                    evidence[e] = "No evidence found"
+                    evidence[e] = 'No evidence found'
         return package(plans, evidence)
 
     def _get_worker_evidences(self, plans: List[str], evidence: Dict[str, str]):
         worker_evidences = {}
         for e, tool_call in evidence.items():
-            if "[" not in tool_call:
+            if '[' not in tool_call:
                 worker_evidences[e] = tool_call
                 continue
-            tool, tool_input = tool_call.split("[", 1)
-            tool_input = tool_input[:-1].strip("'").strip('"')
+            tool, tool_input = tool_call.split('[', 1)
+            tool_input = tool_input[:-1].strip(''').strip(''')
             # find variables in input and replace with previous evidences
-            for var in re.findall(r"#E\d+", tool_input):
+            for var in re.findall(r'#E\d+', tool_input):
                 if var in worker_evidences:
-                    tool_input = tool_input.replace(var, "[" + worker_evidences[var] + "]")
+                    tool_input = tool_input.replace(var, '[' + worker_evidences[var] + ']')
             tool_instance = self._name2tool.get(tool)
             if tool_instance:
                 worker_evidences[e] = tool_instance(tool_input)
             else:
-                worker_evidences[e] = "No evidence found"
+                worker_evidences[e] = 'No evidence found'
 
-        worker_log = ""
+        worker_log = ''
         for idx, plan in enumerate(plans):
-            e = f"#E{idx+1}"
-            worker_log += f"{plan}\nEvidence:\n{worker_evidences[e]}\n"
-        LOG.debug(f"worker_log: {worker_log}")
+            e = f'#E{idx + 1}'
+            worker_log += f'{plan}\nEvidence:\n{worker_evidences[e]}\n'
+        LOG.debug(f'worker_log: {worker_log}')
         return worker_log
 
     def _build_solver_prompt(self, worker_log, input):
-        prompt = S_PROMPT_PREFIX + input + "\n" + worker_log + S_PROMPT_SUFFIX + input + "\n"
+        prompt = S_PROMPT_PREFIX + input + '\n' + worker_log + S_PROMPT_SUFFIX + input + '\n'
         globals['chat_history'][self._solver._module_id] = []
         return prompt
 
