@@ -18,19 +18,19 @@ def _gen_empty_func_str_from_parsed_docstring(parsed_docstring):
     returns a function prototype string
     """
 
-    func_name = "f" + str(int(time.time()))
-    s = "def " + func_name + "("
+    func_name = 'f' + str(int(time.time()))
+    s = 'def ' + func_name + '('
     for param in parsed_docstring.params:
         s += param.arg_name
         if param.type_name:
-            s += ":" + param.type_name + ","
+            s += ':' + param.type_name + ','
         else:
-            s += ","
-    s += ")"
+            s += ','
+    s += ')'
 
     if parsed_docstring.returns and parsed_docstring.returns.type_name:
         s += '->' + parsed_docstring.returns.type_name
-    s += ":\n    pass"
+    s += ':\n    pass'
 
     return s
 
@@ -46,7 +46,7 @@ def _check_return_type_is_the_same(doc_type_hints, func_type_hints) -> None:
     doc_return_type = doc_type_hints.get('return') if doc_type_hints else None
     if func_return_type is not None and doc_return_type is not None:
         if func_return_type != doc_return_type:
-            raise TypeError("return info in docstring is different from that in function prototype.")
+            raise TypeError('return info in docstring is different from that in function prototype.')
 
 # ---------------------------------------------------------------------------- #
 
@@ -87,11 +87,11 @@ Examples:
         super().__init__(return_trace=return_trace)
         self._verbose = verbose
         self._name = self.apply.__name__\
-            if hasattr(self.apply, "__name__") and self.apply.__name__ is not None\
-            else (_ for _ in ()).throw(ValueError("Function must have a name."))
+            if hasattr(self.apply, '__name__') and self.apply.__name__ is not None\
+            else (_ for _ in ()).throw(ValueError('Function must have a name.'))
         self._description = self.apply.__doc__\
-            if hasattr(self.apply, "__doc__") and self.apply.__doc__ is not None\
-            else (_ for _ in ()).throw(ValueError("Function must have a docstring"))
+            if hasattr(self.apply, '__doc__') and self.apply.__doc__ is not None\
+            else (_ for _ in ()).throw(ValueError('Function must have a docstring'))
         # strip space(s) and newlines before and after docstring, as RewooAgent requires
         self._description = self._description.strip(' \n')
 
@@ -151,22 +151,31 @@ Examples:
 
     @property
     def args(self) -> Dict[str, Any]:
-        return self._params_schema.model_json_schema()["properties"]
+        return self._params_schema.model_json_schema()['properties']
 
     @property
     def required_args(self) -> Set[str]:
-        return set(self._params_schema.model_json_schema().get("required", []))
+        return set(self._params_schema.model_json_schema().get('required', []))
 
     def apply(self, *args: Any, **kwargs: Any) -> Any:
         """
-Abstract method to be implemented in subclasses.
+Concrete implementation method of the tool function.
 
-This method should perform a specific task based on the provided arguments.
+This is an abstract method that needs to be implemented in subclasses to provide the core functionality of the tool.
+
+Args:
+    *args (Any): Positional arguments
+    **kwargs (Any): Keyword arguments
+
+**Returns:**
+
+- Result of tool execution
+
+**Raises:**
 
-Raises:
     NotImplementedError: If the method is not overridden in a subclass.
 """
-        raise NotImplementedError("Implement apply function in subclass")
+        raise NotImplementedError('Implement apply function in subclass')
 
     def _validate_input(self, tool_input: Dict[str, Any]) -> Dict[str, Any]:
         input_params = self._params_schema
@@ -189,7 +198,7 @@ Raises:
             arg_type = self._type_hints.values()[0]
             return arg_type(tool_input)
         else:
-            raise TypeError(f"tool_input {tool_input} only supports dict and str.")
+            raise TypeError(f'tool_input {tool_input} only supports dict and str.')
 
     def validate_parameters(self, arguments: Dict[str, Any]) -> bool:
         """
@@ -200,8 +209,9 @@ This method checks if all required keys are present in the input dictionary and
 Args:
     arguments (Dict[str, Any]): Dictionary of input arguments.
 
-Returns:
-    bool: True if valid and complete; False otherwise.
+**Returns:**
+
+- bool: True if valid and complete; False otherwise.
 """
         if len(self.required_args.difference(set(arguments.keys()))) == 0:
             # contains all required parameters
@@ -219,13 +229,13 @@ Returns:
         else:
             ret = self.apply(val_input)
         if verbose or self._verbose:
-            lazyllm.LOG.debug(f"The output of tool {self.name} is {ret}")
+            lazyllm.LOG.debug(f'The output of tool {self.name} is {ret}')
 
         return ret
 
-register = lazyllm.Register(ModuleTool, ["apply"], default_group='tool')
-if "tool" not in LazyLLMRegisterMetaClass.all_clses:
-    register.new_group("tool")
+register = lazyllm.Register(ModuleTool, ['apply'], default_group='tool')
+if 'tool' not in LazyLLMRegisterMetaClass.all_clses:
+    register.new_group('tool')
 
 
 class ToolManager(ModuleBase):
@@ -236,7 +246,7 @@ When constructing this management class, you need to pass in a list of tool name
 Args:
     tools (List[str]): A list of tool name strings.
     return_trace (bool): If True, return intermediate steps and tool calls.
-    stream (bool): Whether to stream the planning and solving process.
+
 
 
 Examples:
@@ -296,7 +306,7 @@ Examples:
         self._tools_desc = self._transform_to_openai_function()
 
     def _load_tools(self, tools: List[Union[str, Callable]]):
-        if "tmp_tool" not in LazyLLMRegisterMetaClass.all_clses:
+        if 'tmp_tool' not in LazyLLMRegisterMetaClass.all_clses:
             register.new_group('tmp_tool')
 
         _tools = []
@@ -344,20 +354,20 @@ Examples:
 
         for example:
             args = {
-                "foo": {
-                    "enum": ["baz", "bar"],
-                    "type": "string",
-                    "description": "a string",
+                'foo': {
+                    'enum': ['baz', 'bar'],
+                    'type': 'string',
+                    'description': 'a string',
                 },
-                "bar": {
-                    "type": "integer",
-                    "description": "an integer",
+                'bar': {
+                    'type': 'integer',
+                    'description': 'an integer',
                 }
             }
         """
         tool_args = tool.args
-        assert len(tool_args) == len(parsed_docstring.params), ("The parameter description and the actual "
-                                                                "number of input parameters are inconsistent.")
+        assert len(tool_args) == len(parsed_docstring.params), ('The parameter description and the actual '
+                                                                'number of input parameters are inconsistent.')
 
         args_description = {}
         for param in parsed_docstring.params:
@@ -366,59 +376,59 @@ Examples:
         args = {}
         for k, v in tool_args.items():
             val = copy.deepcopy(v)
-            val.pop("title", None)
-            val.pop("default", None)
-            args[k] = val if val else {"type": "string"}
+            val.pop('title', None)
+            val.pop('default', None)
+            args[k] = val if val else {'type': 'string'}
             desc = args_description.get(k, None)
             if desc:
-                args[k].update({"description": desc})
+                args[k].update({'description': desc})
             else:
-                raise ValueError(f"The actual input parameter '{k}' is not found "
-                                 f"in the parameter description of tool '{tool.name}'.")
+                raise ValueError(f'The actual input parameter "{k}" is not found '
+                                 f'in the parameter description of tool "{tool.name}".')
         return args
 
     def _transform_to_openai_function(self):
         if not isinstance(self._tools, List):
-            raise TypeError(f"The tools type should be List instead of {type(self._tools)}")
+            raise TypeError(f'The tools type should be List instead of {type(self._tools)}')
 
         format_tools = []
         for tool in self._tools:
             try:
                 parsed_docstring = docstring_parser.parse(tool.description)
                 args = self._gen_args_info_from_moduletool_and_docstring(tool, parsed_docstring)
-                required_arg_list = tool.params_schema.model_json_schema().get("required", [])
+                required_arg_list = tool.params_schema.model_json_schema().get('required', [])
                 func = {
-                    "type": "function",
-                    "function": {
-                        "name": tool.name,
-                        "description": parsed_docstring.short_description,
-                        "parameters": {
-                            "type": "object",
-                            "properties": args,
-                            "required": required_arg_list,
+                    'type': 'function',
+                    'function': {
+                        'name': tool.name,
+                        'description': parsed_docstring.short_description,
+                        'parameters': {
+                            'type': 'object',
+                            'properties': args,
+                            'required': required_arg_list,
                         }
                     }
                 }
                 format_tools.append(func)
             except Exception:
-                typehints_template = """
-                def myfunc(arg1: str, arg2: Dict[str, Any], arg3: Literal["aaa", "bbb", "ccc"]="aaa"):
-                    '''
+                typehints_template = '''
+                def myfunc(arg1: str, arg2: Dict[str, Any], arg3: Literal['aaa', 'bbb', 'ccc']='aaa'):
+                    """
                     Function description ...
 
                     Args:
                         arg1 (str): arg1 description.
                         arg2 (Dict[str, Any]): arg2 description
-                        arg3 (Literal["aaa", "bbb", "ccc"]): arg3 description
-                    '''
-                """
-                raise TypeError("Function description must include function description and "
-                                f"parameter description, the format is as follows: {typehints_template}")
+                        arg3 (Literal['aaa', 'bbb', 'ccc']): arg3 description
+                    """
+                '''
+                raise TypeError('Function description must include function description and '
+                                f'parameter description, the format is as follows: {typehints_template}')
         return format_tools
 
     def forward(self, tools: Union[Dict[str, Any], List[Dict[str, Any]]], verbose: bool = False):
         tool_calls = [tools,] if isinstance(tools, dict) else tools
-        tool_calls = [{"name": tool['name'], "arguments": json.loads(tool['arguments'])
+        tool_calls = [{'name': tool['name'], 'arguments': json.loads(tool['arguments'])
                       if isinstance(tool['arguments'], str) else tool['arguments']} for tool in tool_calls]
         output = []
         flag_val = [True if self._validate_tool(tool['name'], tool['arguments']) else False for tool in tool_calls]
@@ -433,6 +443,6 @@ Examples:
                 ret = rets[idx]
                 output.append(json.dumps(ret, ensure_ascii=False) if not isinstance(ret, str) else ret)
             else:
-                output.append(f"{tool} parameters error.")
+                output.append(f'{tool} parameters error.')
 
         return output
