@@ -2,6 +2,6 @@ from .http_request import HttpRequest
 from .http_executor_response import HttpExecutorResponse
 
 __all__ = [
-    "HttpRequest",
-    "HttpExecutorResponse"
+    'HttpRequest',
+    'HttpExecutorResponse'
 ]
