@@ -1,10 +1,21 @@
-import httpx
+from lazyllm.thirdparty import httpx
 
 class HttpExecutorResponse:
-    headers: dict[str, str]
-    response: httpx.Response
+    """HTTP executor response class for encapsulating and processing HTTP request response results.
 
-    def __init__(self, response: httpx.Response = None):
+Provides unified access interface for HTTP response content, supporting file type detection and content extraction.
+
+Args:
+    response (httpx.Response, optional): httpx library response object, defaults to None
+
+**Returns:**
+
+- HttpExecutorResponse instance, providing multiple response content access methods
+"""
+    headers: dict[str, str]
+    response: 'httpx.Response'
+
+    def __init__(self, response: 'httpx.Response' = None):
         self.response = response
         self.headers = dict(response.headers) if isinstance(self.response, httpx.Response) else {}
 
@@ -23,8 +34,9 @@ class HttpExecutorResponse:
 
 Extracts the 'content-type' field value from the response headers to determine the type of response content.
 
-Returns:
-    str: The content type of the response, or empty string if not found.
+**Returns:**
+
+- str: The content type of the response, or empty string if not found.
 
 
 Examples:
