@@ -1,6 +1,5 @@
 import os
 import time
-import uuid
 import asyncio
 import threading
 from datetime import datetime
@@ -13,27 +12,21 @@ from lazyllm.launcher import Status
 from lazyllm import FastapiApp as app
 from ..services import ServerBase
 
-class JobDescription(BaseModel):
-    """Model deployment job description schema.
+DEFAULT_TOKEN = 'default_token'
 
-Used to specify the configuration for creating a model inference job, including model name and GPU requirements.
-
-Args:
-    deploy_model (str): The model to be deployed. Default is "qwen1.5-0.5b-chat".
-    num_gpus (int): Number of GPUs required for deployment. Default is 1.
-
-
-Examples:
-    >>> from lazyllm.components import JobDescription
-    >>> job = JobDescription(deploy_model="deepseek-coder", num_gpus=2)
-    >>> print(job.dict())
-    ... {'deploy_model': 'deepseek-coder', 'num_gpus': 2}
-    """
-    deploy_model: str = Field(default='qwen1.5-0.5b-chat')
+class _JobDescription(BaseModel):
+    service_name: str
+    model_name: str = Field(default='qwen1.5-0.5b-chat')
+    framework: str = Field(default='auto')
     num_gpus: int = Field(default=1)
 
 
 class InferServer(ServerBase):
+    """Inference service server class, inherits from ServerBase.
+
+Provides RESTful API interfaces for model inference service creation, management, monitoring and log query.
+
+"""
 
     def _update_status(self, token, job_id):  # noqa: C901
         if not self._in_active_jobs(token, job_id):
@@ -55,7 +48,7 @@ class InferServer(ServerBase):
         # Ready to Infer
         if Status[status] == Status.Running and m._url:
             update['status'] = 'Ready'
-            update['url'] = m._url
+            update['endpoint'] = m._url
 
         # Some tasks cannot obtain the storage path when they are just started
         if not log_path:
@@ -67,7 +60,7 @@ class InferServer(ServerBase):
             first_seen = info.get('first_cancelled_time')
             if not first_seen:
                 update['first_cancelled_time'] = datetime.now().strftime(self._time_format)
-                update['status'] = "Pending"
+                update['status'] = 'Pending'
             else:
                 first_seen_time = datetime.strptime(first_seen, self._time_format)
                 if (datetime.now() - first_seen_time).total_seconds() > 60:  # Observe for 60 seconds
@@ -82,7 +75,7 @@ class InferServer(ServerBase):
                     return
                 else:
                     # Still in the obsesrvation period, not cleaned up
-                    update['status'] = "Pending"
+                    update['status'] = 'Pending'
         else:
             # The status is restored, clear first_cancelled_time
             if 'first_cancelled_time' in info:
@@ -141,24 +134,35 @@ class InferServer(ServerBase):
                 newest_file = path
         return newest_file
 
-    @app.post('/v1/deploy/jobs')
-    async def create_job(self, job: JobDescription, token: str = Header(None)):  # noqa B008
-        if not token:
-            raise HTTPException(status_code=401, detail='Invalid token')
-        # await self.authorize_current_user(token)
+    @app.post('/v1/inference_services')
+    async def create_job(self, job: _JobDescription, token: str = Header(DEFAULT_TOKEN)):  # noqa B008
+        """Create inference task.
+
+Create new model inference service based on job description, start deployment thread and initialize task status.
+
+Args:
+    job (JobDescription): Job description object
+    token (str): User token
+
+Returns:
+    dict: Response containing job ID
+"""
         if not self._in_user_job_info(token):
             self._update_user_job_info(token)
-        # Build Job-ID:
+        if self._in_active_jobs(token, job.service_name):
+            raise HTTPException(status_code=400, detail='Service name already exists')
+
+        job_id = job.service_name
         create_time = datetime.now().strftime(self._time_format)
-        job_id = '-'.join(['inf', create_time, str(uuid.uuid4())[:5]])
 
         # Build checkpoint save dir:
         # - No-Env-Set: (work/path + infer_log) + token + job_id;
         # - Env-Set:    (infer_log_root)     + token + job_id;
         save_root = os.path.join(lazyllm.config['infer_log_root'], token, job_id)
         os.makedirs(save_root, exist_ok=True)
-        hypram = dict(launcher=lazyllm.launchers.remote(sync=False, ngpus=job.num_gpus), log_path=save_root)
-        m = lazyllm.TrainableModule(job.deploy_model).deploy_method((lazyllm.deploy.auto, hypram))
+        # wait 5 minutes for launch cmd
+        hypram = dict(launcher=lazyllm.launchers.remote(sync=False, ngpus=job.num_gpus, retry=30), log_path=save_root)
+        m = lazyllm.TrainableModule(job.model_name).deploy_method((getattr(lazyllm.deploy, job.framework), hypram))
 
         # Launch Deploy:
         thread = threading.Thread(target=m.start)
@@ -187,23 +191,35 @@ class InferServer(ServerBase):
             first_seen = None
         self._update_active_jobs(token, job_id, (m, thread))
         self._update_user_job_info(token, job_id, {
-            'job_id': job_id,
-            'base_model': job.deploy_model,
-            'created_at': create_time,
+            'lwsName': job_id,
             'status': status,
+            'endpoint': 'unknown',
+            'service_name': job.service_name,
+            'model_name': job.model_name,
+            'created_at': create_time,
             'hyperparameters': hypram,
             'started_at': started_time,
             'log_path': log_path,
             'cost': None,
             'deploy_method': m._deploy_type.__name__,
-            'url': m._url,
             'first_cancelled_time': first_seen,
         })
 
-        return {'job_id': job_id, 'status': status}
+        return {'lwsName': job_id}
 
-    @app.post('/v1/deploy/jobs/{job_id}/cancel')
-    async def cancel_job(self, job_id: str, token: str = Header(None)):  # noqa B008
+    @app.delete('/v1/inference_services/{job_id}')
+    async def cancel_job(self, job_id: str, token: str = Header(DEFAULT_TOKEN)):  # noqa B008
+        """Cancel inference task.
+
+Stop specified inference task, clean up resources and update task status.
+
+Args:
+    job_id (str): Job ID
+    token (str): User token
+
+Returns:
+    dict: Response containing task status
+"""
         await self.authorize_current_user(token)
         if not self._in_active_jobs(token, job_id):
             raise HTTPException(status_code=404, detail='Job not found')
@@ -228,33 +244,36 @@ class InferServer(ServerBase):
 
         return {'status': status}
 
-    @app.get('/v1/deploy/jobs')
-    async def list_jobs(self, token: str = Header(None)):  # noqa B008
+    @app.get('/v1/inference_services')
+    async def list_jobs(self, token: str = Header(DEFAULT_TOKEN)):  # noqa B008
+        """List all inference tasks.
+
+Get all inference tasks list for current user.
+
+Args:
+    token (str): User token
+
+Returns:
+    dict: Task list information
+"""
         if not self._in_user_job_info(token):
             self._update_user_job_info(token)
         server_running_dict = self._read_user_job_info(token)
-        save_root = os.path.join(lazyllm.config['infer_log_root'], token)
-        os.makedirs(save_root, exist_ok=True)
-        for job_id in os.listdir(save_root):
-            if job_id not in server_running_dict:
-                log_path = os.path.join(save_root, job_id)
-                creation_time = os.path.getctime(log_path)
-                formatted_time = datetime.fromtimestamp(creation_time).strftime(self._time_format)
-                server_running_dict[job_id] = {
-                    'job_id': job_id,
-                    'base_model': None,
-                    'created_at': formatted_time,
-                    'status': 'Cancelled',
-                    'hyperparameters': None,
-                    'log_path': self._get_log_path(log_path),
-                    'cost': None,
-                    'deploy_method': None,
-                    'url': None,
-                }
         return server_running_dict
 
-    @app.get('/v1/deploy/jobs/{job_id}')
-    async def get_job_info(self, job_id: str, token: str = Header(None)):  # noqa B008
+    @app.get('/v1/inference_services/{job_id}')
+    async def get_job_info(self, job_id: str, token: str = Header(DEFAULT_TOKEN)):  # noqa B008
+        """Get task detailed information.
+
+Query detailed information of specified task, including status, endpoint, cost time, etc.
+
+Args:
+    job_id (str): Job ID
+    token (str): User token
+
+Returns:
+    dict: Task detailed information
+"""
         await self.authorize_current_user(token)
         if not self._in_user_job_info(token, job_id):
             raise HTTPException(status_code=404, detail='Job not found')
@@ -263,8 +282,19 @@ class InferServer(ServerBase):
 
         return self._read_user_job_info(token, job_id)
 
-    @app.get('/v1/deploy/jobs/{job_id}/events')
-    async def get_job_log(self, job_id: str, token: str = Header(None)):  # noqa B008
+    @app.get('/v1/inference_services/{job_id}/events')
+    async def get_job_log(self, job_id: str, token: str = Header(DEFAULT_TOKEN)):  # noqa B008
+        """Get task log.
+
+Get log file path or log content of specified task.
+
+Args:
+    job_id (str): Job ID
+    token (str): User token
+
+Returns:
+    dict: Log information
+"""
         await self.authorize_current_user(token)
         if not self._in_user_job_info(token, job_id):
             raise HTTPException(status_code=404, detail='Job not found')
