@@ -7,3 +7,7 @@ class DataType(IntEnum):
     INT32 = 2
     FLOAT_VECTOR = 3
     SPARSE_FLOAT_VECTOR = 4
+    BOOLEAN = 5
+    FLOAT = 6
+    INT64 = 7
+    STRING = 8
