@@ -1,9 +1,7 @@
 import json
-import ast
 import threading
 import time
 from enum import Enum
-from functools import wraps
 from typing import Callable, Dict, List, Optional, Set, Union, Tuple, Any
 from lazyllm import LOG, once_wrapper
 from .transform import (NodeTransform, FuncNodeTransform, SentenceSplitter, LLMParser,
@@ -17,43 +15,12 @@ from .utils import DocListManager, is_sparse
 from .global_metadata import GlobalMetadataDesc, RAG_KB_ID
 from .data_type import DataType
 from .doc_processor import _Processor, DocumentProcessor
+from .embed_wrapper import _EmbedWrapper
 from dataclasses import dataclass
 from itertools import repeat
 
 _transmap = dict(function=FuncNodeTransform, sentencesplitter=SentenceSplitter, llm=LLMParser)
 
-def embed_wrapper(func: Optional[Callable[..., Any]]) -> Optional[Callable[..., List[float]]]:
-    if not func:
-        return None
-
-    @wraps(func)
-    def wrapper(*args, **kwargs) -> List[float]:
-        result = func(*args, **kwargs)
-        if isinstance(result, str):
-            try:
-                # Use json.loads as it's generally more robust for list-like strings
-                return json.loads(result)
-            except json.JSONDecodeError:
-                # Fallback or raise error if json.loads also fails
-                # For example, if ast.literal_eval was truly necessary for some non-JSON compatible Python literal
-                try:
-                    LOG.warning("json.loads failed, attempting ast.literal_eval as a "
-                                "fallback (might hit recursion limit).")
-                    return ast.literal_eval(result)
-                except Exception as e:
-                    LOG.error(f"Both json.loads and ast.literal_eval failed. Error: {e}")
-                    raise  # Re-raise the original or a new error
-        # Explicitly check if it's already a list for dense embedding or dict for sparse embedding
-        elif isinstance(result, (list, dict)):
-            return result
-        else:
-            # Handle unexpected types by raising an error
-            error_message = f"Expected List[float] or str (convertible to List[float]), but got {type(result)}"
-            LOG.error(f"{error_message}")
-            raise TypeError(error_message)
-
-    return wrapper
-
 class StorePlaceholder:
     pass
 
@@ -94,6 +61,20 @@ class BuiltinGroups(object):
 
 
 class DocImpl:
+    """Document implementation class for managing core document processing, storage, and retrieval functionalities.
+
+Args:
+    embed (Dict[str, Callable]): Dictionary of embedding functions.
+    dlm (Optional[DocListManager]): Document list manager, defaults to None.
+    doc_files (Optional[str]): Document files path, defaults to None.
+    kb_group_name (Optional[str]): Knowledge base group name, defaults to default group name.
+    global_metadata_desc (Dict[str, GlobalMetadataDesc]): Global metadata description.
+    store (Optional[Union[Dict, LazyLLMStoreBase]]): Storage instance or configuration.
+    processor (Optional[DocumentProcessor]): Document processor.
+    algo_name (Optional[str]): Algorithm name.
+    display_name (Optional[str]): Display name.
+    description (Optional[str]): Description information.
+"""
     _builtin_node_groups: Dict[str, Dict] = {}
     _global_node_groups: Dict[str, Dict] = {}
     _registered_file_reader: Dict[str, Callable] = {}
@@ -113,7 +94,7 @@ class DocImpl:
             LAZY_ROOT_NAME: dict(parent=None, display_name='Original Source', group_type=NodeGroupType.ORIGINAL),
             LAZY_IMAGE_GROUP: dict(parent=None, display_name='Image Node', group_type=NodeGroupType.OTHER)
         }
-        self.embed = {k: embed_wrapper(e) for k, e in embed.items()}
+        self.embed = {k: _EmbedWrapper(e) for k, e in embed.items()}
         self._global_metadata_desc = global_metadata_desc
         self.store = store  # NOTE: will be initialized in _lazy_init()
         self._activated_groups = set([LAZY_ROOT_NAME, LAZY_IMAGE_GROUP])
@@ -216,7 +197,7 @@ class DocImpl:
                                        num_workers=num_workers, kwargs=kwargs)
 
         if name in groups:
-            LOG.warning(f"Duplicate group name: {name}")
+            LOG.warning(f'Duplicate group name: {name}')
         for t in (transforms if isinstance(transform, list) else [transforms]):
             if isinstance(t.f, str):
                 t.f = _transmap[t.f.lower()]
@@ -227,7 +208,7 @@ class DocImpl:
                     'between nodes may become unreliable, `Document.get_parent/get_child` functions and the '
                     'target parameter of Retriever may have strange anomalies. Please use it at your own risk.')
             else:
-                assert callable(t.f), f"transform should be callable, but get {t.f}"
+                assert callable(t.f), f'transform should be callable, but get {t.f}'
         groups[name] = dict(transform=transforms, parent=parent, display_name=display_name or name,
                             group_type=group_type)
 
@@ -245,6 +226,18 @@ class DocImpl:
                                  trans_node: Optional[bool] = None, num_workers: int = 0,
                                  display_name: Optional[str] = None,
                                  group_type: NodeGroupType = NodeGroupType.CHUNK, **kwargs) -> None:
+        """Create a global node group.
+
+Args:
+    name (str): Node group name.
+    transform (Union[str, Callable]): Transform function or name.
+    parent (str): Parent node group name, defaults to LAZY_ROOT_NAME.
+    trans_node (Optional[bool]): Whether to transform node, defaults to None.
+    num_workers (int): Number of worker threads, defaults to 0.
+    display_name (Optional[str]): Display name.
+    group_type (NodeGroupType): Node group type.
+    **kwargs: Additional arguments.
+"""
         DocImpl._create_node_group_impl(cls, '_global_node_groups', name=name, transform=transform, parent=parent,
                                         trans_node=trans_node, num_workers=num_workers, display_name=display_name,
                                         group_type=group_type, **kwargs)
@@ -252,6 +245,18 @@ class DocImpl:
     def create_node_group(self, name, transform: Union[str, Callable], parent: str = LAZY_ROOT_NAME, *,
                           trans_node: Optional[bool] = None, num_workers: int = 0, display_name: Optional[str] = None,
                           group_type: NodeGroupType = NodeGroupType.CHUNK, **kwargs) -> None:
+        """Create a local node group.
+
+Args:
+    name (str): Node group name.
+    transform (Union[str, Callable]): Transform function or name.
+    parent (str): Parent node group name, defaults to LAZY_ROOT_NAME.
+    trans_node (Optional[bool]): Whether to transform node, defaults to None.
+    num_workers (int): Number of worker threads, defaults to 0.
+    display_name (Optional[str]): Display name.
+    group_type (NodeGroupType): Node group type.
+    **kwargs: Additional arguments.
+"""
         assert not self._lazy_init.flag, 'Cannot add node group after document started'
         DocImpl._create_node_group_impl(self, 'node_groups', name=name, transform=transform, parent=parent,
                                         trans_node=trans_node, num_workers=num_workers, display_name=display_name,
@@ -259,13 +264,23 @@ class DocImpl:
 
     @classmethod
     def register_global_reader(cls, pattern: str, func: Optional[Callable] = None):
+        """Register a global file reader.
+
+Args:
+    pattern (str): File pattern.
+    func (Optional[Callable]): Reader function, defaults to None.
+
+**Returns:**
+
+- Optional[Callable]: Decorator function or None.
+"""
         if func is not None:
             cls._registered_file_reader[pattern] = func
             return None
 
         def decorator(klass):
             if callable(klass): cls._registered_file_reader[pattern] = klass
-            else: raise TypeError(f"The registered object {klass} is not a callable object.")
+            else: raise TypeError(f'The registered object {klass} is not a callable object.')
             return klass
         return decorator
 
@@ -275,6 +290,14 @@ class DocImpl:
         return value
 
     def register_index(self, index_type: str, index_cls: IndexBase, *args, **kwargs) -> None:
+        """Register an index.
+
+Args:
+    index_type (str): Index type.
+    index_cls (IndexBase): Index class.
+    *args: Positional arguments.
+    **kwargs: Keyword arguments.
+"""
         if bool(self._lazy_init.flag):
             args = [self._resolve_index_placeholder(arg) for arg in args]
             kwargs = {k: self._resolve_index_placeholder(v) for k, v in kwargs.items()}
@@ -283,6 +306,12 @@ class DocImpl:
             self._index_pending_registrations.append((index_type, index_cls, args, kwargs))
 
     def add_reader(self, pattern: str, func: Optional[Callable] = None):
+        """Add a local file reader.
+
+Args:
+    pattern (str): File pattern.
+    func (Optional[Callable]): Reader function.
+"""
         assert callable(func), 'func for reader should be callable'
         self._local_file_reader[pattern] = func
 
@@ -295,7 +324,7 @@ class DocImpl:
                                        metadatas=[metadata] if metadata is not None else None)
                 success_ids.append(doc_id)
             except Exception as e:
-                LOG.error(f"Error adding document {doc_id} ({filepath}) to store: {e}")
+                LOG.error(f'Error adding document {doc_id} ({filepath}) to store: {e}')
                 failed_ids.append(doc_id)
 
         if success_ids:
@@ -311,6 +340,8 @@ class DocImpl:
             func(*[arg[i:i + batch_size] if isinstance(arg, (list, tuple)) else arg for arg in args], **kwargs)
 
     def worker(self):
+        """Background worker thread for handling document parsing, deletion, addition, and other operations.
+"""
         is_first_run = True
         while True:
             # Apply meta changes
@@ -377,9 +408,17 @@ class DocImpl:
     def _delete_doc_from_store(self, doc_ids: List[str] = None) -> None:
         self._processor.delete_doc(doc_ids=doc_ids)
 
-    def activate_group(self, group_name: str, embed_keys: List[str]):
+    def activate_group(self, group_name: str, embed_keys: Optional[List[str]] = None, enable_embed: bool = True):
+        """Activate a node group.
+
+Args:
+    group_name (str): Node group name.
+    embed_keys (List[str]): List of embedding keys.
+"""
         group_name = str(group_name)
         self._activated_groups.add(group_name)
+        if embed_keys is None and enable_embed:
+            embed_keys = self.embed.keys()
         if embed_keys:
             activated_embeddings = self._activated_embeddings.setdefault(group_name, set())
             if len(set(embed_keys) - activated_embeddings) == 0: return
@@ -397,17 +436,41 @@ class DocImpl:
             if self.store.is_group_empty(group_name): self._processor.reparse(group_name)
 
     def active_node_groups(self):
+        """Get currently active node groups.
+
+**Returns:**
+
+- Dict: Active node groups and their embedding keys.
+"""
         return {k: v for k, v in self._activated_embeddings.items() if k in self._activated_groups}
 
     def retrieve(self, query: str, group_name: str, similarity: str, similarity_cut_off: Union[float, Dict[str, float]],
                  index: str, topk: int, similarity_kws: dict, embed_keys: Optional[List[str]] = None,
                  filters: Optional[Dict[str, Union[str, int, List, Set]]] = None, **kwargs) -> List[DocNode]:
+        """Retrieve document nodes.
+
+Args:
+    query (str): Query string.
+    group_name (str): Node group name.
+    similarity (str): Similarity calculation method.
+    similarity_cut_off (Union[float, Dict[str, float]]): Similarity threshold.
+    index (str): Index type.
+    topk (int): Number of results to return.
+    similarity_kws (dict): Similarity calculation parameters.
+    embed_keys (Optional[List[str]]): List of embedding keys.
+    filters (Optional[Dict]): Filter conditions.
+    **kwargs: Additional arguments.
+
+**Returns:**
+
+- List[DocNode]: List of retrieved document nodes.
+"""
         self._lazy_init()
 
         if index and index != 'default':
             query_instance = self.store.get_index(type=index)
             if query_instance is None:
-                raise NotImplementedError(f"Index type '{index}' is not registered in the store.")
+                raise NotImplementedError(f'Index type "{index}" is not registered in the store.')
         else:
             query_instance = self.store.get_index(type='default') or self.store
         try:
@@ -424,6 +487,16 @@ class DocImpl:
         return nodes
 
     def find(self, nodes: List[DocNode], group: str) -> List[DocNode]:
+        """Find nodes in specified group.
+
+Args:
+    nodes (List[DocNode]): List of nodes.
+    group (str): Target group name.
+
+**Returns:**
+
+- List[DocNode]: List of found nodes.
+"""
         if len(nodes) == 0: return nodes
         self._lazy_init()
 
@@ -456,20 +529,30 @@ class DocImpl:
             nodes = self.find_children(nodes, next_group)
 
         if not nodes:
-            LOG.warning(f"We can not find any nodes for group `{group}`, please check your input")
+            LOG.warning(f'We can not find any nodes for group `{group}`, please check your input')
             return []
         return nodes
 
     def find_parent(self, nodes: List[DocNode], group: str) -> List[DocNode]:
+        """Find parent nodes.
+
+Args:
+    nodes (List[DocNode]): List of nodes.
+    group (str): Target group name.
+
+**Returns:**
+
+- List[DocNode]: List of found parent nodes.
+"""
         if isinstance(nodes[0].parent, DocNode):
             result = self._find_parent_with_node(nodes, group)
         else:
             result = self._find_parent_with_uid(nodes, group)
         if not result:
             LOG.warning(
-                f"We can not find any nodes for group `{group}`, please check your input"
+                f'We can not find any nodes for group `{group}`, please check your input'
             )
-        LOG.debug(f"Found parent node for {group}: {result}")
+        LOG.debug(f'Found parent node for {group}: {result}')
         return result
 
     def _find_parent_with_node(self, nodes: list[DocNode], group: str):
@@ -500,15 +583,30 @@ class DocImpl:
         return cur_nodes if cur_group == group else []
 
     def find_children(self, nodes: List[DocNode], group: str) -> List[DocNode]:
+        """Find child nodes.
+
+Args:
+    nodes (List[DocNode]): List of nodes.
+    group (str): Target group name.
+
+**Returns:**
+
+- List[DocNode]: List of found child nodes.
+"""
         if not nodes: return []
         kb_id = nodes[0].global_metadata.get(RAG_KB_ID, None)
         result = self.store.get_nodes(group=group, kb_id=kb_id, parent=[n._uid for n in nodes], display=True)
         if not result:
-            LOG.warning(f"We cannot find any nodes for group `{group}`, please check your input.")
-        LOG.debug(f"Found children nodes for {group}: {result}")
+            LOG.warning(f'We cannot find any nodes for group `{group}`, please check your input.')
+        LOG.debug(f'Found children nodes for {group}: {result}')
         return list(result)
 
     def clear_cache(self, group_names: Optional[List[str]] = None):
+        """Clear cache.
+
+Args:
+    group_names (Optional[List[str]]): List of group names to clear cache for, defaults to None for clearing all cache.
+"""
         self.store.clear_cache(group_names)
 
     def __call__(self, func_name: str, *args, **kwargs):
