@@ -5,10 +5,10 @@ import traceback
 from typing import List, Optional, Dict, Union
 from pydantic import BaseModel, Field
 from starlette.responses import RedirectResponse
-from fastapi import UploadFile
 
 import lazyllm
 from lazyllm import FastapiApp as app
+from lazyllm.thirdparty import fastapi
 from .utils import DocListManager, BaseResponse, gen_docid
 from .global_metadata import RAG_DOC_ID, RAG_DOC_PATH
 import uuid
@@ -20,19 +20,20 @@ The `DocManager` class manages document lists and related operations, providing
 
 Args:
     dlm (DocListManager): Document list manager responsible for handling document-related operations.
-
 """
     def __init__(self, dlm: DocListManager) -> None:
         super().__init__()
         # disable path monitoring in case of competition adding/deleting files
         self._manager = dlm
         self._manager.enable_path_monitoring = False
+        self.upload_files.__annotations__['files'] = List[fastapi.UploadFile]
+        self.add_files_to_group.__annotations__['files'] = List[fastapi.UploadFile]
 
     def __reduce__(self):
         self._manager.enable_path_monitoring = False
         return (__class__, (self._manager,))
 
-    @app.get("/", response_model=BaseResponse, summary="docs")
+    @app.get('/', response_model=BaseResponse, summary='docs')
     def document(self):
         """
 An endpoint to redirect to the default documentation page.
@@ -41,9 +42,9 @@ An endpoint to redirect to the default documentation page.
 
 - RedirectResponse: Redirects to the `/docs` page.
 """
-        return RedirectResponse(url="/docs")
+        return RedirectResponse(url='/docs')
 
-    @app.get("/list_kb_groups")
+    @app.get('/list_kb_groups')
     def list_kb_groups(self):
         """
 An endpoint to list all document groups.
@@ -61,27 +62,27 @@ An endpoint to list all document groups.
     @staticmethod
     def _validate_metadata(metadata: Dict) -> Optional[str]:
         if metadata.get(RAG_DOC_ID):
-            return f"metadata MUST not contain key `{RAG_DOC_ID}`"
+            return f'metadata MUST not contain key `{RAG_DOC_ID}`'
         if metadata.get(RAG_DOC_PATH):
-            return f"metadata MUST not contain key `{RAG_DOC_PATH}`"
+            return f'metadata MUST not contain key `{RAG_DOC_PATH}`'
         return None
 
     def _gen_unique_filepath(self, file_path: str) -> str:
         suffix = os.path.splitext(file_path)[1]
         prefix = file_path[0: len(file_path) - len(suffix)]
-        pattern = f"{prefix}%{suffix}"
+        pattern = f'{prefix}%{suffix}'
         MAX_TRIES = 10000
         exist_paths = set(self._manager.get_existing_paths_by_pattern(pattern))
         if file_path not in exist_paths:
             return file_path
         for i in range(1, MAX_TRIES):
-            new_path = f"{prefix}-{i}{suffix}"
+            new_path = f'{prefix}-{i}{suffix}'
             if new_path not in exist_paths:
                 return new_path
-        return f"{str(uuid.uuid4())}{suffix}"
+        return f'{str(uuid.uuid4())}{suffix}'
 
-    @app.post("/upload_files")
-    def upload_files(self, files: List[UploadFile], override: bool = False,  # noqa C901
+    @app.post('/upload_files')
+    def upload_files(self, files: List['fastapi.UploadFile'], override: bool = False,  # noqa C901
                      metadatas: Optional[str] = None, user_path: Optional[str] = None):
         """
 An endpoint to upload files and update their status. Multiple files can be uploaded at once.
@@ -123,16 +124,16 @@ Args:
                 if override is False:
                     file_path = self._gen_unique_filepath(file_path)
                 with open(file_path, 'wb') as f: f.write(content)
-                msg = "success"
+                msg = 'success'
                 doc_id = gen_docid(file_path)
                 if paths_is_new[i]:
                     docs = self._manager.add_files(
                         [file_path], metadatas=[metadata], status=DocListManager.Status.success)
                     if not docs:
-                        msg = f"Failed: path {file_path} already exists in Database."
+                        msg = f'Failed: path {file_path} already exists in Database.'
                 else:
                     self._manager.update_kb_group(cond_file_ids=[doc_id], new_need_reparse=True)
-                    msg = f"Success: path {file_path} will be reparsed."
+                    msg = f'Success: path {file_path} will be reparsed.'
                 ids.append(doc_id)
                 results.append(msg)
             return BaseResponse(data=[ids, results])
@@ -145,7 +146,7 @@ Args:
         group_name: Optional[str] = None
         metadatas: Optional[str] = None
 
-    @app.post("/add_files")
+    @app.post('/add_files')
     def add_files(self, request: AddFilesRequest):
         """
 Batch add files.
@@ -180,7 +181,7 @@ Args:
                     exist_id = exists_files_info.get(file, None)
                     if exist_id:
                         update_kws = dict(fileid=exist_id, status=DocListManager.Status.success)
-                        if metadatas: update_kws["meta"] = json.dumps(metadatas[idx])
+                        if metadatas: update_kws['meta'] = json.dumps(metadatas[idx])
                         self._manager.update_file_message(**update_kws)
                         exist_ids.append(exist_id)
                         id_mapping[file] = exist_id
@@ -203,7 +204,7 @@ Args:
         except Exception as e:
             return BaseResponse(code=500, msg=str(e), data=None)
 
-    @app.get("/list_files")
+    @app.get('/list_files')
     def list_files(self, limit: Optional[int] = None, details: bool = True, alive: Optional[bool] = None):
         """
 An endpoint to list uploaded files.
@@ -224,15 +225,28 @@ Args:
         except Exception as e:
             return BaseResponse(code=500, msg=str(e), data=None)
 
-    @app.get("/reparse_files")
+    @app.get('/reparse_files')
     def reparse_files(self, file_ids: List[str], group_name: Optional[str] = None):
+        """Reparse specified files.
+
+Args:
+    file_ids (List[str]): List of file IDs to reparse.
+    group_name (Optional[str]): Group name for the files, defaults to None.
+
+**Returns:**
+
+- BaseResponse: Response object containing:
+    - code (int): Status code, 200 for success.
+    - msg (str): Error message if any.
+    - data: None.
+"""
         try:
             self._manager.update_need_reparsing(file_ids, group_name)
             return BaseResponse()
         except Exception as e:
             return BaseResponse(code=500, msg=str(e), data=None)
 
-    @app.get("/list_files_in_group")
+    @app.get('/list_files_in_group')
     def list_files_in_group(self, group_name: Optional[str] = None,
                             limit: Optional[int] = None, alive: Optional[bool] = None):
         """
@@ -258,7 +272,7 @@ Args:
         file_ids: List[str]
         group_name: Optional[str] = Field(None)
 
-    @app.post("/add_files_to_group_by_id")
+    @app.post('/add_files_to_group_by_id')
     def add_files_to_group_by_id(self, request: FileGroupRequest):
         """
 An endpoint to add files to a specific group by file IDs.
@@ -276,8 +290,8 @@ Args:
         except Exception as e:
             return BaseResponse(code=500, msg=str(e), data=None)
 
-    @app.post("/add_files_to_group")
-    def add_files_to_group(self, files: List[UploadFile], group_name: str, override: bool = False,
+    @app.post('/add_files_to_group')
+    def add_files_to_group(self, files: List['fastapi.UploadFile'], group_name: str, override: bool = False,
                            metadatas: Optional[str] = None, user_path: Optional[str] = None):
         """
 An endpoint to upload files and directly add them to a specified group.
@@ -302,7 +316,7 @@ Args:
         except Exception as e:
             return BaseResponse(code=500, msg=str(e), data=None)
 
-    @app.post("/delete_files")
+    @app.post('/delete_files')
     def delete_files(self, request: FileGroupRequest):
         """
 An endpoint to delete specified files.
@@ -323,12 +337,12 @@ Args:
                 for doc in documents:
                     if os.path.exists(path := doc.path):
                         os.remove(path)
-                results = ["Success" if ele.doc_id in deleted_ids else "Failed" for ele in documents]
+                results = ['Success' if ele.doc_id in deleted_ids else 'Failed' for ele in documents]
                 return BaseResponse(data=[request.file_ids, results])
         except Exception as e:
             return BaseResponse(code=500, msg=str(e), data=None)
 
-    @app.post("/delete_files_from_group")
+    @app.post('/delete_files_from_group')
     def delete_files_from_group(self, request: FileGroupRequest):
         """
 An endpoint to delete specified files in a group.
@@ -351,7 +365,7 @@ Args:
         doc_ids: List[str]
         kv_pair: Dict[str, Union[bool, int, float, str, list]]
 
-    @app.post("/add_metadata")
+    @app.post('/add_metadata')
     def add_metadata(self, add_metadata_request: AddMetadataRequest):
         """
 An endpoint to add or update metadata for specified documents.
@@ -368,7 +382,7 @@ Args:
         try:
             docs = self._manager.get_docs(doc_ids)
             if not docs:
-                return BaseResponse(code=400, msg="Failed, no doc found")
+                return BaseResponse(code=400, msg='Failed, no doc found')
             doc_meta = {}
             for doc in docs:
                 meta_dict = json.loads(doc.meta) if doc.meta else {}
@@ -407,7 +421,7 @@ Args:
                 if meta_dict[k] == v:
                     meta_dict.pop(k, None)
 
-    @app.post("/delete_metadata_item")
+    @app.post('/delete_metadata_item')
     def delete_metadata_item(self, del_metadata_request: DeleteMetadataRequest):
         """
 An endpoint to delete metadata fields or field values from specified documents.
@@ -435,7 +449,7 @@ Args:
             else:
                 docs = self._manager.get_docs(doc_ids)
                 if not docs:
-                    return BaseResponse(code=400, msg="Failed, no doc found")
+                    return BaseResponse(code=400, msg='Failed, no doc found')
                 doc_meta = {}
                 for doc in docs:
                     meta_dict = json.loads(doc.meta) if doc.meta else {}
@@ -450,7 +464,7 @@ Args:
         doc_ids: List[str]
         kv_pair: Dict[str, Union[bool, int, float, str, list]]
 
-    @app.post("/update_or_create_metadata_keys")
+    @app.post('/update_or_create_metadata_keys')
     def update_or_create_metadata_keys(self, update_metadata_request: UpdateMetadataRequest):
         """
 An endpoint to update or create metadata fields for specified documents.
@@ -467,7 +481,7 @@ Args:
         try:
             docs = self._manager.get_docs(doc_ids)
             if not docs:
-                return BaseResponse(code=400, msg="Failed, no doc found")
+                return BaseResponse(code=400, msg='Failed, no doc found')
             for doc in docs:
                 doc_meta = {}
                 meta_dict = json.loads(doc.meta) if doc.meta else {}
@@ -483,7 +497,7 @@ Args:
         doc_ids: List[str]
         new_meta: Dict[str, Union[bool, int, float, str, list]]
 
-    @app.post("/reset_metadata")
+    @app.post('/reset_metadata')
     def reset_metadata(self, reset_metadata_request: ResetMetadataRequest):
         """
 An endpoint to reset all metadata fields of specified documents.
@@ -500,7 +514,7 @@ Args:
         try:
             docs = self._manager.get_docs(doc_ids)
             if not docs:
-                return BaseResponse(code=400, msg="Failed, no doc found")
+                return BaseResponse(code=400, msg='Failed, no doc found')
             self._manager.set_docs_new_meta({doc.doc_id: new_meta for doc in docs})
             return BaseResponse(data=None)
         except Exception as e:
@@ -510,7 +524,7 @@ Args:
         doc_id: str
         key: Optional[str] = None
 
-    @app.post("/query_metadata")
+    @app.post('/query_metadata')
     def query_metadata(self, query_metadata_request: QueryMetadataRequest):
         """
 An endpoint to query metadata of a specific document.
@@ -533,10 +547,10 @@ Args:
             if not key:
                 return BaseResponse(data=meta_dict)
             if key not in meta_dict:
-                return BaseResponse(code=400, msg=f"Failed, key {key} does not exist")
+                return BaseResponse(code=400, msg=f'Failed, key {key} does not exist')
             return BaseResponse(data=meta_dict[key])
         except Exception as e:
             return BaseResponse(code=500, msg=str(e), data=None)
 
     def __repr__(self):
-        return lazyllm.make_repr("Module", "DocManager")
+        return lazyllm.make_repr('Module', 'DocManager')
