@@ -1,7 +1,7 @@
 from typing import Optional, Dict, Any, Union, Callable, List
 from enum import Enum, auto
 from collections import defaultdict
-from PIL import Image
+from lazyllm.thirdparty import PIL
 from lazyllm import config, reset_on_pickle
 from lazyllm.components.utils.file_operate import _image_to_base64
 from .global_metadata import RAG_DOC_ID, RAG_DOC_PATH, RAG_KB_ID
@@ -25,6 +25,7 @@ class MetadataMode(str, Enum):
 class DocNode:
     """
 Execute assigned tasks on the specified document.
+
 Args:
     uid (str): Unique identifier.
     content (Union[str, List[Any]]): Node content.
@@ -39,7 +40,7 @@ Args:
 """
     def __init__(self, uid: Optional[str] = None, content: Optional[Union[str, List[Any]]] = None,
                  group: Optional[str] = None, embedding: Optional[Dict[str, List[float]]] = None,
-                 parent: Optional[Union[str, "DocNode"]] = None, store=None,
+                 parent: Optional[Union[str, 'DocNode']] = None, store=None,
                  node_groups: Optional[Dict[str, Dict]] = None, metadata: Optional[Dict[str, Any]] = None,
                  global_metadata: Optional[Dict[str, Any]] = None, *, text: Optional[str] = None):
         if text and content:
@@ -58,8 +59,8 @@ Args:
         # Metadata keys that are excluded from text for the LLM.
         self._excluded_llm_metadata_keys: List[str] = []
         # NOTE: node in parent should be id when stored in db (use store to recover): parent: 'uid'
-        self._parent: Optional[Union[str, "DocNode"]] = parent
-        self._children: Dict[str, List["DocNode"]] = defaultdict(list)
+        self._parent: Optional[Union[str, 'DocNode']] = parent
+        self._children: Dict[str, List['DocNode']] = defaultdict(list)
         self._children_loaded = False
         self._store = store
         self._node_groups: Dict[str, Dict] = node_groups or {}
@@ -82,10 +83,10 @@ Args:
             return self._content
         elif isinstance(self._content, list):
             if unexcepted := set([type(ele) for ele in self._content if not isinstance(ele, str)]):
-                raise TypeError(f"Found non-string element in content: {unexcepted}")
+                raise TypeError(f'Found non-string element in content: {unexcepted}')
             return '\n'.join(self._content)
         else:
-            raise TypeError(f"content type '{type(self._content)}' is neither a str nor a list")
+            raise TypeError(f'content type "{type(self._content)}" is neither a str nor a list')
 
     @property
     def embedding(self):
@@ -95,7 +96,7 @@ Args:
     def embedding(self, v: Optional[Dict[str, List[float]]]):
         self._embedding = v
 
-    def _load_from_store(self, group_name: str, uids: Union[str, List[str]]) -> List["DocNode"]:
+    def _load_from_store(self, group_name: str, uids: Union[str, List[str]]) -> List['DocNode']:
         if not self._store or not uids:
             return []
         if isinstance(uids, str):
@@ -108,19 +109,19 @@ Args:
         return nodes
 
     @property
-    def parent(self) -> Optional["DocNode"]:
+    def parent(self) -> Optional['DocNode']:
         if self._parent and isinstance(self._parent, str) and self._node_groups:
-            parent_group = self._node_groups[self._group]["parent"]
+            parent_group = self._node_groups[self._group]['parent']
             loaded = self._load_from_store(parent_group, self._parent)
             self._parent = loaded[0] if loaded else None
         return self._parent
 
     @parent.setter
-    def parent(self, v: Optional["DocNode"]):
+    def parent(self, v: Optional['DocNode']):
         self._parent = v
 
     @property
-    def children(self) -> Dict[str, List["DocNode"]]:
+    def children(self) -> Dict[str, List['DocNode']]:
         if not self._children_loaded and self._store and self._node_groups:
             self._children_loaded = True
             kb_id = self.global_metadata.get(RAG_KB_ID)
@@ -138,11 +139,11 @@ Args:
         return self._children
 
     @children.setter
-    def children(self, v: Dict[str, List["DocNode"]]):
+    def children(self, v: Dict[str, List['DocNode']]):
         self._children = v
 
     @property
-    def root_node(self) -> "DocNode":
+    def root_node(self) -> 'DocNode':
         node = self
         while isinstance(node._parent, DocNode):
             node = node._parent
@@ -194,21 +195,33 @@ Args:
         self.global_metadata[RAG_DOC_PATH] = str(path)
 
     def get_children_str(self) -> str:
+        """Get string representation of child nodes.
+
+**Returns:**
+
+- str: Returns a string representing a dictionary where keys are group names and values are lists of child node UIDs in that group.
+"""
         return str(
             {key: [node._uid for node in nodes] for key, nodes in self.children.items()}
         )
 
     def get_parent_id(self) -> str:
+        """Get the unique identifier of the parent node.
+
+**Returns:**
+
+- str: Returns the parent node's UID, or an empty string if there is no parent node.
+"""
         return self.parent._uid if self.parent else ''
 
     def __str__(self) -> str:
         return (
-            f"DocNode(id: {self._uid}, group: {self._group}, content: {self._content}) parent: {self.get_parent_id()}, "
-            f"children: {self.get_children_str()}"
+            f'DocNode(id: {self._uid}, group: {self._group}, content: {self._content}) parent: {self.get_parent_id()}, '
+            f'children: {self.get_children_str()}'
         )
 
     def __repr__(self) -> str:
-        return str(self) if config["debug"] else f'<Node id={self._uid}>'
+        return str(self) if config['debug'] else f'<Node id={self._uid}>'
 
     def __eq__(self, other):
         if isinstance(other, DocNode):
@@ -227,17 +240,19 @@ Args:
     def has_missing_embedding(self, embed_keys: Union[str, List[str]]) -> List[str]:
         """
 Check for missing embedding vectors.
+
 Args:
     embed_keys (Union[str, List[str]]): List of target keys.
 """
         if isinstance(embed_keys, str): embed_keys = [embed_keys]
-        assert len(embed_keys) > 0, "The ebmed_keys to be checked must be passed in."
+        assert len(embed_keys) > 0, 'The ebmed_keys to be checked must be passed in.'
         if self.embedding is None: return embed_keys
         return [k for k in embed_keys if k not in self.embedding]
 
     def do_embedding(self, embed: Dict[str, Callable]) -> None:
         """
 Execute embedding computation.
+
 Args:
     embed (Dict[str, Callable]): Target embedding objects.
 """
@@ -246,9 +261,15 @@ Args:
             self.embedding = self.embedding or {}
             self.embedding = {**self.embedding, **generate_embed}
 
+    def set_embedding(self, embed_key, embed_value) -> None:
+        with self._lock:
+            self.embedding = self.embedding or {}
+            self.embedding[embed_key] = embed_value
+
     def check_embedding_state(self, embed_key: str) -> None:
         """
 Block to check the embedding status and ensure that asynchronous embedding computation is completed.
+
 Args:
     embed_key (str): List of target keys.
 """
@@ -260,6 +281,12 @@ Args:
             time.sleep(1)
 
     def get_content(self) -> str:
+        """Get the node's content text with metadata in LLM mode.
+
+**Returns:**
+
+- str: Returns the node's text content with formatted metadata information according to LLM mode.
+"""
         return self.get_text(MetadataMode.LLM)
 
     def get_metadata_str(self, mode: MetadataMode = MetadataMode.ALL) -> str:
@@ -277,18 +304,19 @@ Args:
                 if key in metadata_keys:
                     metadata_keys.remove(key)
 
-        return "\n".join([f"{key}: {self.metadata[key]}" for key in metadata_keys])
+        return '\n'.join([f'{key}: {self.metadata[key]}' for key in metadata_keys])
 
     def get_text(self, metadata_mode: MetadataMode = MetadataMode.NONE) -> str:
         """
 Combine metadata and content.
+
 Args:
     metadata_mode: Same as the parameter in get_metadata_str.
 """
         metadata_str = self.get_metadata_str(metadata_mode).strip()
         if not metadata_str:
             return self.text if self.text else ''
-        return f"{metadata_str}\n\n{self.text}".strip()
+        return f'{metadata_str}\n\n{self.text}'.strip()
 
     def to_dict(self) -> Dict:
         """
@@ -299,6 +327,7 @@ Convert to dictionary format
     def with_score(self, score):
         """
 Shallow copy the original node and add a semantic relevance score.
+
 Args:
     score: Relevance score.
 """
@@ -309,6 +338,7 @@ Args:
     def with_sim_score(self, score):
         """
 Shallow copy the original node and add a similarity score.
+
 Args:
     score: Similarity score.
 """
@@ -332,7 +362,7 @@ Args:
     text (str): Node content, mutually exclusive with query.
 """
     def __init__(self, query: str, answer: str, uid: Optional[str] = None, group: Optional[str] = None,
-                 embedding: Optional[Dict[str, List[float]]] = None, parent: Optional["DocNode"] = None,
+                 embedding: Optional[Dict[str, List[float]]] = None, parent: Optional['DocNode'] = None,
                  metadata: Optional[Dict[str, Any]] = None, global_metadata: Optional[Dict[str, Any]] = None,
                  *, text: Optional[str] = None):
         super().__init__(uid, query, group, embedding, parent, metadata, global_metadata=global_metadata, text=text)
@@ -350,8 +380,9 @@ Args:
         When set to MetadataMode.LLM, returns formatted QA pair.
         For other modes, returns base class text format.
 
-Returns:
-    str: The formatted text content.
+**Returns:**
+
+- str: The formatted text content.
 """
         if metadata_mode == MetadataMode.LLM:
             return f'query:\n{self.text}\nanswer\n{self._answer}'
@@ -394,7 +425,7 @@ Examples:
     >>> print(f"content属性: {content_representation}")    
     """
     def __init__(self, image_path: str, uid: Optional[str] = None, group: Optional[str] = None,
-                 embedding: Optional[Dict[str, List[float]]] = None, parent: Optional["DocNode"] = None,
+                 embedding: Optional[Dict[str, List[float]]] = None, parent: Optional['DocNode'] = None,
                  metadata: Optional[Dict[str, Any]] = None, global_metadata: Optional[Dict[str, Any]] = None,
                  *, text: Optional[str] = None):
         super().__init__(uid, None, group, embedding, parent, metadata, global_metadata=global_metadata, text=text)
@@ -433,10 +464,10 @@ Args:
 - Union[PIL.Image.Image, List[str], str]: The image content in the requested format.
 """
         if metadata_mode == MetadataMode.LLM:
-            return Image.open(self._image_path)
+            return PIL.Image.open(self._image_path)
         elif metadata_mode == MetadataMode.EMBED:
             image_base64, mime = _image_to_base64(self._image_path)
-            return [f"data:{mime};base64,{image_base64}"]
+            return [f'data:{mime};base64,{image_base64}']
         else:
             return self.get_text()
 
