@@ -24,7 +24,7 @@ import os
 import traceback
 
 DB_TYPES = ['mysql']
-ENABLE_DB = os.getenv("RAG_ENABLE_DB", "false").lower() == "true"
+ENABLE_DB = os.getenv('RAG_ENABLE_DB', 'false').lower() == 'true'
 
 
 class _Processor:
@@ -54,9 +54,9 @@ class _Processor:
             if image_nodes:
                 self._store.update_nodes(self._set_nodes_number(image_nodes))
                 self._create_nodes_recursive(image_nodes, LAZY_IMAGE_GROUP)
-            LOG.info("Add documents done!")
+            LOG.info('Add documents done!')
         except Exception as e:
-            LOG.error(f"Add documents failed: {e}, {traceback.format_exc()}")
+            LOG.error(f'Add documents failed: {e}, {traceback.format_exc()}')
             raise e
 
     def _set_nodes_number(self, nodes: List[DocNode]) -> List[DocNode]:
@@ -76,8 +76,8 @@ class _Processor:
         for group_name in self._store.activated_groups():
             group = self._node_groups.get(group_name)
             if group is None:
-                raise ValueError(f"Node group '{group_name}' does not exist. Please check the group name "
-                                 "or add a new one through `create_node_group`.")
+                raise ValueError(f'Node group "{group_name}" does not exist. Please check the group name '
+                                 'or add a new one through `create_node_group`.')
 
             if group['parent'] == p_name:
                 nodes = self._create_nodes_impl(p_nodes, group_name)
@@ -107,7 +107,7 @@ class _Processor:
 
     def _reparse_docs(self, group_name: str, doc_ids: List[str], doc_paths: List[str], metadatas: List[Dict]):
         kb_id = metadatas[0].get(RAG_KB_ID, None)
-        if group_name == "all":
+        if group_name == 'all':
             self._store.remove_nodes(doc_ids=doc_ids, kb_id=kb_id)
             removed_flag = False
             for wait_time in fibonacci_backoff():
@@ -117,7 +117,7 @@ class _Processor:
                     break
                 time.sleep(wait_time)
             if not removed_flag:
-                raise Exception(f"Failed to remove nodes for docs {doc_ids} from store")
+                raise Exception(f'Failed to remove nodes for docs {doc_ids} from store')
             self.add_doc(input_files=doc_paths, ids=doc_ids, metadatas=metadatas)
         else:
             p_nodes = self._store.get_nodes(group=self._node_groups[group_name]['parent'],
@@ -136,7 +136,7 @@ class _Processor:
                 break
             time.sleep(wait_time)
         if not removed_flag:
-            raise Exception(f"Failed to remove nodes for docs {doc_ids} group {cur_name} from store")
+            raise Exception(f'Failed to remove nodes for docs {doc_ids} group {cur_name} from store')
 
         t = self._node_groups[cur_name]['transform']
         transform = AdaptiveTransform(t) if isinstance(t, list) or t.pattern else make_transform(t, cur_name)
@@ -147,8 +147,8 @@ class _Processor:
         for group_name in self._store.activated_groups():
             group = self._node_groups.get(group_name)
             if group is None:
-                raise ValueError(f"Node group '{group_name}' does not exist. Please check the group name "
-                                 "or add a new one through `create_node_group`.")
+                raise ValueError(f'Node group "{group_name}" does not exist. Please check the group name '
+                                 'or add a new one through `create_node_group`.')
             if group['parent'] == cur_name:
                 self._reparse_group_recursive(p_nodes=nodes, cur_name=group_name, doc_ids=doc_ids)
 
@@ -156,7 +156,7 @@ class _Processor:
         self._store.update_doc_meta(doc_id=doc_id, metadata=metadata)
 
     def delete_doc(self, doc_ids: List[str] = None, kb_id: str = None) -> None:
-        LOG.info(f"delete_doc_ids: {doc_ids}")
+        LOG.info(f'delete_doc_ids: {doc_ids}')
         self._store.remove_nodes(kb_id=kb_id, doc_ids=doc_ids)
 
 
@@ -180,20 +180,20 @@ class DBInfo(BaseModel):
 
 class AddDocRequest(BaseModel):
     task_id: str
-    algo_id: Optional[str] = "__default__"
+    algo_id: Optional[str] = '__default__'
     file_infos: List[FileInfo]
     db_info: DBInfo
     feedback_url: Optional[str] = None
 
 
 class UpdateMetaRequest(BaseModel):
-    algo_id: Optional[str] = "__default__"
+    algo_id: Optional[str] = '__default__'
     file_infos: List[FileInfo]
     db_info: DBInfo
 
 
 class DeleteDocRequest(BaseModel):
-    algo_id: Optional[str] = "__default__"
+    algo_id: Optional[str] = '__default__'
     dataset_id: str
     doc_ids: List[str]
     db_info: Optional[DBInfo] = None
@@ -242,9 +242,9 @@ Examples:
                 self._feedback_url = config['process_feedback_service']
                 self._path_prefix = config['process_path_prefix']
             except Exception as e:
-                LOG.warning(f"Failed to get config: {e}, use env variables instead")
-                self._feedback_url = os.getenv("PROCESS_FEEDBACK_SERVICE", None)
-                self._path_prefix = os.getenv("PROCESS_PATH_PREFIX", None)
+                LOG.warning(f'Failed to get config: {e}, use env variables instead')
+                self._feedback_url = os.getenv('PROCESS_FEEDBACK_SERVICE', None)
+                self._path_prefix = os.getenv('PROCESS_PATH_PREFIX', None)
 
         def _init_components(self, server: bool):
             if server and not self._inited:
@@ -263,7 +263,7 @@ Examples:
                 self._worker_thread = threading.Thread(target=self._worker, daemon=True)
                 self._worker_thread.start()
             self._inited = True
-            LOG.info(f"[DocumentProcessor] init done. feedback {self._feedback_url}, prefix {self._path_prefix}")
+            LOG.info(f'[DocumentProcessor] init done. feedback {self._feedback_url}, prefix {self._path_prefix}')
 
         def register_algorithm(self, name: str, store: _DocumentStore, reader: ReaderBase,
                                node_groups: Dict[str, Dict], display_name: Optional[str] = None,
@@ -293,12 +293,12 @@ Examples:
             return self._inspectors[url]
 
         def _get_url_from_db_info(self, db_info: DBInfo):
-            return (f"mysql+pymysql://{db_info.user}:{db_info.password}"
-                    f"@{db_info.host}:{db_info.port}/{db_info.db_name}"
-                    "?charset=utf8mb4")
+            return (f'mysql+pymysql://{db_info.user}:{db_info.password}'
+                    f'@{db_info.host}:{db_info.port}/{db_info.db_name}'
+                    '?charset=utf8mb4')
 
         def create_table(self, db_info: DBInfo):
-            if db_info.db_type == "mysql":
+            if db_info.db_type == 'mysql':
                 try:
                     url = self._get_url_from_db_info(db_info)
                     engine = self._get_engine(url=url)
@@ -315,20 +315,20 @@ Examples:
                                       Column('creater', String(255), nullable=False),
                                       Column('dataset_id', String(255), nullable=False),
                                       Column('tags', JSON, nullable=True),
-                                      Column('created_at', TIMESTAMP, server_default=text("CURRENT_TIMESTAMP")))
+                                      Column('created_at', TIMESTAMP, server_default=text('CURRENT_TIMESTAMP')))
                         metadata.create_all(engine, tables=[table])
-                        LOG.info(f"Created table `{tbl}` in `{schema}`")
+                        LOG.info(f'Created table `{tbl}` in `{schema}`')
                 except Exception as e:
-                    LOG.error(f"Failed to create table `{tbl}` in `{schema}`: {e}")
+                    LOG.error(f'Failed to create table `{tbl}` in `{schema}`: {e}')
                     return
             else:
-                raise ValueError(f"Unsupported database type: {db_info.db_type}")
+                raise ValueError(f'Unsupported database type: {db_info.db_type}')
 
         def operate_db(self, db_info: DBInfo, operation: str,
                        file_infos: List[FileInfo] = None, params: Dict = None) -> None:
             db_type = db_info.db_type
             if db_type not in DB_TYPES:
-                raise ValueError(f"Unsupported db_type: {db_type}")
+                raise ValueError(f'Unsupported db_type: {db_type}')
             url = self._get_url_from_db_info(db_info)
             engine = self._get_engine(url=url)
             if operation == 'upsert':
@@ -336,7 +336,7 @@ Examples:
             elif operation == 'delete':
                 self._delete_records(engine, db_info, params)
             else:
-                raise ValueError(f"Unsupported operation: {operation}")
+                raise ValueError(f'Unsupported operation: {operation}')
 
         def _upsert_records(self, engine, db_info, file_infos):
             table_name = db_info['table_name']
@@ -345,16 +345,16 @@ Examples:
             table = metadata.tables[table_name]
             with engine.begin() as conn:
                 for file_info in file_infos:
-                    document_id = file_info.get("doc_id")
-                    file_path = file_info.get("file_path")
+                    document_id = file_info.get('doc_id')
+                    file_path = file_info.get('file_path')
                     if not document_id or not file_path:
-                        raise ValueError(f"Invalid file_info: {file_info}")
+                        raise ValueError(f'Invalid file_info: {file_info}')
 
-                    raw_infos = {"document_id": document_id, "file_name": os.path.basename(file_path),
-                                 "file_path": file_path, "description": file_info["metadata"].get("description", None),
-                                 "creater": file_info["metadata"].get("creater", None),
-                                 "dataset_id": file_info["metadata"].get(RAG_KB_ID, None),
-                                 "tags": file_info["metadata"].get("tags", []) or []}
+                    raw_infos = {'document_id': document_id, 'file_name': os.path.basename(file_path),
+                                 'file_path': file_path, 'description': file_info['metadata'].get('description', None),
+                                 'creater': file_info['metadata'].get('creater', None),
+                                 'dataset_id': file_info['metadata'].get(RAG_KB_ID, None),
+                                 'tags': file_info['metadata'].get('tags', []) or []}
                     infos = {}
                     for k, v in raw_infos.items():
                         if v is None:
@@ -364,8 +364,8 @@ Examples:
                         if isinstance(v, (list, dict)) and not v:
                             continue
                         infos[k] = v
-                    if "document_id" not in infos:
-                        infos["document_id"] = document_id
+                    if 'document_id' not in infos:
+                        infos['document_id'] = document_id
 
                     stmt = mysql_insert(table).values(**infos)
                     update_dict = {k: stmt.inserted[k] for k in infos if k != 'document_id'}
@@ -379,7 +379,7 @@ Examples:
             table = metadata.tables[table_name]
 
             with engine.begin() as conn:  # 自动提交或回滚事务
-                doc_ids = params.get("doc_ids", [])
+                doc_ids = params.get('doc_ids', [])
                 for document_id in doc_ids:
                     stmt = delete(table).where(table.c.document_id == document_id)
                     conn.execute(stmt)
@@ -388,57 +388,57 @@ Examples:
         async def get_algo_list(self) -> None:
             res = []
             for algo_id, processor in self._processors.items():
-                res.append({"algo_id": algo_id, "display_name": processor._display_name,
-                            "description": processor._description})
+                res.append({'algo_id': algo_id, 'display_name': processor._display_name,
+                            'description': processor._description})
             return BaseResponse(code=200, msg='success', data=res)
 
         @app.get('/group/info')
         async def get_group_info(self, algo_id: str) -> None:
             if algo_id not in self._processors:
-                return BaseResponse(code=400, msg=f"Invalid algo_id {algo_id}")
+                return BaseResponse(code=400, msg=f'Invalid algo_id {algo_id}')
             processor = self._processors[algo_id]
             infos = []
             for group_name in processor._store.activated_groups():
                 if group_name in processor._node_groups:
-                    group_info = {"name": group_name, "type": processor._node_groups[group_name].get('group_type'),
-                                  "display_name": processor._node_groups[group_name].get('display_name')}
+                    group_info = {'name': group_name, 'type': processor._node_groups[group_name].get('group_type'),
+                                  'display_name': processor._node_groups[group_name].get('display_name')}
                     infos.append(group_info)
-            LOG.info(f"Get group info for {algo_id} success with {infos}")
+            LOG.info(f'Get group info for {algo_id} success with {infos}')
             return BaseResponse(code=200, msg='success', data=infos)
 
         @app.post('/doc/add')
         async def async_add_doc(self, request: AddDocRequest):
-            LOG.info(f"Add doc for {request.model_dump_json()}")
+            LOG.info(f'Add doc for {request.model_dump_json()}')
             task_id = request.task_id
             algo_id = request.algo_id
             file_infos = request.file_infos
             db_info = request.db_info
             feedback_url = request.feedback_url
             if algo_id not in self._processors:
-                return BaseResponse(code=400, msg=f"Invalid algo_id {algo_id}")
+                return BaseResponse(code=400, msg=f'Invalid algo_id {algo_id}')
             if task_id in self._pending_task_ids or task_id in self._tasks:
                 return BaseResponse(code=400, msg=f'The task {task_id} already exists in queue', data=None)
             if self._path_prefix:
                 for file_info in file_infos:
                     file_info.file_path = create_file_path(path=file_info.file_path, prefix=self._path_prefix)
 
-            params = {"file_infos": file_infos, "db_info": db_info, "feedback_url": feedback_url}
+            params = {'file_infos': file_infos, 'db_info': db_info, 'feedback_url': feedback_url}
             if ENABLE_DB:
                 self.create_table(db_info=db_info)
 
             self._task_queue.put(('add', algo_id, task_id, params))
             self._pending_task_ids.add(task_id)
-            return BaseResponse(code=200, msg='task submit successfully', data={"task_id": task_id})
+            return BaseResponse(code=200, msg='task submit successfully', data={'task_id': task_id})
 
         @app.post('/doc/meta/update')
         async def async_update_meta(self, request: UpdateMetaRequest):
-            LOG.info(f"update doc meta for {request.model_dump_json()}")
+            LOG.info(f'update doc meta for {request.model_dump_json()}')
             algo_id = request.algo_id
             file_infos = request.file_infos
             db_info = request.db_info
 
             if algo_id not in self._processors:
-                return BaseResponse(code=400, msg=f"Invalid algo_id {algo_id}")
+                return BaseResponse(code=400, msg=f'Invalid algo_id {algo_id}')
 
             for file_info in file_infos:
                 doc_id = file_info.doc_id
@@ -446,7 +446,7 @@ Examples:
                 old_fut = self._update_futures.get(doc_id)
                 if old_fut and not old_fut.done():
                     cancelled = old_fut.cancel()
-                    LOG.info(f"Canceled previous update for {doc_id}: {cancelled}")
+                    LOG.info(f'Canceled previous update for {doc_id}: {cancelled}')
 
                 new_fut = self._update_executor.submit(self._processors[algo_id].update_doc_meta, doc_id=doc_id,
                                                        metadata=metadata)
@@ -465,20 +465,20 @@ Examples:
 
         @app.delete('/doc/delete')
         async def async_delete_doc(self, request: DeleteDocRequest) -> None:
-            LOG.info(f"Del doc for {request.model_dump_json()}")
+            LOG.info(f'Del doc for {request.model_dump_json()}')
             algo_id = request.algo_id
             dataset_id = request.dataset_id
             doc_ids = request.doc_ids
             db_info = request.db_info
 
             if algo_id not in self._processors:
-                return BaseResponse(code=400, msg=f"Invalid algo_id {algo_id}")
+                return BaseResponse(code=400, msg=f'Invalid algo_id {algo_id}')
 
             task_id = str(uuid.uuid4())
             self._task_queue.put(('delete', algo_id, task_id,
-                                  {"dataset_id": dataset_id, "doc_ids": doc_ids, "db_info": db_info}))
+                                  {'dataset_id': dataset_id, 'doc_ids': doc_ids, 'db_info': db_info}))
             self._pending_task_ids.add(task_id)
-            return BaseResponse(code=200, msg='task submit successfully', data={"task_id": task_id})
+            return BaseResponse(code=200, msg='task submit successfully', data={'task_id': task_id})
 
         @app.post('/doc/cancel')
         async def cancel_task(self, request: CancelDocRequest):
@@ -495,17 +495,17 @@ Examples:
                         self._tasks.pop(task_id, None)
                 else:
                     status = 0
-            return BaseResponse(code=200, msg="success" if status else "failed",
-                                data={"task_id": task_id, "status": status})
+            return BaseResponse(code=200, msg='success' if status else 'failed',
+                                data={'task_id': task_id, 'status': status})
 
         def _send_status_message(self, task_id: str, callback_path: str, success: bool,
-                                 error_code: str = "", error_msg: str = ""):
+                                 error_code: str = '', error_msg: str = ''):
             if self._feedback_url:
                 try:
                     full_url = self._feedback_url + callback_path
-                    payload = {"task_id": task_id, "status": 1 if success else 0, "error_code": error_code,
-                               "error_msg": error_msg}
-                    headers = {"Content-Type": "application/json"}
+                    payload = {'task_id': task_id, 'status': 1 if success else 0, 'error_code': error_code,
+                               'error_msg': error_msg}
+                    headers = {'Content-Type': 'application/json'}
                     res = None
                     for wait_time in fibonacci_backoff(max_retries=3):
                         try:
@@ -513,18 +513,18 @@ Examples:
                             if res.status_code == 200:
                                 break
                             LOG.warning(
-                                f"Task-{task_id}: Unexpected status {res.status_code}, retrying in {wait_time}s…")
+                                f'Task-{task_id}: Unexpected status {res.status_code}, retrying in {wait_time}s…')
                         except Exception as e:
-                            LOG.error(f"Task-{task_id}: Request failed: {e}, retrying in {wait_time}s…")
+                            LOG.error(f'Task-{task_id}: Request failed: {e}, retrying in {wait_time}s…')
                         time.sleep(wait_time)
 
                     if res is None:
-                        raise RuntimeError("Failed to send feedback—no response received after retries")
+                        raise RuntimeError('Failed to send feedback—no response received after retries')
                     res.raise_for_status()
                 except Exception as e:
-                    LOG.error(f"Task-{task_id}: Failed to send feedback to {full_url}: {e}")
+                    LOG.error(f'Task-{task_id}: Failed to send feedback to {full_url}: {e}')
             else:
-                LOG.error("process_feedback_service is not set")
+                LOG.error('process_feedback_service is not set')
 
         def _exec_add_task(self, algo_id, task_id, params):
             try:
@@ -563,21 +563,21 @@ Examples:
                                                        metadatas=reparse_metadatas)
                 else:
                     LOG.error(
-                        f"Task-{task_id}: add task error, no input files {input_files} or reparse group {reparse_group}"
+                        f'Task-{task_id}: add task error, no input files {input_files} or reparse group {reparse_group}'
                     )
                 self._tasks[task_id] = (future, callback_path)
                 self._pending_task_ids.remove(task_id)
             except Exception as e:
-                LOG.error(f"Task-{task_id}: add task error {e}")
+                LOG.error(f'Task-{task_id}: add task error {e}')
 
         def _exec_delete_task(self, algo_id, task_id, params):
-            dataset_id = params.get("dataset_id")
-            doc_ids = params.get("doc_ids")
+            dataset_id = params.get('dataset_id')
+            doc_ids = params.get('doc_ids')
             future = self._delete_executor.submit(
                 self._processors[algo_id].delete_doc, dataset_id=dataset_id, doc_ids=doc_ids
             )
-            if ENABLE_DB and params.get("db_info") is not None:
-                db_info = params.get("db_info")
+            if ENABLE_DB and params.get('db_info') is not None:
+                db_info = params.get('db_info')
                 future.add_done_callback(lambda fut: self.operate_db(db_info, 'delete', params=params))
             self._tasks[task_id] = (future, None)
             self._pending_task_ids.remove(task_id)
@@ -601,16 +601,16 @@ Examples:
                             ex = future.exception()
                             if callback_path and not ex:
                                 self._send_status_message(task_id=task_id, callback_path=callback_path, success=True,
-                                                          error_code="", error_msg="")
+                                                          error_code='', error_msg='')
                             elif callback_path and ex:
                                 self._send_status_message(task_id=task_id, callback_path=callback_path, success=False,
                                                           error_code=type(ex).__name__, error_msg=str(ex))
-                                LOG.error(f"task {task_id} failed: {str(ex)}")
+                                LOG.error(f'task {task_id} failed: {str(ex)}')
                             elif ex:
-                                LOG.error(f"task {task_id} failed: {str(ex)}")
+                                LOG.error(f'task {task_id} failed: {str(ex)}')
                     for task_id in task_need_pop:
                         self._tasks.pop(task_id)
-                        LOG.info(f"task {task_id} done")
+                        LOG.info(f'task {task_id} done')
                     time.sleep(5)
 
         def __call__(self, func_name: str, *args, **kwargs):
@@ -643,7 +643,10 @@ Args:
     store (StoreBase): Storage instance for managing document data.
     reader (ReaderBase): Reader instance for parsing document content.
     node_groups (Dict[str, Dict]): Node group configuration information.
+    display_name (Optional[str]): Display name for the algorithm, defaults to None.
+    description (Optional[str]): Description of the algorithm, defaults to None.
     force_refresh (bool): Whether to force refresh existing algorithm. Defaults to False.
+    **kwargs: Additional arguments.
 
 **Notes:**
 - If algorithm name exists and force_refresh is False, registration will be skipped
@@ -675,7 +678,7 @@ Examples:
     )
     ```
     """
-        self._dispatch("register_algorithm", name, store, reader, node_groups,
+        self._dispatch('register_algorithm', name, store, reader, node_groups,
                        display_name, description, force_refresh, **kwargs)
 
     def drop_algorithm(self, name: str, clean_db: bool = False) -> None:
@@ -701,4 +704,4 @@ Examples:
     processor.drop_algorithm("pdf_processor", clean_db=True)
     ```
     """
-        return self._dispatch("drop_algorithm", name, clean_db)
+        return self._dispatch('drop_algorithm', name, clean_db)
