@@ -2,11 +2,11 @@ from .doc_analysis import DocGenreAnalyser, DocInfoSchemaAnalyser, DocInfoExtrac
 from .doc_processor import DocToDbProcessor, extract_db_schema_from_files
 
 __all__ = [
-    "extract_db_schema_from_files",
-    "DocGenreAnalyser",
-    "DocInfoSchemaAnalyser",
-    "DocInfoExtractor",
-    "DocInfoSchemaItem",
-    "DocInfoSchema",
-    "DocToDbProcessor",
+    'extract_db_schema_from_files',
+    'DocGenreAnalyser',
+    'DocInfoSchemaAnalyser',
+    'DocInfoExtractor',
+    'DocInfoSchemaItem',
+    'DocInfoSchema',
+    'DocToDbProcessor',
 ]
