@@ -33,21 +33,24 @@ class _MetaDocument(_MetaBind):
 
 
 class Document(ModuleBase, BuiltinGroups, metaclass=_MetaDocument):
-    """Initialize a document module with an optional user interface.
+    """Initialize a document management module with optional embedding, storage, and user interface.
 
-This constructor initializes a document module that can have an optional user interface. If the user interface is enabled, it also provides a UI to manage the document operation interface and offers a web page for user interface interaction.
+The ``Document`` module provides a unified interface for managing document datasets, including support for local files, cloud-based files, or temporary document files. It can optionally run with a document manager service or a web UI, and supports multiple embedding models and custom storage backends.
 
 Args:
-    dataset_path (str): The path to the dataset directory. This directory should contain the documents to be managed by the document module.
-    embed (Optional[Union[Callable, Dict[str, Callable]]]): The object used to generate document embeddings. If you need to generate multiple embeddings for the text, you need to specify multiple embedding models in a dictionary format. The key identifies the name corresponding to the embedding, and the value is the corresponding embedding model.
-    create_ui (bool): [Deprecated] Whether to create a user interface. Use 'manager' parameter instead.
-    manager (bool, optional): A flag indicating whether to create a user interface for the document module. Defaults to False.
-    server (Union[bool, int]): Server configuration. True for default server, False for no server, or an integer port number for custom server.
-    name (Optional[str]): Name identifier for this document collection. Required for cloud services.
-    launcher (optional): An object or function responsible for launching the server module. If not provided, the default asynchronous launcher from `lazyllm.launchers` is used (`sync=False`).
-    doc_fields (optional): Configure the fields that need to be stored and retrieved along with their corresponding types (currently only used by the Milvus backend).
-    doc_files (Optional[List[str]]): List of temporary document files (alternative to dataset_path).When used, dataset_path must be None and only map store is supported.
-    store_conf (optional): Configure which storage backend, MapStore is the default choice.      
+    dataset_path (Optional[str]): Path to the dataset directory. If not found, the system will attempt to locate it in ``lazyllm.config["data_path"]``.
+    embed (Optional[Union[Callable, Dict[str, Callable]]]): Embedding function or mapping of embedding functions. When a dictionary is provided, keys are embedding names and values are embedding models.
+    manager (Union[bool, str], optional): Whether to enable the document manager. If ``True``, launches a manager service. If ``'ui'``, also enables the document management web UI. Defaults to ``False``.
+    server (Union[bool, int], optional): Whether to run a server interface for knowledge bases. ``True`` enables a default server, an integer specifies a custom port, and ``False`` disables it. Defaults to ``False``.
+    name (Optional[str]): Name identifier for this document collection. Defaults to the system default name.
+    launcher (Optional[Launcher]): Launcher instance for managing server processes. Defaults to a remote asynchronous launcher.
+    store_conf (Optional[Dict]): Storage configuration. Defaults to in-memory MapStore.
+    doc_fields (Optional[Dict[str, DocField]]): Metadata field configuration for storing and retrieving document attributes.
+    cloud (bool): Whether the dataset is stored in the cloud. Defaults to ``False``.
+    doc_files (Optional[List[str]]): Temporary document files. When used, ``dataset_path`` must be ``None``. Only MapStore is supported in this mode.
+    processor (Optional[DocumentProcessor]): Document pre-processing module.
+    display_name (Optional[str]): Human-readable display name for this document module. Defaults to the collection name.
+    description (Optional[str]): Description of the document collection. Defaults to ``"algorithm description"``.
 
 
 Examples:
@@ -88,12 +91,12 @@ Examples:
                      launcher: Optional[Launcher] = None, store_conf: Optional[Dict] = None,
                      doc_fields: Optional[Dict[str, DocField]] = None, cloud: bool = False,
                      doc_files: Optional[List[str]] = None, processor: Optional[DocumentProcessor] = None,
-                     display_name: Optional[str] = "", description: Optional[str] = "algorithm description"):
+                     display_name: Optional[str] = '', description: Optional[str] = 'algorithm description'):
             super().__init__()
             self._origin_path, self._doc_files, self._cloud = dataset_path, doc_files, cloud
 
             if dataset_path and not os.path.exists(dataset_path):
-                defatult_path = os.path.join(lazyllm.config["data_path"], dataset_path)
+                defatult_path = os.path.join(lazyllm.config['data_path'], dataset_path)
                 if os.path.exists(defatult_path):
                     dataset_path = defatult_path
             elif dataset_path:
@@ -172,11 +175,11 @@ Examples:
             return super().__new__(cls)
 
     def __init__(self, dataset_path: Optional[str] = None, embed: Optional[Union[Callable, Dict[str, Callable]]] = None,
-                 create_ui: bool = False, manager: Union[bool, str, "Document._Manager", DocumentProcessor] = False,
+                 create_ui: bool = False, manager: Union[bool, str, 'Document._Manager', DocumentProcessor] = False,
                  server: Union[bool, int] = False, name: Optional[str] = None, launcher: Optional[Launcher] = None,
                  doc_files: Optional[List[str]] = None, doc_fields: Dict[str, DocField] = None,
-                 store_conf: Optional[Dict] = None, display_name: Optional[str] = "",
-                 description: Optional[str] = "algorithm description"):
+                 store_conf: Optional[Dict] = None, display_name: Optional[str] = '',
+                 description: Optional[str] = 'algorithm description'):
         super().__init__()
         if create_ui:
             lazyllm.LOG.warning('`create_ui` for Document is deprecated, use `manager` instead')
@@ -226,17 +229,35 @@ Examples:
             files_list.extend(files)
         return files_list
 
+    @property
+    def url(self):
+        assert isinstance(self._manager._kbs, ServerModule), 'Document is not a service, please set `manager` to `True`'
+        return self._manager._kbs._url
+
     def connect_sql_manager(
         self,
         sql_manager: SqlManager,
         schma: Optional[DocInfoSchema] = None,
         force_refresh: bool = True,
     ):
+        """Connect to the SQL manager and initialize the document-to-database processor.
+
+This method validates the database connection and updates or resets the database table schema based on the provided document schema. If the existing schema differs from the new one, ``force_refresh=True`` must be set to enforce a reset.
+
+Args:
+    sql_manager (SqlManager): SQL manager instance for database connection and operations.
+    schma (Optional[DocInfoSchema]): Document table schema definition, including field names, types, and descriptions.
+    force_refresh (bool, optional): Whether to force refresh the database schema when changes are detected. Defaults to ``True``.
+
+Raises:
+    RuntimeError: If the database connection fails.
+    AssertionError: If schema is missing or schema change occurs without setting ``force_refresh``.
+"""
         def format_schema_to_dict(schema: DocInfoSchema):
             if schema is None:
                 return None, None
-            desc_dict = {ele["key"]: ele["desc"] for ele in schema}
-            type_dict = {ele["key"]: ele["type"] for ele in schema}
+            desc_dict = {ele['key']: ele['desc'] for ele in schema}
+            type_dict = {ele['key']: ele['type'] for ele in schema}
             return desc_dict, type_dict
 
         def compare_schema(old_schema: DocInfoSchema, new_schema: DocInfoSchema):
@@ -250,12 +271,12 @@ Examples:
         pre_doc_table_schema = None
         if self._doc_to_db_processor:
             pre_doc_table_schema = self._doc_to_db_processor.doc_info_schema
-        assert pre_doc_table_schema or schma, "doc_table_schma must be given"
+        assert pre_doc_table_schema or schma, 'doc_table_schma must be given'
 
         schema_equal = compare_schema(pre_doc_table_schema, schma)
         assert (
             schema_equal or force_refresh is True
-        ), "When changing doc_table_schema, force_refresh should be set to True"
+        ), 'When changing doc_table_schema, force_refresh should be set to True'
 
         # 2. Init handler if needed
         need_init_processor = False
@@ -270,32 +291,70 @@ Examples:
 
         # 3. Reset doc_table_schema if needed
         if schma and not schema_equal:
-            # This api call will clear existing db table "lazyllm_doc_elements"
+            # This api call will clear existing db table 'lazyllm_doc_elements'
             self._doc_to_db_processor._reset_doc_info_schema(schma)
 
     def get_sql_manager(self):
+        """Get the SQL manager instance currently bound to this document module.
+
+**Returns:**
+
+- SqlManager: The connected SQL manager instance.
+"""
         if self._doc_to_db_processor is None:
-            raise ValueError("Please call connect_sql_manager to init handler first")
+            raise ValueError('Please call connect_sql_manager to init handler first')
         return self._doc_to_db_processor.sql_manager
 
     def extract_db_schema(
         self, llm: Union[OnlineChatModule, TrainableModule], print_schema: bool = False
     ) -> DocInfoSchema:
+        """Extract the database schema from the dataset using a large language model.
+
+This method scans all files in the dataset and uses the LLM to extract document information schema. Optionally, the schema can be printed to the logs.
+
+Args:
+    llm (Union[OnlineChatModule, TrainableModule]): Model used to parse documents and extract schema.
+    print_schema (bool, optional): Whether to log the extracted schema. Defaults to ``False``.
+
+**Returns:**
+
+- DocInfoSchema: The extracted database schema.
+"""
         file_paths = self._list_all_files_in_dataset()
         schema = extract_db_schema_from_files(file_paths, llm)
         if print_schema:
-            lazyllm.LOG.info(f"Extracted Schema:\n\t{schema}\n")
+            lazyllm.LOG.info(f'Extracted Schema:\n\t{schema}\n')
         return schema
 
     def update_database(self, llm: Union[OnlineChatModule, TrainableModule]):
-        assert self._doc_to_db_processor, "Please call connect_db to init handler first"
+        """Update the database with information extracted from documents using a large language model.
+
+This method iterates through all files in the dataset, extracts structured information, and exports it into the database.
+
+Args:
+    llm (Union[OnlineChatModule, TrainableModule]): Model used to parse documents and extract information.
+"""
+        assert self._doc_to_db_processor, 'Please call connect_db to init handler first'
         file_paths = self._list_all_files_in_dataset()
         info_dicts = self._doc_to_db_processor.extract_info_from_docs(llm, file_paths)
         self._doc_to_db_processor.export_info_to_db(info_dicts)
 
     @deprecated('Document(dataset_path, manager=doc.manager, name=xx, doc_fields=xx, store_conf=xx)')
     def create_kb_group(self, name: str, doc_fields: Optional[Dict[str, DocField]] = None,
-                        store_conf: Optional[Dict] = None) -> "Document":
+                        store_conf: Optional[Dict] = None) -> 'Document':
+        """Create a new knowledge base group (KB Group) and return a document object bound to that group.
+
+Knowledge base groups are used to partition different document collections within the same document module. Each group can have independent field definitions and storage configurations.
+
+Args:
+    name (str): Name of the knowledge base group.
+    doc_fields (Optional[Dict[str, DocField]]): Document field definitions, specifying field names, types, and descriptions.
+    store_conf (Optional[Dict]): Storage configuration, defining the backend and its parameters.
+
+**Returns:**
+
+- Document: A copy of the document object bound to the newly created knowledge base group.
+"""
         self._manager.add_kb_group(name=name, doc_fields=doc_fields, store_conf=store_conf)
         doc = copy.copy(self)
         doc._curr_group = name
@@ -311,15 +370,32 @@ Examples:
     @property
     def manager(self): return self._manager._processor or self._manager
 
-    def activate_group(self, group_name: str, embed_keys: Optional[Union[str, List[str]]] = None):
-        if isinstance(embed_keys, str): embed_keys = [embed_keys]
-        elif embed_keys is None: embed_keys = []
-        self._impl.activate_group(group_name, embed_keys)
+    def activate_group(self, group_name: str, embed_keys: Optional[Union[str, List[str]]] = None,
+                       enable_embed: bool = True):
+        """Activate the specified knowledge base group, optionally enabling specific embedding keys.
 
-    def activate_groups(self, groups: Union[str, List[str]]):
+After activation, the document module will perform retrieval and storage operations within the given group. If no embedding keys are provided, all available embeddings will be enabled by default.
+
+Args:
+    group_name (str): Name of the knowledge base group to activate.
+    embed_keys (Optional[Union[str, List[str]]]): Embedding keys to enable, either as a string or a list of strings. Defaults to an empty list, enabling all embeddings.
+"""
+        if embed_keys and not enable_embed:
+            raise ValueError('`enable_embed` must be set to True when `embed_keys` is provided')
+        if isinstance(embed_keys, str): embed_keys = [embed_keys]
+        self._impl.activate_group(group_name, embed_keys, enable_embed)
+
+    def activate_groups(self, groups: Union[str, List[str]], **kwargs):
+        """Activate multiple knowledge base groups in batch.
+
+This method iteratively calls `activate_group` to activate all the provided groups.
+
+Args:
+    groups (Union[str, List[str]]): A single group name or a list of group names to activate.
+"""
         if isinstance(groups, str): groups = [groups]
         for group in groups:
-            self.activate_group(group)
+            self.activate_group(group, **kwargs)
 
     @DynamicDescriptor
     def create_node_group(self, name: str = None, *, transform: Callable, parent: str = LAZY_ROOT_NAME,
@@ -434,23 +510,58 @@ Examples:
         return cls.add_reader(pattern, func)
 
     def get_store(self):
+        """Get the storage placeholder object.
+
+This method returns a placeholder for the storage layer, allowing deferred binding of the actual storage implementation. 
+The caller can use this object for storage-related configuration or extension.
+
+**Returns:**
+
+- StorePlaceholder: Storage placeholder object.
+"""
         return StorePlaceholder()
 
     def get_embed(self):
+        """Get the embedding placeholder object.
+
+This method returns a placeholder for the embedding layer, allowing deferred binding of the actual embedding implementation. 
+The caller can use this object for embedding-related configuration or extension.
+
+**Returns:**
+
+- EmbedPlaceholder: Embedding placeholder object.
+"""
         return EmbedPlaceholder()
 
     def register_index(self, index_type: str, index_cls: IndexBase, *args, **kwargs) -> None:
+        """Register a new index type.
+
+This method allows users to register a new index type for the document module, enabling extension of retrieval capabilities. 
+Once registered, the index can be referenced by its type.
+
+Args:
+    index_type (str): Name of the index type.
+    index_cls (IndexBase): Index class, must inherit from ``IndexBase``.
+    *args: Variable arguments for index initialization.
+    **kwargs: Keyword arguments for index initialization.
+"""
         self._impl.register_index(index_type, index_cls, *args, **kwargs)
 
     def _forward(self, func_name: str, *args, **kw):
         return self._manager(self._curr_group, func_name, *args, **kw)
 
     def find_parent(self, target) -> Callable:
-        """
-Find the parent node of the specified node.
+        """Find the parent node of the target.
+
+This method returns a callable object that performs a deferred parent lookup operation. 
+It invokes the underlying implementation to retrieve the parent node of the specified target.
 
 Args:
-    group (str): The name of the node group for which to find the parent.
+    target: The target for which to find the parent.
+
+**Returns:**
+
+- Callable: Callable object for performing the parent lookup.
 
 
 Examples:
@@ -466,11 +577,17 @@ Examples:
         return functools.partial(self._forward, 'find_parent', group=target)
 
     def find_children(self, target) -> Callable:
-        """
-Find the child nodes of the specified node.
+        """Find the children nodes of the target.
+
+This method returns a callable object that performs a deferred children lookup operation. 
+It invokes the underlying implementation to retrieve all children nodes of the specified target.
 
 Args:
-    group (str): The name of the node group for which to find the children.
+    target: The target for which to find the children.
+
+**Returns:**
+
+- Callable: Callable object for performing the children lookup.
 
 
 Examples:
@@ -486,19 +603,40 @@ Examples:
         return functools.partial(self._forward, 'find_children', group=target)
 
     def find(self, target) -> Callable:
+        """Find the target.
+
+This method returns a callable object that performs a deferred lookup operation. 
+It invokes the underlying implementation to retrieve the specified target.
+
+Args:
+    target: The target to be found.
+
+**Returns:**
+
+- Callable: Callable object for performing the target lookup.
+"""
         return functools.partial(self._forward, 'find', group=target)
 
     def forward(self, *args, **kw) -> List[DocNode]:
         return self._forward('retrieve', *args, **kw)
 
     def clear_cache(self, group_names: Optional[List[str]] = None) -> None:
+        """Clear cache.
+
+This method clears the cache of the document module. A list of group names can be specified to 
+clear cache for specific groups. If no group names are provided, all group caches will be cleared.
+
+Args:
+    group_names (Optional[List[str]]): List of group names whose cache should be cleared. 
+        Defaults to ``None``, meaning clear all caches.
+"""
         return self._forward('clear_cache', group_names)
 
     def _get_post_process_tasks(self):
         return lazyllm.pipeline(lambda *a: self._forward('_lazy_init'))
 
     def __repr__(self):
-        return lazyllm.make_repr("Module", "Document", manager=hasattr(self._manager, '_manager'),
+        return lazyllm.make_repr('Module', 'Document', manager=hasattr(self._manager, '_manager'),
                                  server=isinstance(self._manager._kbs, ServerModule))
 
 class UrlDocument(ModuleBase):
@@ -517,7 +655,7 @@ Args:
 
     def _forward(self, func_name: str, *args, **kwargs):
         args = (self._curr_group, func_name, *args)
-        return self._manager._call("__call__", *args, **kwargs)
+        return self._manager._call('__call__', *args, **kwargs)
 
     def find(self, target) -> Callable:
         """Creates a partially applied function to find a specified target within the current document group.
