@@ -1,5 +1,5 @@
 from pathlib import Path
-from fsspec import AbstractFileSystem
+from lazyllm.thirdparty import fsspec
 from typing import Optional, List
 
 from lazyllm.thirdparty import docx2txt
@@ -13,10 +13,11 @@ Args:
     file (Path): Path to the `.docx` file.
     fs (Optional[AbstractFileSystem]): Optional file system object for custom reading.
 
-Returns:
-    List[DocNode]: A list containing the extracted text content as `DocNode` instances.
+**Returns:**
+
+- List[DocNode]: A list containing the extracted text content as `DocNode` instances.
 """
-    def _load_data(self, file: Path, fs: Optional[AbstractFileSystem] = None) -> List[DocNode]:
+    def _load_data(self, file: Path, fs: Optional['fsspec.AbstractFileSystem'] = None) -> List[DocNode]:
         if not isinstance(file, Path): file = Path(file)
 
         if fs:
