@@ -2,4 +2,4 @@ from .map_store import MapStore
 from .sensecore_store import SenseCoreStore
 from .hybrid_store import HybridStore
 
-__all__ = ["MapStore", "SenseCoreStore", "HybridStore"]
+__all__ = ['MapStore', 'SenseCoreStore', 'HybridStore']
