@@ -21,6 +21,7 @@ from lazyllm.components.formatter import encode_query_with_filepaths
 class TransformArgs():
     """
 A document transformation parameter container for centralized management of processing configurations.
+
 Args:
     f (Union[str, Callable]): Transformation function or registered function name.Can be either a callable function or a string identifier for registered functions.
     trans_node (bool): Whether to transform node types.When True, modifies the document node structure during processing.
@@ -94,6 +95,7 @@ def split_text_keep_separator(text: str, separator: str) -> List[str]:
 class NodeTransform(ABC):
     """
 Processes document nodes in batch, supporting both single-threaded and multi-threaded modes.
+
 Args:
     num_workers(int): Controls whether multi-threading is enabled (enabled when >0).
 
@@ -115,6 +117,7 @@ Examples:
     ) -> List[DocNode]:
         """
 Process documents in batch with node group transformation.
+
 Args:
     documents (Union[DocNode, List[DocNode]]): Input node(s) to process.
     node_group (str): Target transformation group name.
@@ -143,6 +146,7 @@ Args:
     def transform(self, document: DocNode, **kwargs) -> List[Union[str, DocNode]]:
         """
 [Abstract] Core transformation logic to implement.
+
 Args:
     document (DocNode): Input document node.
     **kwargs: Implementation-specific parameters.
@@ -152,6 +156,7 @@ Args:
     def with_name(self, name: Optional[str], *, copy: bool = True) -> 'NodeTransform':
         """
 Set transformer name with optional copying.
+
 Args:
     name (Optional[str]): New name for the transformer.
     copy (bool): Whether to return a copy. Default True.
@@ -320,6 +325,16 @@ Examples:
         )
 
     def split_text(self, text: str, metadata_size: int) -> List[str]:
+        """Split the input text into multiple chunks based on sentence boundaries and chunk size.
+
+Args:
+    text (str): The text to be split.
+    metadata_size (int): Length occupied by additional metadata, used to adjust effective chunk size.
+
+**Returns:**
+
+- List[str]: List of resulting text chunks.
+"""
         if text == '':
             return ['']
         effective_chunk_size = self.chunk_size - metadata_size
@@ -473,14 +488,15 @@ Args:
     node (DocNode): The document node to be transformed.
     **kwargs: Additional keyword arguments passed to the transformation function.
 
-Returns:
-    List[Union[str, DocNode]]: The transformed results, which can be either strings or DocNode objects depending on the function implementation.
+**Returns:**
+
+- List[Union[str, DocNode]]: The transformed results, which can be either strings or DocNode objects depending on the function implementation.
 """
         return self._func(node if self._trans_node else node.get_text())
 
 
 templates = dict(
-    en=dict(summary="""
+    en=dict(summary='''
 ## Role: Text Summarizer
 You are a text summarization engine responsible for analyzing user input text and providing a concise summary based on \
 the requested task.
@@ -500,7 +516,7 @@ My mission is to assist you in building the most powerful large-scale model appl
 Introduction of AI robot LazyLLM
 
 You should not have any unnecessary output. Lets begin:
-""", keywords="""
+''', keywords='''
 ## Role: Keyword Extractor
 You are a text keyword extraction engine responsible for analyzing user input text and providing a extracting relevant \
 keywords based on the requested task.
@@ -514,13 +530,13 @@ The input is a string contains the user's raw input text
 
 ## Example:
 #input:
-"Hello, I am an AI robot developed by SenseTime, named LazyLLM.
-My mission is to assist you in building the most powerful large-scale model applications with minimal cost."
+'Hello, I am an AI robot developed by SenseTime, named LazyLLM.
+My mission is to assist you in building the most powerful large-scale model applications with minimal cost.'
 #output:
 LazyLLM, SenseTime, AI robot, large-scale model applications
 
 You should not have any unnecessary output. Lets begin:
-""", qa="""
+''', qa='''
 ## Role: QA-pair Extractor
 You are a question-answer extraction engine responsible for analyzing user input text and providing a extracting \
 query and answer based on the requested task.
@@ -534,8 +550,8 @@ The input is a string contains the user's raw input text
 
 ## Example:
 #input:
-"Hello, I am an AI robot developed by SenseTime, named LazyLLM.
-My mission is to assist you in building the most powerful large-scale model applications with minimal cost."
+'Hello, I am an AI robot developed by SenseTime, named LazyLLM.
+My mission is to assist you in building the most powerful large-scale model applications with minimal cost.'
 #output:
 Q: What is LazyLLM developed by?
 A: LazyLLM is developed by SenseTime.
@@ -543,7 +559,7 @@ Q: What can LazyLLM do?
 A: LazyLLM can assist you in building the most powerful large-scale model applications with minimal cost.
 
 You should not have any unnecessary output. Lets begin:
-""", qa_img="""
+''', qa_img='''
 ## Role: Q&A Pair Extraction Engine
 You are a Q&A pair extraction engine, responsible for analyzing and extracting Q&A pairs from images.
 
@@ -560,8 +576,8 @@ Q: What is the pig doing?
 A: The pig is running on the lawn.
 
 You should not output any extra characters. Let's start now.
-"""),
-    zh=dict(summary="""
+'''),
+    zh=dict(summary='''
 ## 角色：文本摘要
 你是一个文本摘要引擎，负责分析用户输入的文本，并根据请求任务提供简洁的摘要。
 
@@ -579,7 +595,7 @@ You should not output any extra characters. Let's start now.
 人工智能机器人LazyLLM的简介
 
 你不应输出任何多余的字符，现在我们开始吧
-""", keywords="""
+''', keywords='''
 ## 角色：关键词提取引擎
 你是一个关键词提取引擎，负责分析用户输入的文本，提取其中的关键词。
 
@@ -597,7 +613,7 @@ You should not output any extra characters. Let's start now.
 LazyLLM, 商汤, 人工智能机器人, 大模型应用
 
 你不应输出任何多余的字符，现在我们开始吧
-""", qa="""
+''', qa='''
 ## 角色：问答对提取引擎
 你是一个问答对提取引擎，负责分析用户输入的文本，提取其中的问答对。
 
@@ -618,7 +634,7 @@ Q: LazyLLM能做什么？
 A: LazyLLM可以协助用户，用最低的成本，构建最强大的大模型应用
 
 你不应输出任何多余的字符，现在我们开始吧
-""", qa_img="""
+''', qa_img='''
 ## 角色：问答对提取引擎
 你是一个问答对提取引擎，负责分析从图像中提取其中的问答对。
 
@@ -635,7 +651,7 @@ Q: 小猪在做啥呢？
 A: 小猪在草坪上奔跑。
 
 你不应输出任何多余的字符，现在我们开始吧
-"""))
+'''))
 
 class LLMParser(NodeTransform):
     """
@@ -701,6 +717,6 @@ Examples:
             return [s.strip() for s in input.split(',')]
         elif self._task_type in ('qa', 'qa_img'):
             return [QADocNode(query=q.strip()[3:].strip(), answer=a.strip()[3:].strip()) for q, a in zip(
-                list(filter(None, map(str.strip, input.split("\n"))))[::2],
-                list(filter(None, map(str.strip, input.split("\n"))))[1::2])]
+                list(filter(None, map(str.strip, input.split('\n'))))[::2],
+                list(filter(None, map(str.strip, input.split('\n'))))[1::2])]
         return input
