@@ -1,4 +1,3 @@
-import concurrent
 import hashlib
 import json
 import os
@@ -13,10 +12,11 @@ from concurrent.futures import ThreadPoolExecutor, as_completed
 from typing import (Any, Callable, Dict, Generator, List, Optional, Set, Tuple,
                     Union)
 from urllib.parse import urlsplit, urlunsplit
+from numbers import Integral
 
 import pydantic
 import sqlalchemy
-from fastapi import UploadFile
+from lazyllm.thirdparty import fastapi
 from filelock import FileLock
 from pydantic import BaseModel
 from sqlalchemy import Column, Row, bindparam, insert, select, update
@@ -29,20 +29,20 @@ from lazyllm.common import override
 from lazyllm.common.queue import sqlite3_check_threadsafety
 from lazyllm.thirdparty import tarfile
 
-from .doc_node import DocNode
+from .doc_node import DocNode, MetadataMode
 from .global_metadata import RAG_DOC_ID, RAG_DOC_PATH
 from .index_base import IndexBase
 from pathlib import Path
 
 # min(32, (os.cpu_count() or 1) + 4) is the default number of workers for ThreadPoolExecutor
 config.add(
-    "max_embedding_workers",
+    'max_embedding_workers',
     int,
     min(32, (os.cpu_count() or 1) + 4),
-    "MAX_EMBEDDING_WORKERS",
+    'MAX_EMBEDDING_WORKERS',
 )
 
-config.add("default_dlmanager", str, "sqlite", "DEFAULT_DOCLIST_MANAGER")
+config.add('default_dlmanager', str, 'sqlite', 'DEFAULT_DOCLIST_MANAGER')
 
 def gen_docid(file_path: str) -> str:
     return hashlib.sha256(file_path.encode()).hexdigest()
@@ -53,7 +53,7 @@ class KBDataBase(DeclarativeBase):
 
 
 class KBOperationLogs(KBDataBase):
-    __tablename__ = "operation_logs"
+    __tablename__ = 'operation_logs'
     id = Column(sqlalchemy.Integer, primary_key=True, autoincrement=True)
     log = Column(sqlalchemy.Text, nullable=False)
     created_at = Column(sqlalchemy.DateTime, default=sqlalchemy.func.now(), nullable=False)
@@ -61,7 +61,7 @@ class KBOperationLogs(KBDataBase):
 
 DocPartRow = Row
 class KBDocument(KBDataBase):
-    __tablename__ = "documents"
+    __tablename__ = 'documents'
 
     doc_id = Column(sqlalchemy.Text, primary_key=True)
     filename = Column(sqlalchemy.Text, nullable=False, index=True)
@@ -73,7 +73,7 @@ class KBDocument(KBDataBase):
     count = Column(sqlalchemy.Integer, default=0)
 
 class KBGroup(KBDataBase):
-    __tablename__ = "document_groups"
+    __tablename__ = 'document_groups'
 
     group_id = Column(sqlalchemy.Integer, primary_key=True, autoincrement=True)
     group_name = Column(sqlalchemy.String, nullable=False, unique=True)
@@ -82,11 +82,11 @@ DocMetaChangedRow = Row
 GroupDocPartRow = Row
 
 class KBGroupDocuments(KBDataBase):
-    __tablename__ = "kb_group_documents"
+    __tablename__ = 'kb_group_documents'
 
     id = Column(sqlalchemy.Integer, primary_key=True, autoincrement=True)
-    doc_id = Column(sqlalchemy.String, sqlalchemy.ForeignKey("documents.doc_id"), nullable=False)
-    group_name = Column(sqlalchemy.String, sqlalchemy.ForeignKey("document_groups.group_name"), nullable=False)
+    doc_id = Column(sqlalchemy.String, sqlalchemy.ForeignKey('documents.doc_id'), nullable=False)
+    group_name = Column(sqlalchemy.String, sqlalchemy.ForeignKey('document_groups.group_name'), nullable=False)
     status = Column(sqlalchemy.Text, nullable=True)
     log = Column(sqlalchemy.Text, nullable=True)
     need_reparse = Column(sqlalchemy.Boolean, default=False, nullable=False)
@@ -138,7 +138,7 @@ Examples:
         lazyllm.LOG.info(f'DocManager use file-system monitoring worker: {enable_path_monitoring}')
         self._id = hashlib.sha256(f'{name}@+@{path}'.encode()).hexdigest()
         if not os.path.isabs(path):
-            raise ValueError(f"path [{path}] is not an absolute path")
+            raise ValueError(f'path [{path}] is not an absolute path')
 
         self._init_sql()
         self._delete_nonexistent_docs_on_startup()
@@ -178,7 +178,7 @@ Examples:
             files_list.extend(files)
         return set(files_list)
 
-    # Actually it shoule be "set_docs_status_deleting"
+    # Actually it shoule be 'set_docs_status_deleting'
     def delete_files(self, file_ids: List[str]) -> List[DocPartRow]:
         """Set the knowledge base entries associated with the document to "deleting," and have each knowledge base asynchronously delete parsed results and associated records.
 
@@ -193,8 +193,11 @@ Args:
     def table_inited(self):
         """Checks if the database table `documents` is initialized. This method ensures thread-safety when accessing the database.
 Determines whether the `documents` table exists in the database.
-Returns:
-    bool: `True` if the `documents` table exists, `False` otherwise.
+
+**Returns:**
+
+- bool: `True` if the `documents` table exists, `False` otherwise.
+
 Notes:
     - Uses a thread-safe lock (`self._db_lock`) to ensure safe access to the database.
     - Establishes a connection to the SQLite database at `self._db_path` with the `check_same_thread` option.
@@ -209,10 +212,13 @@ Notes:
     def validate_paths(self, paths: List[str]) -> Tuple[bool, str, List[bool]]:
         """Validates a list of file paths to ensure they are ready for processing.
 This method checks whether the provided paths are new, already processed, or currently being processed. It ensures there are no conflicts in processing the documents.
-Args
+
+Args:
     paths (List[str]): A list of file paths to validate.
-Returns:
-    Tuple[bool, str, List[bool]]: A tuple containing:
+
+**Returns:**
+
+- Tuple[bool, str, List[bool]]: A tuple containing:
         - `bool`: `True` if all paths are valid, `False` otherwise.
         - `str`: A message indicating success or the reason for failure.
         - `List[bool]`: A list where each element corresponds to whether a path is new (`True`) or already exists (`False`).
@@ -228,13 +234,13 @@ Notes:
     def update_need_reparsing(self, doc_id: str, need_reparse: bool):
         """Updates the `need_reparse` status of a document in the `KBGroupDocuments` table.
 This method sets the `need_reparse` flag for a specific document, optionally scoped to a given group.
+
 Args:
     doc_id (str): The ID of the document to update.
     need_reparse (bool): The new value for the `need_reparse` flag.
-    group_name (Optional[str]): If provided, the update will be applied only to the specified group.
+
 Notes:
     - Uses a thread-safe lock (`self._db_lock`) to ensure safe database access.
-    - The `group_name` parameter allows scoping the update to a specific group; if not provided, the update applies to all groups containing the document.
     - The method commits the change to the database immediately.
 """
         pass
@@ -245,13 +251,17 @@ Notes:
                    exclude_status: Optional[Union[str, List[str]]] = None):
         """Lists files from the `documents` table with optional filtering, limiting, and returning details.
 This method retrieves file IDs or detailed file information from the database, based on the specified filtering conditions.
+
 Args:
     limit (Optional[int]): Maximum number of files to return. If `None`, all matching files will be returned.
     details (bool): Whether to return detailed file information (`True`) or just file IDs (`False`).
     status (Union[str, List[str]]): The status or list of statuses to include in the results. Defaults to all statuses.
     exclude_status (Optional[Union[str, List[str]]]): The status or list of statuses to exclude from the results. Defaults to `None`.
-Returns:
-    List: A list of file IDs if `details=False`, or a list of detailed file rows if `details=True`.
+
+**Returns:**
+
+- List: A list of file IDs if `details=False`, or a list of detailed file rows if `details=True`.
+
 Notes:
     - The method constructs a query dynamically based on the provided `status` and `exclude_status` conditions.
     - A thread-safe lock (`self._db_lock`) ensures safe database access.
@@ -262,10 +272,14 @@ Notes:
     @abstractmethod
     def get_docs(self, doc_ids: List[str]) -> List[KBDocument]:
         """This method retrieves document objects of type `KBDocument` from the database for the provided list of document IDs.
+
 Args:
     doc_ids (List[str]): A list of document IDs to fetch.
-Returns:
-    List[KBDocument]: A list of `KBDocument` objects corresponding to the provided document IDs. If no documents are found, an empty list is returned.
+
+**Returns:**
+
+- List[KBDocument]: A list of `KBDocument` objects corresponding to the provided document IDs. If no documents are found, an empty list is returned.
+
 Notes:
     - The method uses a thread-safe lock (`self._db_lock`) to ensure safe database access.
     - It performs a SQL join between `KBDocument` and `KBGroupDocuments` to retrieve the relevant rows.
@@ -286,10 +300,14 @@ Args:
     def fetch_docs_changed_meta(self, group: str) -> List[DocMetaChangedRow]:
         """List files in a specific knowledge base (KB) group with optional filters, limiting, and details.
 This method retrieves files from the `kb_group_documents` table, optionally filtering by group, document status, upload status, and whether reparsing is needed.
+
 Args:
     group (str): The name of the group to filter documents by.
+
 **Returns:**
-    List[DocMetaChangedRow]: A list of rows, where each row contains the `doc_id` and the `new_meta` field of documents with changed metadata.
+
+- List[DocMetaChangedRow]: A list of rows, where each row contains the `doc_id` and the `new_meta` field of documents with changed metadata.
+
 Notes:
     - This method constructs a SQL query dynamically based on the provided filters.
     - Uses a thread-safe lock (`self._db_lock`) to ensure safe database access.
@@ -302,6 +320,7 @@ Notes:
         """Lists all the knowledge base group names.
 
 **Returns:**
+
 - list: List of knowledge base group names.
 """
         pass
@@ -333,8 +352,10 @@ Args:
     upload_status (Union[str, List[str]]): The document upload status or list of statuses to include in the results. Defaults to all statuses.
     exclude_upload_status (Optional[Union[str, List[str]]): The document upload status or list of statuses to exclude from the results. Defaults to `None`.
     need_reparse (Optional[bool]): Whether to filter files that need reparsing or not . Defaults to `None` .
-**Returns:**:
-    List: If `details=False`, returns a list of tuples containing `(doc_id, path)`. 
+
+**Returns:**
+
+- List: If `details=False`, returns a list of tuples containing `(doc_id, path)`. 
           If `details=True`, returns a list of detailed rows with additional metadata.
 Notes:
     - The method first creates document records using the `_add_doc_records` helper function.
@@ -352,13 +373,17 @@ Notes:
     ) -> List[DocPartRow]:
         """Add multiple files to the document list with optional metadata, status, and batch processing.
 This method adds a list of files to the database and sets optional metadata and initial status for each file. The files are processed in batches for efficiency. After the files are added, they are automatically associated with the default knowledge base (KB) group.
+
 Args:
     files (List[str]): A list of file paths to add to the database.
     metadatas (Optional[List[Dict[str, Any]]]): A list of metadata dictionaries corresponding to the files. If `None`, no metadata will be associated. Defaults to `None`.
     status (Optional[str]): The initial status for the added files. Defaults to `Status.waiting`.
     batch_size (int): The number of files to process in each batch. Defaults to 64.
-**Returns:**:
-    List[DocPartRow]: A list of `DocPartRow` objects representing the added files and their associated information.
+
+**Returns:**
+
+- List[DocPartRow]: A list of `DocPartRow` objects representing the added files and their associated information.
+
 Notes:
 - The method first creates document records using the helper function _add_doc_records.
 - After the files are added, they are automatically linked to the default knowledge base group (DocListManager.DEFAULT_GROUP_NAME).
@@ -385,8 +410,8 @@ Notes:
     def delete_unreferenced_doc(self):
         """Delete documents marked as "deleting" and no longer referenced in the database.
 This method removes documents from the database that meet the following conditions:
-1. Their status is set to `DocListManager.Status.deleting`.
-2. Their reference count (`count`) is 0.
+    1. Their status is set to `DocListManager.Status.deleting`.
+    2. Their reference count (`count`) is 0.
 """
         pass
 
@@ -394,10 +419,14 @@ This method removes documents from the database that meet the following conditio
     def get_docs_need_reparse(self, group: Optional[str] = None) -> List[KBDocument]:
         """Retrieve documents that require reparsing for a specific group.
 This method fetches documents that are marked as needing reparsing (`need_reparse=True`) for the given group. Only documents with a status of `success` or `failed` are included in the results.
+
 Args:
     group (str): The name of the group to filter documents by.
-**Returns:**:
-    List[KBDocument]: A list of `KBDocument` objects that need reparsing.
+
+**Returns:**
+
+- List[KBDocument]: A list of `KBDocument` objects that need reparsing.
+
 Notes:
     - The method uses a thread-safe lock (`self._db_lock`) to ensure safe database access.
     - The query performs a SQL `JOIN` between `KBDocument` and `KBGroupDocuments` to filter by group and reparse status.
@@ -409,10 +438,14 @@ Notes:
     def get_existing_paths_by_pattern(self, file_path: str) -> List[str]:
         """Retrieve existing document paths that match a given pattern.
 This method fetches all document paths from the database that match the provided SQL `LIKE` pattern.
+
 Args:
     pattern (str): The SQL `LIKE` pattern to filter document paths. For example, `%example%` matches paths containing the word "example".
-**Returns:**:
-    List[str]: A list of document paths that match the given pattern. If no paths match, an empty list is returned.
+
+**Returns:**
+
+- List[str]: A list of document paths that match the given pattern. If no paths match, an empty list is returned.
+
 Notes:
     - The method uses a thread-safe lock (`self._db_lock`) to ensure safe database access.
     - The `LIKE` operator in the SQL query is used to perform pattern matching on document paths.
@@ -469,6 +502,7 @@ Args:
     fileid (str): File ID.
 
 **Returns:**
+
 - str: The current status of the file.
 """
         pass
@@ -487,6 +521,7 @@ Args:
     new_need_reparse (bool, optinoal): the new need_reparse flag to update to, default None
 
 **Returns:**
+
 - list: updated records, list of (doc_id, group_name)
 """
         pass
@@ -501,8 +536,10 @@ Args:
     def enable_path_monitoring(self):
         """Enable or disable path monitoring for the document manager.
 This method enables or disables the path monitoring functionality in the document manager. When enabled, a monitoring thread starts to handle path-related operations. When disabled, the thread stops and joins (waits for it to terminate).
+
 Args:
     val (bool): Whether to enable or disable path monitoring.
+
 Notes:
     - If `val` is `True`, path monitoring is enabled by setting `_monitor_continue` to `True` and starting the `_monitor_thread`.
     - If `val` is `False`, path monitoring is disabled by setting `_monitor_continue` to `False` and joining the `_monitor_thread` if it is running.
@@ -514,8 +551,10 @@ Notes:
     def enable_path_monitoring(self, val: bool):
         """Enable or disable path monitoring for the document manager.
 This method enables or disables the path monitoring functionality in the document manager. When enabled, a monitoring thread starts to handle path-related operations. When disabled, the thread stops and joins (waits for it to terminate).
+
 Args:
     val (bool): Whether to enable or disable path monitoring.
+
 Notes:
     - If `val` is `True`, path monitoring is enabled by setting `_monitor_continue` to `True` and starting the `_monitor_thread`.
     - If `val` is `False`, path monitoring is disabled by setting `_monitor_continue` to `False` and joining the `_monitor_thread` if it is running.
@@ -580,7 +619,7 @@ Notes:
                 self._init_monitor_event.set()
             is_first_run = False
             time.sleep(10)
-        lazyllm.LOG.warning("END MONITORING")
+        lazyllm.LOG.warning('END MONITORING')
 
     def __del__(self):
         self.enable_path_monitoring = False
@@ -616,7 +655,7 @@ Examples:
         # ensure that this connection is not used in another thread when sqlite3 is not threadsafe
         self._check_same_thread = not sqlite3_check_threadsafety()
         self._engine = sqlalchemy.create_engine(
-            f"sqlite:///{self._db_path}?check_same_thread={self._check_same_thread}"
+            f'sqlite:///{self._db_path}?check_same_thread={self._check_same_thread}'
         )
         self._Session = sessionmaker(bind=self._engine)
         self.init_tables()
@@ -634,13 +673,26 @@ The method queries the sqlite_master metadata table to verify if the "documents"
 - bool: True if the "documents" table exists, False otherwise.
 """
         with self._db_lock, sqlite3.connect(self._db_path, check_same_thread=self._check_same_thread) as conn:
-            cursor = conn.execute("SELECT name FROM sqlite_master WHERE type='table' AND name='documents'")
+            cursor = conn.execute('SELECT name FROM sqlite_master WHERE type=\'table\' AND name=\'documents\'')
             return cursor.fetchone() is not None
 
     @staticmethod
     def get_status_cond_and_params(status: Union[str, List[str]],
                                    exclude_status: Optional[Union[str, List[str]]] = None,
                                    prefix: str = None):
+        """Generates SQL condition expressions and parameter values for filtering documents by status.
+
+Builds WHERE clause components using the given inclusion and exclusion statuses. Supports field name prefixing for use in joined queries.
+
+Args:
+    status (str or list of str): Document status(es) to include. If set to "all", no inclusion condition will be applied.
+    exclude_status (str or list of str, optional): Status(es) to exclude. Must not be "all".
+    prefix (str, optional): Optional field prefix (e.g., table alias) to prepend to the status field.
+
+**Returns:**
+
+- Tuple[str, list]: A tuple containing the SQL condition string and its corresponding parameter values.
+"""
         conds, params = [], []
         prefix = f'{prefix}.' if prefix else ''
         if isinstance(status, str):
@@ -701,7 +753,7 @@ Args:
                 select(KBDocument.doc_id).where(KBDocument.doc_id.in_(doc_ids))
             ).fetchall()
             if len(rows) == 0:
-                return True, "Success", paths_is_new
+                return True, 'Success', paths_is_new
             found_doc_ids = [row.doc_id for row in rows]
             found_doc_group_rows = session.execute(
                 select(KBGroupDocuments.doc_id, KBGroupDocuments.need_reparse, KBGroupDocuments.status)
@@ -709,16 +761,16 @@ Args:
 
         for doc_group_record in found_doc_group_rows:
             if doc_group_record.need_reparse:
-                msg = f"Failed: {doc_id_to_path[doc_group_record.doc_id]} lasttime reparsing has not been finished"
+                msg = f'Failed: {doc_id_to_path[doc_group_record.doc_id]} lasttime reparsing has not been finished'
                 return False, msg, None
             if doc_group_record.status in unsafe_staus_set:
-                return False, f"Failed: {doc_id_to_path[doc_group_record.doc_id]} is being parsed by kbgroup", None
+                return False, f'Failed: {doc_id_to_path[doc_group_record.doc_id]} is being parsed by kbgroup', None
         found_doc_ids = set(found_doc_ids)
         for i in range(len(paths)):
             cur_doc_id = doc_ids[i]
             if cur_doc_id in found_doc_ids:
                 paths_is_new[i] = False
-        return True, "Success", paths_is_new
+        return True, 'Success', paths_is_new
 
     def update_need_reparsing(self, doc_id: str, need_reparse: bool, group_name: Optional[str] = None):
         """Updates the re-parsing flag for a specific document.
@@ -751,14 +803,14 @@ Args:
 
 - list: A list of file records or document paths depending on the `details` flag.
 """
-        query = "SELECT * FROM documents"
+        query = 'SELECT * FROM documents'
         params = []
         status_cond, status_params = self.get_status_cond_and_params(status, exclude_status, prefix=None)
         if status_cond:
             query += f' WHERE {status_cond}'
             params.extend(status_params)
         if limit:
-            query += " LIMIT ?"
+            query += ' LIMIT ?'
             params.append(limit)
         with self._db_lock, sqlite3.connect(self._db_path, check_same_thread=self._check_same_thread) as conn:
             cursor = conn.execute(query, params)
@@ -785,17 +837,17 @@ Args:
 Args:
     doc_meta (Dict[str, dict]): A dictionary mapping document IDs to their new metadata dictionaries.
 """
-        data_to_update = [{"_doc_id": k, "_meta": json.dumps(v)} for k, v in doc_meta.items()]
+        data_to_update = [{'_doc_id': k, '_meta': json.dumps(v)} for k, v in doc_meta.items()]
         with self._db_lock, self._Session() as session:
             # Use sqlalchemy core bulk update
             stmt = KBDocument.__table__.update().where(
-                KBDocument.doc_id == bindparam("_doc_id")).values(meta=bindparam("_meta"))
+                KBDocument.doc_id == bindparam('_doc_id')).values(meta=bindparam('_meta'))
             session.execute(stmt, data_to_update)
             session.commit()
 
             stmt = KBGroupDocuments.__table__.update().where(
-                KBGroupDocuments.doc_id == bindparam("_doc_id"),
-                KBGroupDocuments.status != DocListManager.Status.waiting).values(new_meta=bindparam("_meta"))
+                KBGroupDocuments.doc_id == bindparam('_doc_id'),
+                KBGroupDocuments.status != DocListManager.Status.waiting).values(new_meta=bindparam('_meta'))
             session.execute(stmt, data_to_update)
             session.commit()
 
@@ -830,7 +882,7 @@ Args:
 - List[str]: A list of knowledge base group names.
 """
         with self._db_lock, sqlite3.connect(self._db_path, check_same_thread=self._check_same_thread) as conn:
-            cursor = conn.execute("SELECT group_name FROM document_groups")
+            cursor = conn.execute('SELECT group_name FROM document_groups')
             return [row[0] for row in cursor]
 
     def add_kb_group(self, name):
@@ -868,12 +920,12 @@ Args:
     - If details is True, returns a list of tuples containing detailed file information:
       document ID, path, status, metadata, group name, group status, and group log.
 """
-        query = """
+        query = '''
             SELECT documents.doc_id, documents.path, documents.status, documents.meta,
                    kb_group_documents.group_name, kb_group_documents.status, kb_group_documents.log
             FROM kb_group_documents
             JOIN documents ON kb_group_documents.doc_id = documents.doc_id
-        """
+        '''
         conds, params = [], []
         if group:
             conds.append('kb_group_documents.group_name = ?')
@@ -922,7 +974,7 @@ and adds operation logs for these deletions.
             )
             for doc in docs_to_delete:
                 session.delete(doc)
-                log = KBOperationLogs(log=f"Delete obsolete file, doc_id:{doc.doc_id}, path:{doc.path}.")
+                log = KBOperationLogs(log=f'Delete obsolete file, doc_id:{doc.doc_id}, path:{doc.path}.')
                 session.add(log)
             session.commit()
 
@@ -1009,10 +1061,10 @@ Args:
     fileid (str): Unique identifier of the file (doc_id).
     **kw: Key-value pairs of fields to update and their new values.
 """
-        set_clause = ", ".join([f"{k} = ?" for k in kw.keys()])
+        set_clause = ', '.join([f'{k} = ?' for k in kw.keys()])
         params = list(kw.values()) + [fileid]
         with self._db_lock, sqlite3.connect(self._db_path, check_same_thread=self._check_same_thread) as conn:
-            conn.execute(f"UPDATE documents SET {set_clause} WHERE doc_id = ?", params)
+            conn.execute(f'UPDATE documents SET {set_clause} WHERE doc_id = ?', params)
             conn.commit()
 
     def update_file_status(self, file_ids: List[str], status: str,
@@ -1099,7 +1151,7 @@ Args:
                     doc.count = max(0, doc.count - 1)
                     session.commit()
                 except NoResultFound:
-                    lazyllm.LOG.warning(f"No document found for {doc_id}")
+                    lazyllm.LOG.warning(f'No document found for {doc_id}')
 
     def get_file_status(self, fileid: str):
         """Gets the status of a specified file.
@@ -1112,7 +1164,7 @@ Args:
 - Optional[Tuple]: A tuple containing the status, or None if the file does not exist.
 """
         with self._db_lock, sqlite3.connect(self._db_path, check_same_thread=self._check_same_thread) as conn:
-            cursor = conn.execute("SELECT status FROM documents WHERE doc_id = ?", (fileid,))
+            cursor = conn.execute('SELECT status FROM documents WHERE doc_id = ?', (fileid,))
         return cursor.fetchone()
 
     def update_kb_group(self, cond_file_ids: List[str], cond_group: Optional[str] = None,
@@ -1166,7 +1218,6 @@ Args:
         """Clears all documents, groups, and operation logs from the database.
 
 This operation deletes all records from documents, document_groups, kb_group_documents, and operation_logs tables.
-
 """
         with self._db_lock, sqlite3.connect(self._db_path, check_same_thread=self._check_same_thread) as conn:
             conn.execute('delete from documents')
@@ -1183,15 +1234,15 @@ DocListManager.__pool__ = dict(sqlite=SqliteDocListManager)
 
 
 class BaseResponse(BaseModel):
-    code: int = pydantic.Field(200, description="API status code")
-    msg: str = pydantic.Field("success", description="API status message")
-    data: Any = pydantic.Field(None, description="API data")
+    code: int = pydantic.Field(200, description='API status code')
+    msg: str = pydantic.Field('success', description='API status message')
+    data: Any = pydantic.Field(None, description='API data')
 
     class Config:
         json_schema_extra = {
-            "example": {
-                "code": 200,
-                "msg": "success",
+            'example': {
+                'code': 200,
+                'msg': 'success',
             }
         }
 
@@ -1207,32 +1258,32 @@ def run_in_thread_pool(func: Callable, params: Optional[List[Dict]] = None) -> G
             yield obj.result()
 
 
-Default_Suport_File_Types = [".docx", ".pdf", ".txt", ".json"]
+Default_Suport_File_Types = ['.docx', '.pdf', '.txt', '.json']
 
 
-def _save_file(_file: UploadFile, _file_path: str):
+def _save_file(_file: 'fastapi.UploadFile', _file_path: str):
     file_content = _file.file.read()
-    with open(_file_path, "wb") as f:
+    with open(_file_path, 'wb') as f:
         f.write(file_content)
 
 
 def _convert_path_to_underscores(file_path: str) -> str:
-    return file_path.replace("/", "_").replace("\\", "_")
+    return file_path.replace('/', '_').replace('\\', '_')
 
 
 def _save_file_to_cache(
-    file: UploadFile, cache_dir: str, suport_file_types: List[str]
+    file: 'fastapi.UploadFile', cache_dir: str, suport_file_types: List[str]
 ) -> list:
     to_file_path = os.path.join(cache_dir, file.filename)
 
     sub_result_list_real_name = []
-    if file.filename.endswith(".tar"):
+    if file.filename.endswith('.tar'):
 
         def unpack_archive(tar_file_path: str, extract_folder_path: str):
 
             out_file_names = []
             try:
-                with tarfile.open(tar_file_path, "r") as tar:
+                with tarfile.open(tar_file_path, 'r') as tar:
                     file_info_list = tar.getmembers()
                     for file_info in list(file_info_list):
                         file_extension = os.path.splitext(file_info.name)[-1]
@@ -1240,7 +1291,7 @@ def _save_file_to_cache(
                             tar.extract(file_info.name, path=extract_folder_path)
                             out_file_names.append(file_info.name)
             except tarfile.TarError as e:
-                lazyllm.LOG.error(f"untar error: {e}")
+                lazyllm.LOG.error(f'untar error: {e}')
                 raise e
 
             return out_file_names
@@ -1259,13 +1310,13 @@ def _save_file_to_cache(
 
 
 def save_files_in_threads(
-    files: List[UploadFile],
+    files: List['fastapi.UploadFile'],
     override: bool,
     source_path,
     suport_file_types: List[str] = Default_Suport_File_Types,
 ):
     real_dir = source_path
-    cache_dir = os.path.join(source_path, "cache")
+    cache_dir = os.path.join(source_path, 'cache')
 
     if os.path.exists(cache_dir):
         shutil.rmtree(cache_dir)
@@ -1275,7 +1326,7 @@ def save_files_in_threads(
             os.makedirs(dir)
 
     param_list = [
-        {"file": file, "cache_dir": cache_dir, "suport_file_types": suport_file_types}
+        {'file': file, 'cache_dir': cache_dir, 'suport_file_types': suport_file_types}
         for file in files
     ]
 
@@ -1306,30 +1357,69 @@ def save_files_in_threads(
     return (already_exist_files, new_add_files, overwritten_files)
 
 # returns a list of modified nodes
-def parallel_do_embedding(embed: Dict[str, Callable], embed_keys: Optional[Union[List[str], Set[str]]],
+def parallel_do_embedding(embed: Dict[str, Callable], embed_keys: Optional[Union[List[str], Set[str]]],  # noqa: C901
                           nodes: List[DocNode], group_embed_keys: Dict[str, List[str]] = None) -> List[DocNode]:
-    modified_nodes = []
-    with ThreadPoolExecutor(config["max_embedding_workers"]) as executor:
-        futures = []
-        for node in nodes:
-            if group_embed_keys:
-                embed_keys = group_embed_keys.get(node._group)
-                if not embed_keys:
-                    continue
-            miss_keys = node.has_missing_embedding(embed_keys)
-            if not miss_keys:
-                continue
-            modified_nodes.append(node)
-            for k in miss_keys:
-                with node._lock:
-                    if node.has_missing_embedding(k):
-                        future = executor.submit(node.do_embedding, {k: embed[k]}) \
-                            if k not in node._embedding_state else executor.submit(node.check_embedding_state, k)
-                        node._embedding_state.add(k)
-                        futures.append(future)
-        if len(futures) > 0:
-            for future in concurrent.futures.as_completed(futures):
-                future.result()
+    if not nodes: return []
+
+    max_workers = config['max_embedding_workers']
+
+    tasks_by_key: Dict[str, List[DocNode]] = defaultdict(list)
+    modified_nodes: List[DocNode] = []
+    for node in nodes:
+        if group_embed_keys and not group_embed_keys.get(node._group):
+            continue
+        keys_for_node = (group_embed_keys.get(node._group) if group_embed_keys else embed_keys) or embed.keys()
+        miss = node.has_missing_embedding(keys_for_node)
+        if not miss:
+            continue
+        modified_nodes.append(node)
+        for k in miss:
+            tasks_by_key[k].append(node)
+            if hasattr(node, '_embedding_state'):
+                node._embedding_state.add(k)
+
+    if not tasks_by_key:
+        return []
+    concurrent_workers = min(max_workers, len(tasks_by_key))
+    max_workers_per_key = max(1, max_workers // max(1, concurrent_workers))
+
+    def _check_batch(fn):
+        batch_size = getattr(fn, 'batch_size', None)
+        return isinstance(batch_size, Integral) and batch_size > 1
+
+    def _process_key(k: str, knodes: List[DocNode]):
+        try:
+            fn = embed[k]
+            if _check_batch(fn):
+                texts = [n.get_text(MetadataMode.EMBED) for n in knodes]
+                vecs = fn(texts)
+                if len(vecs) != len(texts):
+                    raise ValueError(f'[LazyLLM - parallel_do_embedding][{k}] batch size mismatch: '
+                                     f'[text_num:{len(texts)}] vs [vec_num:{len(vecs)}]')
+                for n, v in zip(knodes, vecs):
+                    n.set_embedding(k, v)
+                return
+
+            if max_workers_per_key == 1:
+                for n in knodes:
+                    n.do_embedding({k: fn})
+            else:
+                with ThreadPoolExecutor(max_workers=max_workers_per_key) as ex2:
+                    futs = [ex2.submit(n.do_embedding, {k: fn}) for n in knodes]
+                    for fut in as_completed(futs):
+                        fut.result()
+        except Exception as e:
+            lazyllm.LOG.error(f'[LazyLLM - parallel_do_embedding][{k}] error: {e}')
+            for n in knodes:
+                if hasattr(n, '_embedding_state') and k in n._embedding_state:
+                    with n._lock:
+                        n._embedding_state.remove(k)
+            raise e
+
+    with ThreadPoolExecutor(max_workers=min(max_workers, len(tasks_by_key))) as ex:
+        futs = [ex.submit(_process_key, k, k_nodes) for k, k_nodes in tasks_by_key.items()]
+        for fut in as_completed(futs):
+            fut.result()
     return modified_nodes
 
 class _FileNodeIndex(IndexBase):
@@ -1413,19 +1503,17 @@ def is_sparse(embedding: Union[Dict[int, float], List[Tuple[int, float]], List[f
     raise TypeError(f'unsupported embedding type `{type(embedding[0])}`')
 
 
-def ensure_call_endpoint(raw: str) -> str:
-    if not raw: return raw
-    if '://' not in raw:
-        raw = f'http://{raw}'
+def ensure_call_endpoint(raw: str, *, default_path: str = '/_call') -> str:
+    if not raw:
+        return raw
 
-    parts = urlsplit(raw)
-    path = parts.path or ''
+    raw = raw.strip()
+    has_scheme = '://' in raw
+    parts = urlsplit(raw if has_scheme else f'//{raw}', allow_fragments=True)
 
-    if path.rstrip('/').endswith('_call'):
-        new_path = path.rstrip('/')
-    elif path == '' or path.endswith('/'):
-        new_path = (path or '') + '_call' if path.endswith('/') else '/_call'
-    else:
-        new_path = path + '/_call'
+    if not parts.netloc:
+        raise ValueError(f'Invalid endpoint (missing host): {raw}')
 
-    return urlunsplit((parts.scheme, parts.netloc, new_path, parts.query, parts.fragment))
+    scheme = parts.scheme or 'http'
+    new_path = default_path
+    return urlunsplit((scheme, parts.netloc, new_path, parts.query, parts.fragment))
