@@ -2,4 +2,4 @@ from .sql_manager import SqlManager
 from .mongodb_manager import MongoDBManager
 from .db_manager import DBManager, DBResult, DBStatus
 
-__all__ = ["DBManager", "SqlManager", "MongoDBManager", "DBResult", "DBStatus"]
+__all__ = ['DBManager', 'SqlManager', 'MongoDBManager', 'DBResult', 'DBStatus']
