@@ -1,3 +1,3 @@
 from .sql_call import SqlCall
 
-__all__ = ["SqlCall"]
+__all__ = ['SqlCall']
