@@ -7,16 +7,16 @@ import datetime
 import re
 from lazyllm.tools.sql import DBManager
 
-sql_query_instruct_template = """
+sql_query_instruct_template = '''
 Given the following SQL tables and current date {current_date}, your job is to write sql queries in {db_type} given a user’s request.
 
 {desc}
 
-Alert: Just reply the sql query in a code block start with triple-backticks and keyword "sql"
-"""  # noqa E501
+Alert: Just reply the sql query in a code block start with triple-backticks and keyword 'sql'
+'''  # noqa E501
 
 
-mongodb_query_instruct_template = """
+mongodb_query_instruct_template = '''
 Current date is {current_date}.
 You are a seasoned expert with 10 years of experience in crafting NoSQL queries for {db_type}. 
 I will provide a collection description in a specified format. 
@@ -24,10 +24,10 @@ Your task is to analyze the user_question, which follows certain guidelines, and
 
 {desc}
 
-Note: Please return the json pipeline in a code block start with triple-backticks and keyword "json".
-"""  # noqa E501
+Note: Please return the json pipeline in a code block start with triple-backticks and keyword 'json'.
+'''  # noqa E501
 
-db_explain_instruct_template = """
+db_explain_instruct_template = '''
 According to chat history
 ```
 {{history_info}}
@@ -47,19 +47,20 @@ the result is
 ```
 {{result}}
 ```
-"""
+'''
 
 
 class SqlCall(ModuleBase):
     """SqlCall is a class that extends ModuleBase and provides an interface for generating and executing SQL queries using a language model (LLM).
 It is designed to interact with a SQL database, extract SQL queries from LLM responses, execute those queries, and return results or explanations.
 
-Arguments:
+Args:
     llm: A language model to be used for generating and interpreting SQL queries and explanations.
-    sql_manager (SqlManager): An instance of SqlManager that handles interaction with the SQL database.
-    sql_examples (str, optional): An example of converting natural language represented by a JSON string into an SQL statement, formatted as: [{"Question": "Find the names of people in the same department as Smith", "Answer": "SELECT...;"}]
-    use_llm_for_sql_result (bool, optional): Default is True. If set to False, the module will only output raw SQL results in JSON without further processing.
-    return_trace (bool, optional): If set to True, the results will be recorded in the trace. Defaults to False.
+    sql_manager (DBManager): Database manager instance containing connection and description information
+    sql_examples (str, optional): SQL example strings for prompt engineering. Defaults to empty string
+    sql_post_func (Callable, optional): Function for post-processing generated SQL statements. Defaults to ``None``
+    use_llm_for_sql_result (bool, optional): Whether to use LLM to explain SQL execution results. Defaults to ``True``
+    return_trace (bool, optional): Whether to return execution trace information. Defaults to ``False``
 
 
 Examples:
@@ -71,35 +72,35 @@ Examples:
         >>> sql_call = SqlCall(sql_llm, sql_tool, use_llm_for_sql_result=True)
         >>> print(sql_call("去年一整年销售额最多的员工是谁?"))
     """
-    EXAMPLE_TITLE = "Here are some example: "
+    EXAMPLE_TITLE = 'Here are some example: '
 
     def __init__(
         self,
         llm,
         sql_manager: DBManager,
-        sql_examples: str = "",
+        sql_examples: str = '',
         sql_post_func: Callable = None,
         use_llm_for_sql_result=True,
         return_trace: bool = False,
     ) -> None:
         super().__init__(return_trace=return_trace)
         if not sql_manager.desc:
-            raise ValueError("Error: sql_manager found empty description.")
+            raise ValueError('Error: sql_manager found empty description.')
         self._sql_tool = sql_manager
         self.sql_post_func = sql_post_func
 
-        if sql_manager.db_type == "mongodb":
+        if sql_manager.db_type == 'mongodb':
             self._query_prompter = ChatPrompter(instruction=mongodb_query_instruct_template).pre_hook(
                 self.sql_query_promt_hook
             )
-            statement_type = "mongodb json pipeline"
-            self._pattern = re.compile(r"```json(.+?)```", re.DOTALL)
+            statement_type = 'mongodb json pipeline'
+            self._pattern = re.compile(r'```json(.+?)```', re.DOTALL)
         else:
             self._query_prompter = ChatPrompter(instruction=sql_query_instruct_template).pre_hook(
                 self.sql_query_promt_hook
             )
-            statement_type = "sql query"
-            self._pattern = re.compile(r"```sql(.+?)```", re.DOTALL)
+            statement_type = 'sql query'
+            self._pattern = re.compile(r'```sql(.+?)```', re.DOTALL)
 
         self._llm_query = llm.share(prompt=self._query_prompter).used_by(self._module_id)
         self._answer_prompter = ChatPrompter(
@@ -135,15 +136,16 @@ Args:
     tools (Union[List[Dict[str, Any]], None]): Available tool descriptions.
     label (Union[str, None]): Optional label for the prompt.
 
-Returns:
-    Tuple: A tuple containing the formatted prompt dict (with current_date, db_type, desc, user_query), history, tools, and label.
+**Returns:**
+
+- Tuple: A tuple containing the formatted prompt dict (with current_date, db_type, desc, user_query), history, tools, and label.
 """
-        current_date = datetime.datetime.now().strftime("%Y-%m-%d")
+        current_date = datetime.datetime.now().strftime('%Y-%m-%d')
         schema_desc = self._sql_tool.desc
         if self.example:
-            schema_desc += f"\n{self.EXAMPLE_TITLE}\n{self.example}\n"
+            schema_desc += f'\n{self.EXAMPLE_TITLE}\n{self.example}\n'
         if not isinstance(input, str):
-            raise ValueError(f"Unexpected type for input: {type(input)}")
+            raise ValueError(f'Unexpected type for input: {type(input)}')
         return (
             dict(current_date=current_date, db_type=self._sql_tool.db_type, desc=schema_desc, user_query=input),
             history or [],
@@ -166,16 +168,17 @@ Args:
     tools (Union[List[Dict[str, Any]], None]): Available tool descriptions.
     label (Union[str, None]): Optional label for the prompt.
 
-Returns:
-    Tuple: A tuple containing the formatted prompt dict (history_info, desc, query, result, explain_query), history, tools, and label.
+**Returns:**
+
+- Tuple: A tuple containing the formatted prompt dict (history_info, desc, query, result, explain_query), history, tools, and label.
 """
-        explain_query = "Tell the user based on the execution results, making sure to keep the language consistent \
-            with the user's input and don't translate original result."
+        explain_query = 'Tell the user based on the execution results, making sure to keep the language consistent \
+            with the user\'s input and don\'t translate original result.'
         if not isinstance(input, list) and len(input) != 2:
-            raise ValueError(f"Unexpected type for input: {type(input)}")
-        assert "root_input" in globals and self._llm_answer._module_id in globals["root_input"]
-        user_query = globals["root_input"][self._llm_answer._module_id]
-        globals.pop("root_input")
+            raise ValueError(f'Unexpected type for input: {type(input)}')
+        assert 'root_input' in globals and self._llm_answer._module_id in globals['root_input']
+        user_query = globals['root_input'][self._llm_answer._module_id]
+        globals.pop('root_input')
         history_info = chat_history_to_str(history, user_query)
         return (
             dict(
@@ -196,8 +199,9 @@ Returns:
 Args:
     str_response (str): Raw text returned by the LLM which may contain code fences.
 
-Returns:
-    tuple[bool, str]: A tuple where the first element indicates whether extraction succeeded, and the second is the cleaned or original content. If sql_post_func is provided, it is applied to the extracted content.
+**Returns:**
+
+- tuple[bool, str]: A tuple where the first element indicates whether extraction succeeded, and the second is the cleaned or original content. If sql_post_func is provided, it is applied to the extracted content.
 """
         # Remove the triple backticks if present
         matches = self._pattern.findall(str_response)
@@ -209,7 +213,7 @@ Returns:
             return False, str_response
 
     def forward(self, input: str, llm_chat_history: List[Dict[str, Any]] = None):
-        globals["root_input"] = {self._llm_answer._module_id: input}
-        if self._module_id in globals["chat_history"]:
-            globals["chat_history"][self._llm_query._module_id] = globals["chat_history"][self._module_id]
+        globals['root_input'] = {self._llm_answer._module_id: input}
+        if self._module_id in globals['chat_history']:
+            globals['chat_history'][self._llm_query._module_id] = globals['chat_history'][self._module_id]
         return self._impl(input)
