@@ -18,7 +18,7 @@ from lazyllm.components.formatter import decode_query_with_filepaths, encode_que
 from ...module.module import ModuleBase
 
 
-css = """
+css = '''
 #logging {background-color: #FFCCCB}
 
 #module {
@@ -26,7 +26,7 @@ css = """
   font-size: 16px;
   white-space: pre !important;
 }
-"""
+'''
 
 class WebModule(ModuleBase):
     """WebModule is a web-based interactive interface provided by LazyLLM for developers. After initializing and starting
@@ -37,18 +37,20 @@ programmatically to the web page for additional parameters to the background mod
 provides Checkboxes of “Use Context,” “Stream Output,” and “Append Output,” which can be used to adjust the
 interaction between the page and the module behind.
 
-<span style="font-size: 20px;">&ensp;**`WebModule.init_web(component_descs) -> gradio.Blocks`**</span>
-
-Generate a demonstration web page based on gradio. The function initializes session-related data to save chat history
-and logs for different pages, then dynamically add Checkbox and Text components to the page according to component_descs
-parameter, and set the corresponding functions for the buttons and text boxes on the page at last.
-WebModule’s __init__ function calls this method to generate the page.
-
 Args:
-    component_descs (list): A list used to add components to the page. Each element in the list is also a list containing
-    5 elements, which are the module ID, the module name, the component name, the component type (currently only
-    supports Checkbox and Text), and the default value of the component.
-
+    m (Any): The model object to wrap, can be a lazyllm.FlowBase subclass or other callable object.
+    components (Dict[Any, Any], optional): Additional UI component configurations, defaults to empty dict.
+    title (str, optional): Web page title, defaults to 'Dialogue Demo Terminal'.
+    port (Optional[Union[int, range, tuple, list]], optional): Service port number or port range, defaults to 20500-20799.
+    history (List[Any], optional): List of historical session modules, defaults to empty list.
+    text_mode (Optional[Mode], optional): Text output mode (Dynamic/Refresh/Appendix), defaults to Dynamic.
+    trace_mode (Optional[Mode], optional): Deprecated trace mode parameter.
+    audio (bool, optional): Whether to enable audio input functionality, defaults to False.
+    stream (bool, optional): Whether to enable streaming output, defaults to False.
+    files_target (Optional[Union[Any, List[Any]]], optional): Target module for file processing, defaults to None.
+    static_paths (Optional[Union[str, Path, List[Union[str, Path]]]], optional): Static resource paths, defaults to None.
+    encode_files (bool, optional): Whether to encode file paths, defaults to False.
+    share (bool, optional): Whether to generate a shareable public link, defaults to False.
 
 
 Examples:
@@ -84,7 +86,7 @@ Examples:
         elif static_paths is None:
             self._static_paths = []
         else:
-            raise ValueError(f"static_paths only supported str, path or list types. Not supported {static_paths}")
+            raise ValueError(f'static_paths only supported str, path or list types. Not supported {static_paths}')
         self.m = lazyllm.ActionModule(m) if isinstance(m, lazyllm.FlowBase) else m
         self.pool = lazyllm.ThreadPoolExecutor(max_workers=50)
         self.title = title
@@ -118,7 +120,7 @@ Examples:
         )
 
     def _signal_handler(self, signum, frame):
-        LOG.info(f"Signal {signum} received, terminating subprocess.")
+        LOG.info(f'Signal {signum} received, terminating subprocess.')
         atexit._run_exitfuncs()
         sys.exit(0)
 
@@ -135,11 +137,14 @@ Examples:
     def init_web(self, component_descs):
         """Initialize the Web UI page.
 This method uses Gradio to build the interactive chat interface and binds all components to the appropriate logic. It supports session selection, streaming output, context toggling, multimodal input, and control tools. The method returns the constructed Gradio Blocks object.
+
 Args:
     component_descs (List[Tuple]): A list of component descriptors. Each element is a 5-tuple 
         (module, group_name, name, component_type, value), e.g. ('MyModule', 'GroupA', 'use_cache', 'Checkbox', True).
-Returns:
-    gr.Blocks: The constructed Gradio UI object, which can be launched via `.launch()`.
+
+**Returns:**
+
+- gr.Blocks: The constructed Gradio UI object, which can be launched via `.launch()`.
 """
         gr.set_static_paths(self._static_paths)
         with gr.Blocks(css=css, title=self.title, analytics_enabled=False) as demo:
@@ -156,13 +161,13 @@ Returns:
                     with gr.Row():
                         with lazyllm.config.temp('repr_show_child', True):
                             gr.Textbox(elem_id='module', interactive=False, show_label=True,
-                                       label="模型结构", value=repr(self.m))
+                                       label='模型结构', value=repr(self.m))
                     with gr.Row():
-                        chat_use_context = gr.Checkbox(interactive=True, value=False, label="使用上下文")
+                        chat_use_context = gr.Checkbox(interactive=True, value=False, label='使用上下文')
                     with gr.Row():
-                        stream_output = gr.Checkbox(interactive=self.stream, value=self.stream, label="流式输出")
+                        stream_output = gr.Checkbox(interactive=self.stream, value=self.stream, label='流式输出')
                         text_mode = gr.Checkbox(interactive=(self.text_mode == WebModule.Mode.Dynamic),
-                                                value=(self.text_mode != WebModule.Mode.Refresh), label="追加输出")
+                                                value=(self.text_mode != WebModule.Mode.Refresh), label='追加输出')
                     components = []
                     for _, gname, name, ctype, value in component_descs:
                         if ctype in ('Checkbox', 'Text'):
@@ -175,15 +180,15 @@ Returns:
                     with gr.Row():
                         dbg_msg = gr.Textbox(show_label=True, label='处理日志',
                                              elem_id='logging', interactive=False, max_lines=10)
-                    clear_btn = gr.Button(value="🗑️  Clear history", interactive=True)
+                    clear_btn = gr.Button(value='🗑️  Clear history', interactive=True)
                 with gr.Column(scale=6):
                     with gr.Row():
-                        add_sess_btn = gr.Button("添加新会话")
-                        sess_drpdn = gr.Dropdown(choices=sess_data.value['sess_titles'], label="选择会话：", value='')
-                        del_sess_btn = gr.Button("删除当前会话")
+                        add_sess_btn = gr.Button('添加新会话')
+                        sess_drpdn = gr.Dropdown(choices=sess_data.value['sess_titles'], label='选择会话：', value='')
+                        del_sess_btn = gr.Button('删除当前会话')
                     chatbot = gr.Chatbot(height=700)
                     query_box = gr.MultimodalTextbox(show_label=False, placeholder='输入内容并回车!!!', interactive=True)
-                    recordor = gr.Audio(sources=["microphone"], type="filepath", visible=self.audio)
+                    recordor = gr.Audio(sources=['microphone'], type='filepath', visible=self.audio)
 
             query_box.submit(self._init_session, [query_box, sess_data, recordor],
                                                  [sess_drpdn, chatbot, dbg_msg, sess_data, recordor], queue=True
@@ -221,11 +226,11 @@ Returns:
         if session['curr_sess'] != '':  # remain unchanged.
             return gr.Dropdown(), gr.Chatbot(), gr.Textbox(), session, audio
 
-        if "text" in query and query["text"] is not None:
+        if 'text' in query and query['text'] is not None:
             id_name = query['text']
         else:
             id_name = id(id_name)
-        session['curr_sess'] = f"({session['sess_num']})  {id_name}"
+        session['curr_sess'] = f'({session["sess_num"]})  {id_name}'
         session['sess_num'] += 1
         session['sess_titles'][0] = session['curr_sess']
 
@@ -290,9 +295,9 @@ Returns:
             query = session['frozen_query']
         if chat_history is None:
             chat_history = []
-        for x in query["files"]:
+        for x in query['files']:
             chat_history.append([[x,], None])
-        if "text" in query and query["text"]:
+        if 'text' in query and query['text']:
             chat_history.append([query['text'], None])
         return {}, chat_history
 
@@ -357,20 +362,20 @@ Returns:
 
             def get_log_and_message(s):
                 if isinstance(s, dict):
-                    s = s.get("message", {}).get("content", "")
+                    s = s.get('message', {}).get('content', '')
                 else:
                     try:
                         r = decode_query_with_filepaths(s)
                         if isinstance(r, str):
                             r = json.loads(r)
                         if 'choices' in r:
-                            if "type" not in r["choices"][0] or (
-                                    "type" in r["choices"][0] and r["choices"][0]["type"] != "tool_calls"):
-                                delta = r["choices"][0]["delta"]
-                                if "content" in delta:
-                                    s = delta["content"]
+                            if 'type' not in r['choices'][0] or (
+                                    'type' in r['choices'][0] and r['choices'][0]['type'] != 'tool_calls'):
+                                delta = r['choices'][0]['delta']
+                                if 'content' in delta:
+                                    s = delta['content']
                                 else:
-                                    s = ""
+                                    s = ''
                         elif isinstance(r, dict) and 'files' in r and 'query' in r:
                             return r['query'], ''.join(log_history), r['files'] if len(r['files']) > 0 else None
                         else:
@@ -378,15 +383,15 @@ Returns:
                     except (ValueError, KeyError, TypeError):
                         s = s
                     except Exception as e:
-                        LOG.error(f"Uncaptured error `{e}` when parsing `{s}`, please contact us if you see this.")
-                return s, "".join(log_history), None
+                        LOG.error(f'Uncaptured error `{e}` when parsing `{s}`, please contact us if you see this.')
+                return s, ''.join(log_history), None
 
             def contains_markdown_image(text: str):
-                pattern = r"!\[.*?\]\((.*?)\)"
+                pattern = r'!\[.*?\]\((.*?)\)'
                 return bool(re.search(pattern, text))
 
             def extract_img_path(text: str):
-                pattern = r"!\[.*?\]\((.*?)\)"
+                pattern = r'!\[.*?\]\((.*?)\)'
                 urls = re.findall(pattern, text)
                 return urls
 
@@ -419,11 +424,11 @@ Returns:
                     for url in urls:
                         suffix = os.path.splitext(url)[-1].lower()
                         if suffix in PIL.Image.registered_extensions().keys() and os.path.exists(url):
-                            show_result = show_result.replace(url, "file=" + url)
+                            show_result = show_result.replace(url, 'file=' + url)
                 if result:
                     count = (len(match.group(1)) if (match := re.search(r'(\n+)$', result)) else 0) + len(result) + 1
                     if not (result in chat_history[-1][1][-count:]):
-                        chat_history[-1][1] += "\n\n" + show_result
+                        chat_history[-1][1] += '\n\n' + show_result
                     elif show_result != result:
                         chat_history[-1][1] = chat_history[-1][1].replace(result, show_result)
         except requests.RequestException as e:
@@ -451,7 +456,7 @@ Returns:
         self.url = f'http://127.0.0.1:{port}'
         self.broadcast_url = f'http://0.0.0.0:{port}'
 
-        self.demo.queue().launch(server_name="0.0.0.0", server_port=port, prevent_thread_lock=True, share=self.share)
+        self.demo.queue().launch(server_name='0.0.0.0', server_port=port, prevent_thread_lock=True, share=self.share)
         LOG.success('LazyLLM webmodule launched successfully: Running on: '
                     f'{self.broadcast_url}, local URL: {self.url}')
 
